
/*
 * header file for the XINU serial communication driver
 * for eZ80L92 MPU
 * 
 * by Andrei Kovalev
 * Copyright (C) Zilog 2002-2003
 */

#ifndef _AKOV_COM_DRIVER
#define _AKOV_COM_DRIVER

typedef unsigned char uc8;

#define hCOM1 com_device[0]. device_index
#define hCOM2 com_device[1]. device_index

// control functions
#define GET_INQ  1 // input queue usage in bytes
#define GET_OUQ  2 // output queue usage
#define GET_OV   3 // overflow count
#define SET_RATE 4 // set the baudrate
#define SET_LINE 5 // set the line control register
#define SET_FLOW 6 // set the line flow control

// eZ80 UART configuration flags,
// see product specification, UART_LCTL register
#define COM_PEN   0x08 // parity enable
#define COM_STOP1 0x00 // 1 stop bit
#define COM_STOP2 0x04 // 2 stop bits
#define COM_DATA5 0x00 // 5 data bits
#define COM_DATA6 0x01 // 6 data bits
#define COM_DATA7 0x02 // 7 data bits
#define COM_DATA8 0x03 // 8 data bits

#define COM_FLOW_NONE 0x00 // no flow control
#define COM_FLOW_SOFT 0x01 // software flow control
#define COM_FLOW_HARD 0x02 // hardware flow control

#define COM_XON  (char)17 // Ctrl-Q, resume 
#define COM_XOFF (char)19 // Ctrl-S, stop

/*
 * communication buffer descriptor structure
 * inbfr - input cycling buffer
 * inrd  - input buffer read pointer
 * inwr  - input buffer write pointer
 * inov  - input buffer overflow counter
 * oubfr - output cycling buffer
 * ourd  - output buffer read pointer
 * ouwr  - output buffer write pointer
 * ouov  - output buffer overflow counter
 * base  - UART base for the com port
 */
typedef struct combuffers
{
    unsigned char base;
    unsigned char flow;
    unsigned char *inbfr;
    unsigned char *inrd;
    unsigned char *inwr;
    unsigned char inov;
    unsigned char *oubfr;
    unsigned char *ourd;
    unsigned char *ouwr;
    unsigned char ouov;
} combufferpool;

/*--
 * The structure sontains information about an initialized
 * COM device
 */
typedef struct tag_com_device
{
    int device_index;
    combufferpool *com_ctl_block;
} tcom_device;

extern tcom_device com_device[2];

int com_init( );

#endif
