
/*
 * comisr.c - serial communication interrupt
 * for the driver implementation by Andrei Kovalev of Zilog
 * ----------------------------
 *    Copyright (C) 2003
 * ----------------------------
 * September 2002 - 190 version
 * January   2003 - L92 version
 */
#include <kernel.h>

#include "com.h"

// UART control block
extern int comBfrSize;
extern combufferpool *com_ctl_block;

/*-- @func comisr
 * communication interrupt service routine
 * 
 * 03.09.2002 14:29 
 * try to find the source and process it
 * 
 * the routine is 600 bytes large - latency 1000/48 ~ 20 us
 */
void comisr( void )
{
    unsigned char status, base;
    combufferpool *com_ctl_block;

    #ifdef DEBUG
    // illumination for L92 development board
    unsigned char *ledan,*ledca;
    ledan = (unsigned char *)0xE00000;
    ledca = (unsigned char *)0xE00001;
    #endif

    // read the indication register to find out the source
    // pick the proper control block
    com_ctl_block = NULL;
//    kprintf("\n%x", UART_IIR(0xD0) );
    if( !(UART_IIR(0xD0) & 0x01) )
        com_ctl_block =
            com_device[1]. com_ctl_block;
    else
    if( !(UART_IIR(0xC0) & 0x01) )
        com_ctl_block =
            com_device[0]. com_ctl_block;

    if( com_ctl_block != 0 )
    while( 1 )
    {
        status = UART_IIR(com_ctl_block->base);

    #ifdef DEBUG
        *ledca = 0xFE;
        *ledan = status; 
    #endif

        if( status & 0x01 )
            break;

        // extract the interrupt status code
        status = status & 0x0E;
        // Status codes sorted by priority
        // Value    Interrupt Type
        //   0110   Receiver Line Status
        //   0100   Receive Data Ready or Trigger Level
        //   1100   Character Time-out
        //   0010   Transmit Buffer Empty
        //   0000   Modem Status

        //*-- receive data ready
        // or a character timeout
        if( (status ==  4)
         || (status == 12) )
        {
            status = UART_LSR(com_ctl_block->base);

            // check overrun error and do flow control
            if(status & 0x02)
            // stop sender
            if( com_ctl_block->flow == COM_FLOW_HARD )
                UART_MCTL(com_ctl_block->base) &= 0xFD;
            else
                UART_THR(com_ctl_block->base) = COM_XOFF;
            else
            // resume sender
            if( com_ctl_block->flow == COM_FLOW_HARD )
                UART_MCTL(com_ctl_block->base) |= 0x02;
            else
                UART_THR(com_ctl_block->base) = COM_XON;

            status = UART_RBR(com_ctl_block->base);
            //kprintf("r");
            // place the character into the input buffer
            *com_ctl_block->inwr ++ = status;
            if( com_ctl_block->inwr - com_ctl_block->inbfr >= comBfrSize )
                com_ctl_block->inwr = com_ctl_block->inbfr;
            // if wrote and equal to read location then overflow
            if( com_ctl_block->inwr == com_ctl_block->inrd )
                com_ctl_block->inov ++ ;
        }
        //*-- transmit buffer empty
        else if(status == 2)
        {
            unsigned char cnt;
            cnt = 16;
            // this is the transmit interrupt, output FIFO is empty
            // can write up to 16 bytes
            // place the character into the input buffer
            while( (com_ctl_block->ourd != com_ctl_block->ouwr) && --cnt )
            {
                // put the charachter into UART
                UART_THR(com_ctl_block->base) = *com_ctl_block->ourd ++;
                #ifdef DEBUG
                // wipe the sent chars to see progress
                *(com_ctl_block->ourd-1) = 0;
                #endif
                // roll over the buffer end
                if( com_ctl_block->ourd - com_ctl_block->oubfr >= comBfrSize )
                    com_ctl_block->ourd = com_ctl_block->oubfr;
            }
            UART_IER(com_ctl_block->base) &= ~IER_TIE;
        }
        //*-- receiver line status
        else if(status == 6)
        {
            status = UART_LSR(com_ctl_block->base);
        }
    }
    status = UART_LSR(com_ctl_block->base);
}

/*-- @func comisr
 * communication interrupt service routine
 * 
 * 03.09.2002 14:29 just repeat the same routine for both
 * interfaces
 * /
void comisr( void )
{
    unsigned char status, base;
    combufferpool *com_ctl_block;
    // read the indication register to find out the source
    base = 0xC0;
    com_ctl_block =
        com_device[0]. com_ctl_block;
    while( 1 )
    {
        status = UART_IIR(base);
        if( status & 0x01 )
            break;

        status = status & 0x0E;
        if( status == 4 )       // receive data ready
        {
            status = UART_LSR(base);
            status = UART_RBR(base);
            //kprintf("r");
            // place the character into the input buffer
            *com_ctl_block->inwr ++ = status;
            if( com_ctl_block->inwr - com_ctl_block->inbfr > comBfrSize )
                com_ctl_block->inwr = com_ctl_block->inbfr;
            // if wrote and equal to read location then overflow
            if( com_ctl_block->inwr == com_ctl_block->inrd )
                com_ctl_block->inov ++ ;
        }
        else if(status == 2)    // transmit buffer empty
        {
            char xch[2];
            // place the character into the input buffer
            if( com_ctl_block->ourd != com_ctl_block->ouwr  )
            {
                xch[0] = *com_ctl_block->ourd;
                xch[1] = 0;
                UART_THR(com_ctl_block->base) = *com_ctl_block->ourd ++;
                kprintf(xch);
                if( com_ctl_block->ourd - com_ctl_block->oubfr > comBfrSize )
                    com_ctl_block->ourd = com_ctl_block->oubfr;
            }
            else
                UART_IER(com_ctl_block->base) &= ~IER_TIE;
        }
        else if(status == 6)    // receiver line status
        {
            status = UART_LSR(com_ctl_block->base);
            kprintf("l");
        }
        else
            kprintf("0");
    }
    status = UART_LSR(com_ctl_block->base);

    base = 0xD0;
    com_ctl_block =
        com_device[1]. com_ctl_block;
    while( 1 )
    {
        status = UART_IIR(base);
        if( status & 0x01 )
            break;

        status = status & 0x0E;
        if( status == 4 )       // receive data ready
        {
            status = UART_LSR(base);
            status = UART_RBR(base);
            //kprintf("r");
            // place the character into the input buffer
            *com_ctl_block->inwr ++ = status;
            if( com_ctl_block->inwr - com_ctl_block->inbfr > comBfrSize )
                com_ctl_block->inwr = com_ctl_block->inbfr;
            // if wrote and equal to read location then overflow
            if( com_ctl_block->inwr == com_ctl_block->inrd )
                com_ctl_block->inov ++ ;
        }
        else if(status == 2)    // transmit buffer empty
        {
            char xch[2];
            // place the character into the input buffer
            if( com_ctl_block->ourd != com_ctl_block->ouwr  )
            {
                xch[0] = *com_ctl_block->ourd;
                xch[1] = 0;
                UART_THR(com_ctl_block->base) = *com_ctl_block->ourd ++;
                kprintf(xch);
                if( com_ctl_block->ourd - com_ctl_block->oubfr > comBfrSize )
                    com_ctl_block->ourd = com_ctl_block->oubfr;
            }
            else
                UART_IER(com_ctl_block->base) &= ~IER_TIE;
        }
        else if(status == 6)    // receiver line status
        {
            status = UART_LSR(com_ctl_block->base);
            kprintf("l");
        }
        else
            kprintf("0");
    }
    status = UART_LSR(com_ctl_block->base);
}

 */
