
/*
 * COM device driver test with Ethernet
 * 
 * HTTP simulates Ethernet activity
 */

#include <http.h>
#include <bootinfo.h>
#include <network.h>
#include <stdlib.h>

#include "com.h"

int comBfrSize = 2048;

/*
 * Default Network Configuration
 */
struct BootInfo Bootrecord = {
        "192.168.1.192",    /* Default IP address */
        "192.168.1.4",      /* Default Gateway */
        "192.168.1.5",      /* Default Timer Server */
        "192.168.1.6",      /* Default File Server - Not currently Used */
        "",
        "192.168.1.7",      /* Default Name Server */
        "",
        0xffffff00UL        /* Default Subnet Mask */
        };

void ra_init();

int bootp_tries=2;

extern  int init_ether(struct BootInfo *bootinfo, int dodhcp);

void netconfig( void )
{
	// the default IP in IPWorks is 10.1.3.252/255.0.0.0 !!!
	// enable DHCP for more control
    init_ether( &Bootrecord, TRUE);
}

void receiver_thread();
void tcp_start();

extern Webpage webconf[];

// status of transmission
char tcp_active;
extern char tcp_host[];
extern char tcp_port[];
extern int hReceiver;

/*--
 * initialization of the Serial 2 TCP gateway
 * 
 * at the beginning the serial thread will be started
 * but the TCP activity is down. The TCP transmission
 * must first be enabled from the HTML control page.
 * Moreover the host address must be submitted.
 */
void s2t_init()
{
    tcp_active  = 0;
    tcp_host[0] = 0;
    tcp_port[0] = 0;
    hReceiver = SYSERR;
}



void con_init();
void xprintf();

/*--
 * main entry of the Serial 2 TCP gateway
 */
int main( void )
{
    con_init();
    xprintf("\nSerial Driver Demo\n");
    // init the application
    s2t_init();

    // run remote access services
    ra_init();
    xprintf("\nRemote Access IP: ");
    xprintf(Bootrecord. myip);

    // install and activate the COM driver
    //com_init();

    xprintf("\nrecv thread start\n");
    // start the receiver thread test
    resume( create((procptr)receiver_thread, 1024, 30, "com receiver", 0, 0) );

    xprintf("\ntcp start\n");
    // start the tcp module
    tcp_start();

	// start the configuration webserver
	http_init(http_defmethods, httpdefheaders, webconf, 80);
}

