/*
 * recv_test.c
 * 
 * receiver test - get keyboard input on COM2
 * creates a packet from every line entered ending with LF
 * and put packets in the queue from every five chars received
 * 
 * 13.12.2002 16:34
 * 
 * 12.01.02 methods created to separate TCP layer from any
 * serial driver implementations...
 */

#include <kernel.h>
#include <stdlib.h>
#include <tty.h>

#include "gw_conf.h"

//void xprintf(char *);
//#define kprintf xprintf

// packet queue. Packets are added at tail, pqt.
// Packets are removed from head, pqh.
struct mblock *pqh, *pqt;
int pqsize;

int init_receiver( );
int read_data( int receiver, char *buffer, int max_size );

/*
void xprintf(char* x);
#define kprintf xprintf
*/

extern struct devsw comdev;

typedef struct pkt
{
    char P[6];
    long len;
} packet_structure;

int compute_int(int int_value, unsigned char c)
{
    c -= '0';
    if( c > 9 )
        c -= 7;
    int_value <<= 4;
    int_value += c;
    return int_value;
}

int hReceiver;

/*--
 * testing receive thread using IPWorks com drivers
 */
void receiver_thread( )
{
int sz, bs;
char msg[128];
struct mblock *packetdata = 0;
char *packetbfr;

    // init queue
    pqh = pqt = NULL;
    pqsize = 0;

    // open serial device
    //open(SERIAL1, 0,0);
  
    /*
    hReceiver = init_receiver( 0 );
    if( hReceiver == SYSERR )
    {
        kprintf("\nReceiver COM open failed");
        return ;
    }
    else
        kprintf("\nserial port opened");
     */
          
    while( hReceiver == SYSERR )
        sleep(1);

    while( 1 )
    {
        if(packetdata != 0)
        {
            freemem( packetdata, PACKET_SIZE );
            kprintf("\n\tpacket discarded");
        }
        packetdata = (struct mblock *)getmem( PACKET_SIZE );
        memset( (void*)packetdata, 0, PACKET_SIZE);
        packetdata->mnext = NULL;
        packetdata->mlen  = PACKET_SIZE;
        // reach the contents skipping 6 bytes of the header
        packetbfr = (char*)(packetdata);
        packetbfr += 6;
        
        // block till read a number of chars
        // specific of reading from a TTY device is that the
        // read() blocks till a newline char is entered
        // so the buffer must be large enough
        // but the user input is limited by the size of the buffer!
        //original: sz = read( hReceiver, packetbfr, PACKET_SIZE-8);
        //
        // 16.02.2003 15:00 implementation may return 0 if no chars avaliable
        do{
            if( hReceiver == SYSERR )
                break;
            sz = read_data( hReceiver, packetbfr, PACKET_SIZE-8 );
            if( sz == 0 )
                sleep(1);
        }while( sz == 0 );

            if( hReceiver == SYSERR )
                break;

        //sz = read_data( hReceiver, packetbfr, PACKET_SIZE-8 );

        // serial packet is received
        
        // control the queue size
        // if full, remove the packet on the side of the head
        pqsize++;
        if( pqsize > 32 )
        {
            char *temp = (char *)pqh;
            pqh = pqh->mnext;
            freemem( (void*)temp, PACKET_SIZE );
            pqsize--;
        }

        // insert the prepared packet into the queue
        // on the side of the tail
        if( pqt == 0 )
        {
            pqh =
            pqt = packetdata;
        }
        else
        {
            pqt-> mnext = packetdata;
            pqt = packetdata;
        }
        pqt-> mnext = NULL;

        /* test message when putting packet to the queue
        sprintf((char*)msg, "\npqt = %x, %d total, %d chars; ", pqt, PACKET_SIZE, sz);
        sz = strlen(msg);
        msg[sz++] = packetbfr[0];
        msg[sz++] = packetbfr[1];
        msg[sz++] = packetbfr[2];
        msg[sz++] = packetbfr[3];
        msg[sz++] = 0;
        kprintf((char*)msg);
         */

        // packet is in the queue, free cycle handle
        packetdata = NULL;
    }    

    //close(hReceiver);
}
