/*
 * tcpsend.c
 * 
 * 26.08.2002 18:34 provide connection to the TCP host and
 * send the data from serial queue
 */

#include <kernel.h>
#include <stdlib.h>
#include <proc.h>
#include <network.h>
//#include <systypes.h>
//#include <tcpstat.h>
//#include <tcp.h>
//#include <tcb.h>

#include "gw_conf.h"

//#ifdef _EZ80L92
    #define _asm asm
//#endif

extern struct mblock *pqh, *pqt;
extern int pqsize;

int tx_cnt;

typedef struct pkt
{
    char P[6];
    long len;
} packet_structure;

void tcp_start();

extern int hReceiver;

/*--
 * the TCP reception thread
 */
int tcp_reading_thread(int tcp_connection)
{
int state, status;
struct tcpstat ts;
struct tcpstat  *pts;
char input[2];

    input[1] = 0;

    // check connection status
    pts = &ts;
    control( tcp_connection, TCPC_STATUS,
            (char*)pts, (char*)sizeof(ts));

    // monitor if the connection state changes
    if( state - (int)ts. ts_state )
    {
        state = ts. ts_state;
        kprintf("\nreading state: %x", state);
    }

// status:
// 5 = sending
// 8 = connection broken...

    while(1){
    // if enabled, do reading
    status =
        read ( tcp_connection, input, 1 );

    if( status == SYSERR )
        sleep(1);
    else
        write( hReceiver, input, 1);
        //kprintf(input);
    }
}


/*--
 * the TCP transmission thread
 */
int tcp_thread(int tcp_connection)
{
int count = 0;
int reading_thread;

    // create low priority reading thread
    reading_thread = create((procptr)tcp_reading_thread, 1024, 10, "reading", 1, tcp_connection);
    if( isbadpid(reading_thread) )
        kprintf("\nakov-!-bad reading_thread");
    else
        kprintf("\nreading_thread prepared");

    // the packet queue must be created by the serial thread
    // which continuously recepts packets, tcp thread must find
    // the queue allocation in the mem_list, we must provide
    // a function returning heap handle
    while( 1 )
    {
        char m[32];
        int status;
        packet_structure* ps;
        struct mblock *blk;

        // wait for packets prepared
        while( pqh == 0 )
        {
            resume( reading_thread );
            sleep10( 5 );
        }
        suspend( reading_thread );

        // look up packet
        // S2T packet
        //ps = (packet_structure*)(pqh + 2*sizeof(int));
        //sprintf(m, "\npkt %x,%d bytes", pqh, ps->len);
        // pick the packet from the head of the queue
        blk = (struct mblock *)pqh;
        //sprintf(m, "\npkt %x,%d bytes", pqh, blk->mlen);
        //kprintf(m);

        status =
            write( tcp_connection,
                (char*)blk, blk->mlen);

        if( status == SYSERR )
        {
            kprintf("\nakov-!-write: TCP connection broken");
            break;
        }
        else
            tx_cnt ++;



        // move head pointer, if it hits 0 then the process
        // will wait above for some time till queue is filled
        // again. Here we free the packet which was sent.
        {
        char *temp;
            _asm(" di");
            temp = (char*)pqh;
            pqh = pqh->mnext;
            if(pqh==0)
				pqt=(struct mblock *)0;
            _asm(" ei");
            pqsize--;
            freemem( (struct mblock *)temp, PACKET_SIZE);
        }
    }

    close(tcp_connection);

    // try to start again
    tcp_start();
}

extern char tcp_host[];
extern char tcp_port[];
 
SYSCALL tcp_process;
   
char check_ip(char *ip_string);

int tcp_connection;

/*--
 * the TCP channel init thread
 * 
 * the eZ80 tries to connect to the host to which it is supposed
 * to send the data received from the serial channel!
 * In case the operation has no success, the false value is
 * returned. Otherwise the function returns true
 */
unsigned char tcp_start( )
{
int itcp_port;
char serverAddr[24];

    tx_cnt = 0;

    if( !check_ip(tcp_host) )
    {
        kprintf("\nakov-!-tcp host is not defined");
        return FALSE;
    }

    itcp_port = atoi(tcp_port);
    // check that the port belongs to the range of user ports
    if( !((1024<itcp_port)&&(itcp_port<8192)) )
    {
        kprintf("\nakov-!-check tcp port value");
        return FALSE;
    }

    // try to open active connection
    // to the port defined in the request on the host PC
    kprintf("\nConnecting %s:%s\n", tcp_host, tcp_port);
    sprintf( serverAddr, "%s:%s", tcp_host, tcp_port);
    do
    {
        sleep( 3 );
        kprintf(".");
        tcp_connection = open( TCP, serverAddr, (char*)3301);
    }
    while( tcp_connection == SYSERR );

    //kprintf("\ntcp_open returned %d\n", tcp_connection);
    tcp_process = create((procptr)tcp_thread, 1024, 10, "tcp_thread", 1, tcp_connection);
    if( isbadpid(tcp_process) )
        kprintf("\nakov-!-bad tcp_thread");
    else
        kprintf("\ntcp_thread OK");

    return TRUE;
}

unsigned char tcp_connect( char * serverAddr)
{
    // try to open active connection
    // to the supplied host address
    kprintf("\nConnecting ");
    kprintf( serverAddr );
    do
    {
        sleep( 3 );
        kprintf(".");
        tcp_connection = open( TCP, serverAddr, (char*)3301);
    }
    while( tcp_connection == SYSERR );

    //kprintf("\ntcp_open returned %d\n", tcp_connection);
    tcp_process = create((procptr)tcp_thread, 1024, 10, "tcp_thread", 1, tcp_connection);
    if( isbadpid(tcp_process) )
        kprintf("\nakov-!-bad tcp_thread");
    else
        kprintf("\ntcp_thread OK");

    return TRUE;
}
