/*
 * config.c
 * 
 * Script to configure and control the status of the serial
 * to TCP gateway.
 * Keywords:
 * host=nnn.nnn.nnn.nnn: the address of the TCP host is submitted
 * port=NNNNN: the connection port is submitted
 * control=Start: the command to start the transmission
 * control=Stop: the command to stop the transmission to TCP
 * 
 * Script is not for online webpage update, internal firmware script!
 * 
 * 10.12.2002 21:40
 */

#include <stdlib.h>
#include <httpd.h>

extern int tx_cnt;
extern int pqsize;

extern const struct staticpage * control_html;
extern const struct staticpage * about_html;
extern const struct staticpage * serial_gif;

int config_cgi(struct http_request *request);
int status_cgi(struct http_request *request);

// the control website
Webpage webconf[] =
{
    {HTTP_PAGE_DYNAMIC, "/", "text/html", (void*)&config_cgi },
    {HTTP_PAGE_STATIC , "/control.html", "text/html", control_html },
    {HTTP_PAGE_STATIC , "/about.html", "text/html", about_html },
    {HTTP_PAGE_STATIC , "/serial.gif", "text/html", serial_gif },
    {HTTP_PAGE_DYNAMIC, "/cgi-bin/status", "text/html", (void*)&config_cgi },
};

char check_ip(char *ip_string)
{
char i, dots, digs;
    dots = 0;
    digs = 0;
    i=strlen(ip_string)-1;
    while( i >= 0)
    {
        if( '.' == ip_string[i] )
        {
            if(digs > 3)
                break;
            dots ++;
            digs = 0;
        }
        else
        if( ('0' <= ip_string[i]) && (ip_string[i] <= '9') )
            digs ++;
        else
            break;
        i--;
    }
    // debug the address recognition
    //kprintf("\ndigs = %d, dots = %d", digs, dots);
    if( (digs > 3) || (dots != 3) )
        dots = 0;
    return dots;
}

unsigned char tcp_start( );
void html_status( struct http_request *request, char stat );

extern char tcp_active;
extern SYSCALL tcp_process;

char tcp_host[16];
char tcp_port[6];

extern int tcp_connection;

/*--
 * the CGI script function
 * this script configures the Serial 2 TCP gateway:
 * it sets the tcp_host string which is the host where to send
 * TCP data to and the tcp_port, to which port to connect
 * 
 * the control command for the script tells wether to start,
 * to stop the server or just to set the parameters
 */
int config_cgi( struct http_request *request )
{
int count;
char *info, address[24], invalid_ip, invalid_port, *control;

    invalid_ip = 0;
    invalid_port = 0;

    control = http_find_argument( request, "control");
    if(control)

    if( !strcmp(control, "Stop") )
    {
        if( tcp_active )
        {
            tcp_active = 0;
            //suspend( tcp_process );
            kprintf("\nTCP stopped");
        }else{
            kprintf("\nTCP is idle");
        }
    }
    else
    {
        // parsing the host IP address
        info = http_find_argument( request, "host");
        if( !info )
            invalid_ip = 4;
        else
        if( check_ip(info) )
            strcpy(tcp_host, info);
        else
            invalid_ip = 1;

        // parsing the host connection port
        info = http_find_argument( request, "port");
        if( !info )
            invalid_ip = 4;
        else
        if( atoi(info) )
            strcpy(tcp_port, info);
        else
            invalid_port = 1;

        if( !strcmp(control, "Start") )
        {
            if( !tcp_active )
            {
                if( TRUE == tcp_start( ) )
                {
                    tcp_active = 1;
                    if( resume( tcp_process ) != SYSERR )
                        kprintf("\nTCP started");
                    else
                        kprintf("\nTCP process start failed");
                }
                else
                {
                    tcp_active = 0;
                    kprintf("\nTCP failed");
                }
            }else
            {
                kprintf("\nTCP already active");
            }
        }
    }

    // composing the status page
    html_status( request, invalid_ip + 2*invalid_port );
}

#define _httpw(string) strcpy( buffer, (string) ); \
    request->write( request->fd, buffer, strlen(buffer))

/*
 * status = invalid_ip + 2*invalid_port
 */
void html_status( struct http_request *request, char status )
{
char msg[16];
char buffer[256];
    _httpw( "<HTML><HEAD><TITLE>Serial to TCP/IP Gateway status page</TITLE><STYLE>" );
    _httpw( " p  {font: 10pt Verdana, Arial}" );
    _httpw( " td {font: 10pt Verdana, Arial}" );
    _httpw( " li {font: 10pt Verdana, Arial}" );
    _httpw( "</STYLE></HEAD><BODY><CENTER><h1>e<FONT COLOR=goldenrod>Z</FONT>80 Serial To TCP/IP Gateway</h1></CENTER>" );
    _httpw( "<TABLE ALIGN=right BGCOLOR=black cellpadding=4 BORDER=2 BORDERCOLOR=orange>" );
    _httpw( "<TD><CENTER><img src=\"../serial.gif\"><hr color=red width=250><font color=orange>ZiLOG Application Note</font><hr width=250 color=red><font color=red>Status</font>" );
    _httpw( " | <a href=\"../control.html\"><font color=orange>Config</font></a> | <a href=\"../about.html\"><font color=orange>About</font></a></font></CENTER></TD></TABLE>" );
    _httpw( "<table border=0><tr><th bgcolor=yellow>ZiLOG Application Note</th></tr><tr><td width=400 align=center><I>Transferring data from serial RS232 channel<br>to an Ethernet based TCP/IP</I></td></tr></table></TABLE>" );
    if( 0 == status & 0x0C )
    {
    if( status & 1 )
    {
        _httpw( "<p><font color=red>invalid IP address value</font>" );
    }
    if( status & 2 )
    {
        _httpw( "<p><font color=red>invalid port value</font>" );
    }
    }
    _httpw( "<table border=0>" );
    _httpw( "<tr><th colspan=2 width=400 bgcolor=yellow>Status Page</th></tr>" );
    _httpw( "<tr><td>TCP/IP Host address: </td><td>" );
    _httpw( tcp_host );
    _httpw( "</td></tr>" );
    _httpw( "<tr><td>Communication Port:  </td><td>" );
    _httpw( tcp_port );
    _httpw( "</td></tr>" );
    _httpw( "<tr><td>Connection Status:   </td><td>connected</td></tr>" );
    _httpw( "<tr><td>Input Status:        </td><td>suspended</td></tr>" );
    _httpw( "<tr><td>Transmission Status: </td><td>" );
    if( tcp_active )
    {
        _httpw( "active" );
    }else{
        _httpw( "suspended" );
	}
    _httpw( "</td></tr>" );
    sprintf( msg, "%d", pqsize );
    _httpw( "<tr><td>Messages in Serial input queue:</td><td>");
    _httpw( msg );
    _httpw( "</td></tr>" );
    sprintf( msg, "%d", tx_cnt );
    _httpw( "<tr><td>Frames Sent:</td><td>");
    _httpw( msg );
    _httpw( "</td></tr>" );
    _httpw( "</table>" );
    _httpw( "</BODY></HTML>" );
    
}
