/*
 @doc LCD_FLEX_HEADER
 @module LCD_flex.h |
 *
 * This header file provides predefined command words and operating modes
 * of the following, tested displays:<nl>
 *   - Optrex DMC 16249, 2x16 char dot LCD display module<nl>
 *   - Noritake CU16025ECPB-U5J, 2x16 char dot VFD display module<nl>
 *
 * If other or additional display command words shall be supported, the
 * corresponding enums in this file can be changed accordingly.<nl>
 *
 *	AUTHOR:<nl>	
 *				Ralf Ebert<nl>
 *				Mathias Loehr (Editor)<nl>
 *				ZiLOG Europe<nl>
 *				Thomas-Dehler Str. 18<nl>
 *				81737 Munich<nl>
 *				Germany<nl>
 *
 *	HISTORY:<nl>
 *	$Log: LCD_flex.h,v $
 *
 ********************************************************************
 @index type struct enum | LCD_FLEX_Header
 @normal Copyright (c) 2002 ZiLOG
 @end
 ********************************************************************
*/

#ifndef __LCD_flex_H__
#define __LCD_flex_H__

#ifdef	LCD_INTERNAL
#undef	__EXTERN
#define	__EXTERN
#else
#undef	__EXTERN
#define	__EXTERN	extern
#endif


/*--------- Include Files ---------*/

#include "stddefs.h"
#include <ez80.h>


/******************************************************************************
*
* For other controllers than eZ80190 you may have to write new delay functions.
* To make adaption easy, the delay functions are provided as Macros.
*
* Just exchange:     DelayMicroseconds(microseconds)
*                    DelayMilliseconds(milliseconds) 
*                    DelayMilliseconds10(milliseconds10)				
*                    DelayMilliseconds100(milliseconds100)
*
* with the name of your delay function and the library will work fine. 
******************************************************************************/  

#define DelayMicroseconds_Macro(microseconds) DelayMicroseconds(microseconds)
#define DelayMilliseconds_Macro(milliseconds) DelayMilliseconds(milliseconds)
#define DelayMilliseconds10_Macro(milliseconds10) DelayMilliseconds10(milliseconds10)
#define DelayMilliseconds100_Macro(milliseconds100) DelayMilliseconds100(milliseconds100)


/********************************************************************
*
* Bit and Port mask definitions.
*********************************************************************/  

#define BIT0	(U8) 0x01
#define BIT1	(U8) 0x02
#define BIT2	(U8) 0x04
#define BIT3	(U8) 0x08
#define BIT4	(U8) 0x10
#define BIT5	(U8) 0x20
#define BIT6	(U8) 0x40
#define BIT7	(U8) 0x80

#define PortA	1
#define PortB	2
#define PortC	3
#define PortD	4


/************************************************************************
* @enum LCD_HARDWARE_INTERFACE |	
* Options for display control modes.
************************************************************************/

typedef	enum
{
        I80 = 1,//@emem I80 display interface mode
        M68 = 3 //@emem M68 display interface mode
}LCD_HARDWARE_INTERFACE;


/************************************************************************
* @enum LCD_DOT_ARRAY |	
* Options for display dot array.
************************************************************************/

typedef	enum
{
        Array5_7 = 0,           //@emem 5*7 dot array.
        Array5_10 = BIT2        //@emem 5*10 dot array.
}LCD_DOT_ARRAY;


/************************************************************************
* @enum LCD_CURSOR_OPTION |	
* Options for cursor appearance.
************************************************************************/

typedef	enum
{
	LCDcursorOff = 0,					//@emem cursor off.
	LCDcursorOn = BIT1,				//@emem cursor on.
	LCDcursorBlinking = BIT0+BIT1 //@emem cursor blinking.
}LCD_CURSOR_OPTION;


/*******************************************************************
* The following table shows, how the LCD module on the Zilog Thermostat
* Demonstration Board is connected to the eZ80.
*
LCD module "Optrex DMC 16249" Pin connection

Pin 1	=	VSS		;GND
Pin 2	=	VDD 		;Power Supply
Pin 3 =  Vo       ;LCD Driver Supply Voltage

******************************************************************
Control lines:
******************************************************************

         I80   M68    I/O   ;signal description

Pin 4	=  RS =  RS   = PA3   ;Register Select: 0 = Instruction , 1 = Data
Pin 5	=  WR =  R/W  = PA1   ;Read/Write: 0 = Write to LCD , 1 = Read from LCD
Pin 6	=  RD =  E    = PA2   ;Enable, active high

******************************************************************
Data bus:
******************************************************************
	Pin 7		=	DB0		= not connected 	  
	Pin 8		=	DB1		= not connected	
	Pin 9		=	DB2		= not connected
	Pin 10	=	DB3		= not connected
	Pin 11	=	DB4		= PA4
	Pin 12	=	DB5		= PA5
	Pin 13	=	DB6		= PA6
	Pin 14	=	DB7		= PA7
******************************************************************

* If you want to connect your LCD module to another I/O Port,
* just change the port to signal assignments in lcd_conf.c and
* compile lcd_conf.c in your project.
*
* Below comments refer to a former version of the LCD driver,
* where you could assign the interface signals only within a
* single I/O port:
* If you wanted to use another I/O port there, you may have to
* rewrite the following functions:
*
* LCDwriteData(U8 LCDdata);
* LCDwriteLetter(U8 letter);
* LCDinstruction(U8 instruction);
*
* Macros for easy exchange with your new function names
******************************************************************/
#define LCDwriteData_Macro(LCDdata) LCDwriteData(LCDdata)
#define LCDreadData_Macro(LCDdata) LCDreadData(LCDdata)
#define LCDwriteControl_Macro(LCDdata) LCDwriteControl(LCDdata)

/*******************************************************************
* Change pin assignment definitions as your hardware requires.
******************************************************************/
#define	RS LCDControlLineConnection[0].PinForLine //@ Bitpostion in the LCD CONTROL Register
#define WR LCDControlLineConnection[1].PinForLine //@ Bitpostion in the LCD CONTROL Register
#define RD LCDControlLineConnection[2].PinForLine //@ Bitpostion in the LCD CONTROL Register
#define RW LCDControlLineConnection[1].PinForLine //@ Bitpostion in the LCD CONTROL Register
#define E LCDControlLineConnection[2].PinForLine //@ Bitpostion in the LCD CONTROL Register

#define	LCD_DATA_BIT0	BIT0 //@ Bitpostion in PORT_FOR_LCD_DATA_BIT0
#define	LCD_DATA_BIT1	BIT1 //@ Bitpostion in PORT_FOR_LCD_DATA
#define	LCD_DATA_BIT2	BIT2 //@ Bitpostion in PORT_FOR_LCD_DATA
#define	LCD_DATA_BIT3	BIT3 //@ Bitpostion in PORT_FOR_LCD_DATA
#define	LCD_DATA_BIT4	BIT4 //@ Bitpostion in PORT_FOR_LCD_DATA
#define	LCD_DATA_BIT5	BIT5 //@ Bitpostion in PORT_FOR_LCD_DATA
#define	LCD_DATA_BIT6	BIT6 //@ Bitpostion in PORT_FOR_LCD_DATA
#define	LCD_DATA_BIT7	BIT7 //@ Bitpostion in PORT_FOR_LCD_DATA
#define LCD_DATA_BIT1_TO_BIT7 (~(BIT0)) //@ Bitpostions in PORT_FOR_LCD_DATA_BIT1_TO_BIT7

#define	PORT_FOR_LCD_DATA	PA_DR	//@ Register for the data[DB1-7] you want to send to the LCD
#define	LCD_CONTROL	PA_DR	//@ Register for the control lines of the LCD	


/*******************************************************************
* The following Defines are the command words for the display module.
* You may compare them with your display module specification, if using
* a different module than the tested ones.
******************************************************************/

/*******************************************************************
* Check the display RAM buffer addresses with your module spec 
******************************************************************/

#define LCD_DDRAM_LINE_1  0x80 //@ address of the first display line
#define LCD_DDRAM_LINE_2  0xC0 //@ address of the second display line
#define LCD_DDRAM_LINE_3  0	//@ for this LCD the lines are not used
#define LCD_DDRAM_LINE_4  0	//@ for this LCD the lines are not used  
#define LCD_DDRAM_LINE_5  0	//@ for this LCD the lines are not used
#define LCD_DDRAM_LINE_6  0	//@ for this LCD the lines are not used  
#define LCD_DDRAM_LINE_7  0	//@ for this LCD the lines are not used
#define LCD_DDRAM_LINE_8  0	//@ for this LCD the lines are not used  

/*******************************************************************
* Check the display command words with your module spec
******************************************************************/
#define FUNCTION_SET BIT5+BIT3 //@ init LCD for 2 lines, 8-bit interface and 5*7 dot array
#define DISPLAY_OFF	BIT3 //@ turns off the LCD 
#define DISPLAY_ON	BIT2+BIT3	//@ turns on the LCD 
#define DISPLAY_CLEAR	BIT0	//@ clears the whole display
#define ENTRY_MODE	BIT1+BIT2	//@ cursor move increment, no display shift
#define FULL_BRIGHT	0 //@ adjust the brightness of the display 
#define HALF_BRIGHT	BIT1 //@ adjust the brightness of the display 
#define QUARTER_BRIGHT	BIT1+BIT0 //@ adjust the brightness of the display 
#define CURSOR_HOME	BIT1 //@ moves the cursor to the first position in the first line
#define CURSOR_SHIFT_RIGHT	BIT2+BIT4 //@ moves the cursor to the first position in the first line
#define CURSOR_SHIFT_LEFT	BIT4 //@ moves the cursor to the first position in the first line
#define DISPLAY_SHIFT_RIGHT	BIT2+BIT3+BIT4 //@ moves the cursor to the first position in the first line
#define DISPLAY_SHIFT_LEFT	BIT3+BIT4 //@ moves the cursor to the first position in the first line



/*************************************************************************
 * @enum LCD_LINE |	
 * LCD line definition.
 ************************************************************************/
 typedef	enum
{
	Line_1 = 0x80,		//@emem line 1 of the display.
	Line_2 = 0xC0,		//@emem line 2 of the display.
	Line_All = 1		//@emem all lines of the display.
}LCD_LINE;


/*************************************************************************
 * @enum LCD_WRITE_MODE |	
 * LCD text display mode definition.<nl> 
 ************************************************************************/
typedef enum
{
	TextStandard = 0,	//@emem standard mode.
	ScrollingText		//@emem scrolling mode, not supported.
}LCD_WRITE_MODE;


/*************************************************************************
 * @enum LCD_CONTROL_MODE |	<nl>
 * LCD control mode definitions.<nl> 
 ************************************************************************/
typedef enum
{
	ClearDisplay = 0,	//@emem command word for clearing the whole display.
	ClearLine,			//@emem command word for clearing a selected line.
	CursorHome,			//@emem command word for moving the cursor home.
	CursorShiftRight, //@emem command word for shifting the cursor one position to the right.
	CursorShiftLeft,	//@emem command word for shifting the cursor one position to the left.
	DisplayShiftRight,//@emem command word for incrementing the address of the display window in the buffer.
	DisplayShiftLeft, //@emem command word for decrementing the address of the display window in the buffer.
	TextShiftRight,	//@emem command word for moving the text in the buffer one address up.
	TextShiftLeft,		//@emem command word for moving the text in the buffer one address down.
	SetCGRAM,			//@emem command word for setting the address counter in CG RAM.
	SetDDRAM,			//@emem command word for setting the address counter in DD RAM.
	ReadBusyFlag		//@emem command word for reading the Busy flag.
}LCD_CONTROL_MODE;



/******************************************************************** 
 * @struct TypeLCDLineConfig| 
 * This structure defines the I/O pins used for the display.
 ********************************************************************/
typedef struct
{
	U8					PortForLine;			//@field  port of the used interface line.
	U8					PinForLine;				//@field  bit position of the used interface line.
}TypeLCDLineConfig;


/*******************************************************************
 * @type pTypeLCDLineConfig |
 * Defines a pointer to the structure <t TypeLCDLineConfig>.
 *******************************************************************/
typedef TypeLCDLineConfig *pTypeLCDLineConfig;


/*************************************************************************
 * @enum INTERRUPT_MODE |	
 * Interrrupt mode definition. The eZ80 offers five interrupt modes.
 ************************************************************************/
typedef enum
{
	FallingEdge = 0,	//@emem interrupt input falling edge triggered.
	RisingEdge = 0,	//@emem interrupt input rising edge triggered.
	DualEdge = 0,	//@emem interrupt input both edges triggered.
	ActiveHigh = 1,	//@emem interrupt input high level sensitive.
	ActiveLow = 1		//@emem interrupt input low level sensitive.
}INTERRUPT_MODE;


/**************************************************************************** 
 * @struct TypeInterruptLine| 
 * This structure defines the interrupt pins & modes used by the application.
  ***************************************************************************/
typedef struct
{
	U8					PortForLine;			//@field  port of the used interface line.
	U8					PinForLine;				//@field  bit position of the used interface line.
	INTERRUPT_MODE		InterruptMode;		//@field  mode of the used interrupt.
}TypeInterruptLine;


/*******************************************************************
 * @type pTypeInterruptLine |
 * Defines a pointer to the structure <t TypeInterruptLine>.
 *******************************************************************/
typedef TypeInterruptLine *pTypeInterruptLine;



/*----- External Data ----------------------*/
__EXTERN LCD_HARDWARE_INTERFACE LCDhardwareInterfaceG;

__EXTERN U8 NumberOfCharactersPerLineG;
__EXTERN U8 NumberOfLCDlinesG;
__EXTERN U8 LCDbuffer[8*16]; // adapt size to display buffer size
// make small to save RAM, but then dont call ReadLCDbuffer.



/*----- Internal Data --- ------------------*/
/*----- Puplic Data ------------------------*/


/*----- Internal Function ------------------------*/


void PortMaskInit(void);
void PortInit(void);
void PRT5init_1ms(void);
void LCDinit(LCD_HARDWARE_INTERFACE LCDhardwareInterface,
			 LCD_DOT_ARRAY LCDdotArray,
			 U8 NumberOfLCDlines,
			 U8 NumberOfCharactersPerLine,
			 LCD_CURSOR_OPTION LCDcursorOption);
void LCDwriteControl(U8 LCDcontrol);
void LCDwriteData(U8 LCDdata);
void LCDwriteLetter(U8 letter);
void LCDinstruction(U8 instruction);
U8 LCDreadData(void);
U8 LCDreadLetter(void);
void LCDI80interface1(U8 RegisterSelect,
					  U8 UsedLine,
					  U8 WasteLine);
void LCDI80interface2(U8 RegisterSelect,
					  U8 UsedLine,
					  U8 WasteLine);

void LCDM68interface1(U8 RegisterSelect,
					  U8 ReadWrite);
void LCDM68interface2(U8 RegisterSelect,
					  U8 ReadWrite);


void LCDwriteString(LCD_WRITE_MODE mode,
					LCD_LINE line,
					U8 position,
					U8 *pstr,
					U8 StringLength);
void ControlLCD(LCD_CONTROL_MODE CommandWord,
				U8 Value);

void LCDlibaryShortDelay(void);
void DelayMilliseconds(U16 milliseconds);
void DelayMilliseconds10(U8 milliseconds10);
void DelayMilliseconds100(U8 milliseconds100);
U8  FindLCDline(U8 position);
U8 LCDlineAddress(U8 LCDlineNumber);
U8 ReadLCDbuffer(void);


/*----- External Function ------------------*/

#endif

