/*
 @doc HEADERSERVERAPI
 @module SERVERAPI.H |
 *
 *	Header file for the 'ServerAPI.c' module. In this file the global function
 *	table will be defined.
 *	
 *
 @index type struct enum | HEADERSERVERAPI
 @normal Copyright (c) 2001 ZiLOG, Inc
 @end
*/

#include "stddefs.h"

#include <kernel.h>
#include <http.h>


#ifndef __SERVERAPI_H__
#define __SERVERAPI_H__

struct mblock* getheaphandle();

/******************************************************************** 
 * @struct TypeAPIfunctionTable | 
 * This structure contains all function pointers supported in the basic
 * IPWorks Server implementation. A web page application can call the
 * API functions using this function table. API functions are all
 * system functions, library functions, driver functions and so on.
 * A table from that type allows to call any functions from
 * a separatelly linked module. Only the table address must be known.
 * For example, when you want to call the 'abs' library function from
 * a CGI fucntion, just call this function listed below:<nl>
 * <nl>
 * pft->abs(-1234);
 * <nl>
 * As you can see, just put 'pft->' in front of the original function.
 * The function table pointer 'pft' and all necessary steps to make
 * the separated CGI functions compilable and linkable will be auto-
 * matically generated by the IPWorks Client software.
 ********************************************************************/
typedef struct APIfunctionTable_tag
{
// kernel general purpose functions
    int     (*getpid)  ( );
    int     (*create)  ( procptr procaddr, int ssize, int priority, char* name, int nargs, int args);
    int     (*resume)  (int pid);
    int     (*suspend) (int pid); 
    int     (*chprio)  (int pid, int priority);
    int     (*getprio) (int pid); 
    int     (*kill)    (int pid); 
    int     (*sleep)   (int n); 
    int     (*sleep10) (int n);
    int     (*sleep100)(int n); 
    int     (*unsleep) (int pid); 
    int     (*open)    (int descrp, char *name, char *mode); 
    int     (*close)   (int descrp); 
    int     (*control) (int descrp, int func, char *arg1, char *arg2) ;
    int     (*read)    (int descrp, char* buff, int count); 
    int     (*write)   (int descrp, char* buff, int count); 
    int     (*getc)    (int descrp); 
    int     (*putc)    (int descrp, char ch);
//  int     (*openClient) (int descrp, char *remote_port, int local_port); 
//  int     (*readXgram) (int descrp, struct xgram *data_from, int length); 
//  int     (*writeXgram) (int descrp, struct xgram *data_to, int length); 

// XINU messaging
    #ifdef ipw147
    int     (*send)    (int pid, msg_t msg); 
    msg_t   (*receive) (void); 
    int     (*pcreate) (int count); 
    int     (*pdelete) (int portid, int     (*dispose)(int *)); 
    msg_t   (*preceive)(int portid); 
    int     (*psend)   (int portid, msg_t message); 
    int     (*psendu)  (int portid, msg_t message); 
    #else
    int     (*send)    (int pid, WORD msg); 
    int     (*receive) (void); 
    int     (*pcreate) (int count); 
    int     (*pdelete) (int portid, int     (*dispose)(int *)); 
    int     (*preceive)(int portid); 
    int     (*psend)   (int portid, WORD message); 
    int     (*psendu)  (int portid, WORD message); 
    #endif
// ports and semaphores
    int     (*pcount)  (int portid); 
    int     (*preset)  (int portid, int     (*dispose)(int *)); 
    int     (*scount)  (int semaphore); 
    int     (*screate) (int count); 
    int     (*sdelete) (int semaphore); 
    int     (*signal)  (int semaphore); 
    int     (*signaln) (int semaphore, int count); 
    int     (*sreset)  (int semaphore, int count); 
    int     (*wait)    (int semaphore); 

    int     (*kprintf) (char *fmt, ... );

    int     (*abs)     (int arg);
    int     (*ascdate) (long time, char* str); 
#ifdef FP_API
    double  (*atof)    (char *str); 
    char*   (*ecvt)    (double arg, int ndigits, int* decpt, int* sign); 
    char*   (*fcvt)    (double arg, int ndigits, int* decpt, int* sign); 
#endif
    int     (*atoi)    (char *str); 
    long    (*atol)    (char *str); 
    void    (*bzero)   (char *buffer, int length); 
    char*   (*fgets)   (int descriptor, char *buff, int maxlen); 
    int     (*fprintf) (int descriptor, char *format, ...); 
    int     (*fputs)   (int descriptor, char *str); 
    int     (*freemem) (struct mblock *block, WORD size);
    WORD*   (*getmem)  (unsigned nbytes);
    struct mblock* (*getheaphandle)();
    char*   (*gets)    (char *buff); 
    void    (*memset)  (char *buffer, char *value, int length); 
    int     (*printf)  (char *format, ...); 
    int     (*puts)    (char *str); 
    void    (*qsort)   (char *base, int num, int size, int (*compare)(char *, char*)); 
    void    (*srand)   (unsigned int seed); 
    int     (*rand)    (void); 
    char*   (*rindex)  (char *str, char c); 
    int     (*scanf)   (char *format, ...); 
    int     (*fscanf)  (int descriptor, char *format, ...); 
    int     (*sscanf)  (char *buffer, char *format, ...); 
    int     (*sprintf) (char *buffer, char *format, ...); 
    int     (*strcasecmp)(char *str1, char *str2); 
    char*   (*strcat)  (char *str1, char *str2); 
    int     (*strcmp)  (char *str1, char *str2); 
    char*   (*strcpy)  (char *outstr, char *instr); 
    int     (*strlen)  (char *str); 
    char*   (*strncat) (char *str1, char *str2, int num); 
    int     (*strncmp) (char *str1, char *str2, int num); 
    char*   (*strncpy) (char *outstr, char *instr, int num); 
    int     (*tolower) (char c); 
    int     (*toupper) (char c); 

    #ifdef ipw147
    int     (*http_init) (Http_Context *httpcontext,const Http_Method *methods,const struct header_rec *headers, Webpage *webpages,int port);
    #else
    int     (*http_init) (Http_Method* methods, struct header_rec* headers, struct webpage* webpages, int port); 
    #endif
    void    (*http_get)            (Http_Request* request); 
    void    (*http_post)           (Http_Request* request); 
    void    (*http_output_headers) (Http_Request* request); 
    int     (*http_get_header)     (Http_Request *request); 
    void    (*http_add_header)     (Http_Request* request, int header, char* value); 
    char*   (*http_find_argument)  (Http_Request* request, char* arg); 
    int     (*http_output_reply)   (Http_Request* request, int reply); 
    int     (*http_output_request) (Http_Request* request, int method, char* url); 
    void    (*http_request)        (Http_Request* request);

	/*
	 *************************************************************************
	 * Place here further function pointer definition which should be callable
	 * from external.
	 * Pay attention that you must insert the cooresponding function pointers
	 * in the global 'APIfunctionTable' in exactly the same order!
	 *************************************************************************
	 */

}TypeAPIfunctionTable;

/*******************************************************************
 * @type pTypeAPIfunctionTable |
 * Defines a pointer to the structure <t TypeAPIfunctionTable>.
 *******************************************************************/
typedef TypeAPIfunctionTable *pTypeAPIfunctionTable;

#endif	//__SERVERAPI_H__

pTypeAPIfunctionTable GetpAPIfunctionTable(void);
	

