/*
 @doc HEADERTARGET
 @module TARGET.H |
 *
 *	This file contains all relevant definitions which can be different on another
 *	target platform. This definitions are for the eZ80 evaluation board. When
 *	another target platform will be used instead of the eZ80 eval board this 
 *  values can/must be changed accordingly.
 *	
 @index type struct enum | HEADERTARGET
 @normal Copyright (c) 2001 ZiLOG, Inc
 @end
*/

#ifndef __TARGET_H__
#define __TARGET_H__
#include "stddefs.h"

/*--
 * This is the clock rate of the eZ80 processor. This value must be adjusted
 * according to the used oscillator. To ensure proper operation of the serial
 * interface - UART - this value must be accurate. MCLK will be used to 
 * calculate the time constants for the different baud rates.
 */
#ifdef	SCIA_MODULE
#define	MCLK	24000000	//SCIA uses only 24MHz
#else
#define MCLK	40000000	//We use a 40MHz osc
#endif	//SCIA_MODULE

/*--
 * @type pIIO |
 * Defines a pointer to a internal 8Bit I/O register.
 */
typedef volatile U8 __INTIO *pIIO;

// Boot information file default location
#define SA_BOOTINFO_FILE	0x4000
// Webpage Link List file default location
#define SA_WPLINKLIST_FILE  0x6000
// Webpage Contents default location
#define SA_WEBPAGE 0xA0000

/*
 * eZ80 Chip Select register definition. For each Chip Select the dedicated register
 * set is available.
*/
#define CS0 0xA8
#define CS1 0xAB
#define CS2 0xAE
#define CS3 0xB1

#ifndef _EZ80L92
#define	CSLBR(q)		(((pIIO)(q + 0))[0])
#define	CSUBR(q)		(((pIIO)(q + 1))[0])
#define	CSCTL(q)		(((pIIO)(q + 2))[0])
#endif

/*
 * This defines the Base Address of the Flash memory. We need this address in 
 * order to access the flash physically. We will use the programmed value of the
 * corresponding CS LBR register. It depends on the CS what flash (in the case of 
 * more than 1) will be actually accessed.
 */
/*
 * This defines the CS configuration of the used HW platform. 
 */
#ifdef	EZ80EB_REV_C	//Crystal Board
#define	FLASH1_CS	CS0
#define FLASH2_CS	CS0
#define RAM1_CS		CS1
#define RAM2_CS		CS2
#define EMAC_CS		CS3
#else					//Realtek Board
#define	FLASH1_CS	CS0
#define FLASH2_CS	CS3
#define RAM1_CS		CS1
#define RAM2_CS		CS1
#define EMAC_CS		CS2
#endif	//EZ80EB_REV_C

#endif	//__TARGET_H__
