/*
 @doc HEADERWPLINKLIST
 @module WPLINKLIST.H |
 *******************************************************************************
 *
 *	Header file for the 'WpLinklist.c' source file. This file contains all 
 *	structures, types and prototypes for the configuration module. 			<nl>
 *	
 *******************************************************************************
 @index type struct enum | HEADERWPLINKLIST
 @normal Copyright (c) 2001 ZiLOG, Inc
 @end
 *******************************************************************************
*/

#ifndef __WPLINKLIST_H__
#define __WPLINKLIST_H__
#include "stddefs.h"
#include "Target.h"

/*
 *****************************************************************************
 * Defines a valid Link List information block.
 ****************************************************************************
 */
#define		WPLL_VALID		0x1234		//indicates that the flash file is valid

/*
 *****************************************************************************
 * Defines the start value for the 32bit Check Sum.
 ****************************************************************************
 */
//#define MAGIC     0x00AFFE00

/******************************************************************** 
 * @struct TypeWpLinkList | 
 * Structure for the Webapge Link List Header. This header will be add
 * in front of the real website link list according to IPWorks. The
 * Client tool (JClient, WClient) will create this header before sending
 * a new link list the this server. Furthermore, this header will be used
 * for webpage management within the client tool.<nl>
 * The link list header has a fixed size of 64 bytes, but not all location
 * are in use at this time.
 ********************************************************************/
typedef struct WpLinkList_tag
{
    U16     valid;      //@field Indicates whether or not the file is valid.
    U32     defSALinkList;  //@field Default start address of the Link List.
    U32     defSAWebpage;   //@field Default start address of the Webpage Image.

    U32     llSA;       //@field Current Link List Start address.
    U32     llEA;       //@field Current Link List End Address.
    U32     llSize;     //@field Current Size of Link List.
	
    U32     wpSA;       //@field Current Webpage start address.
    U32     wpEA;       //@field Current Webpage end address.
    U32     wpSize;     //@field Current Webpage size.

    U32     CheckSum;       //@field 32 bit check sum
    U8      reserved[64-38]; //@field Reserved bytes.
}TypeWpLinkList;

/*******************************************************************
 * @type pTypeWpLinkList |
 * Defines a pointer to the structure <t TypeWpLinkList>.
 *******************************************************************/
typedef TypeWpLinkList *pTypeWpLinkList;

#endif //__WPLINKLIST_H__

/*
 ******************************************************************************************
 *	Function definition for intern and extern! The eZ80 C-Compiler will use this sequence
 *	to assign the address! Thus, the sequence of this prototypes must be the same like in
 *	the C-module. This is needed for copying all functions into RAM when using the flash
 *	loader as resifent boot loader!
 ******************************************************************************************
 */
 //this function are from ServConfig module
extern U32 CalcCRC(U32 SA, U32 EA);

__REFERENCE__ BOOL ReadWpLinkList(U32 FA, U8 *pDest);	
__REFERENCE__ BOOL WriteWpLinkList(pTypeWpLinkList pHead);



