/*
 @doc HEADERTYPEDEFS
 @module TYPEDEFS.H |
 ********************************************************************
 *
 *	This file contains typedefs used for eZ80 projects. When using 
 *	redefined TYPES based on the compiler types, the software can
 *	easier be ported to another platform.<nl>
 *	When changing the compiler or platform, only the here defined 
 *	types need to be changed.<nl>
 *	
 ********************************************************************
 @index type struct enum | HEADERTYPEDEFS
 @normal Copyright (c) 2001 ZiLOG, Inc
 @end
 ********************************************************************
*/

#ifndef __TYPEDEFS_H__
#define __TYPEDEFS_H__

//When using the eZ80 evaluation Board Rev. C, the data bus to the flash
//memory is in the reverse order. Thus, when wriiting or reading data to/from
//flash memory, the byte value must be reversed.
#ifdef EZ80EB_REV_C
#define REVERSE_DB
#endif //EZ80EB_REV_C

#ifdef ZDS_II
#define di()    asm("\tdi");
#define ei()    asm("\tei");
#else
//extern void _asm(char *);
/*
 ****************************************************************************
 * defines Disable Interrupt and Enable Interrupt macros
 ****************************************************************************
 */
#ifndef di
#define	di()	_asm("\tdi");
#endif
#ifndef ei
#define	ei()	_asm("\tei");
#endif
#endif

/*******************************************************************
 * @type UCHAR |
 * Type definition of unsigned character. Variables from that type
 * contain 8 Bits.
 *******************************************************************/
typedef	unsigned char		UCHAR;

/*******************************************************************
 * @type USHORT |
 * Type definition of unsigned short. Variables from that type
 * contain 16 Bits.
 *******************************************************************/
typedef	unsigned short		USHORT;

/*******************************************************************
 * @type UINT16 |
 * Type definition of unsigned short int. Variables from that type
 * contain 16 Bits.
 *******************************************************************/
typedef unsigned short		UINT16;			//16Bit unsigned int

/*******************************************************************
 * @type UINT24 |
 * Type definition of unsigned int. Variables from that type
 * contain 24 Bits.
 *******************************************************************/
typedef unsigned int		UINT24;			//24Bit unsigned int

/*******************************************************************
 * @type UINT32 |
 * Type definition of unsigned int. Variables from that type
 * contain 32 Bits.
 *******************************************************************/
typedef	unsigned long		UINT32;			//32 bit unsigned int

/*******************************************************************
 * @type ULONG |
 * Type definition of unsigned long. Variables from that type
 * contain 32 Bits.
 *******************************************************************/
typedef	unsigned long		ULONG;			//32 bit unsigned long

#ifndef	xinu
/*******************************************************************
 * @type CHAR |
 * Type definition of signed character. Variables from that type
 * contain 8 Bits.
 *******************************************************************/
//typedef	char				CHAR;			//8 bit signed
#endif

/*******************************************************************
 * @type SHORT |
 * Type definition of signed short. Variables from that type
 * contain 16 Bits.
 *******************************************************************/
typedef	short				SHORT;			//16 bit signed 

/*******************************************************************
 * @type INT16 |
 * Type definition of signed short int. Variables from that type
 * contain 16 Bits.
 *******************************************************************/
typedef	short				INT16;			//16 bit signed int

/*******************************************************************
 * @type INT24 |
 * Type definition of signed int. Variables from that type
 * contain 24 Bits.
 *******************************************************************/
typedef	int				    INT24;			//24 bit signed int

/*******************************************************************
 * @type INT32 |
 * Type definition of signed int. Variables from that type
 * contain 32 Bits.
 *******************************************************************/
typedef long				INT32;			//32 bit signed int

/*******************************************************************
 * @type LONG |
 * Type definition of signed long. Variables from that type
 * contain 32 Bits.
 *******************************************************************/
typedef	long				LONG;			//32 bit signed

/*******************************************************************
 * @type FLOAT |
 * Type definition of float. Variables from that type
 * contain 32 Bits.
 *******************************************************************/
typedef float				FLOAT;

/*******************************************************************
 * @type DOUBLE |
 * Type definition double. Variables from that type
 * contain 64 Bits.
 *******************************************************************/
typedef double				DOUBLE;

/*******************************************************************
 * @type BYTE |
 * Type definition of byte. Variables from that type
 * contain 8 Bits.
 *******************************************************************/

#ifndef _EZ80L92
#ifndef _EZ80F91
typedef	UCHAR				BYTE;

//#ifndef _KERNEL_H_
/*******************************************************************
 * @type WORD |
 * Type definition of word. Variables from that type
 * contain 16 Bits.
 * Required by the v1.5 again.
 * 
 * 31.10.2002 12:37 AKOV: WORD is defined in kernel.h in 1.3.2
 * Decision: remove the definition
 *******************************************************************/
//typedef    USHORT              WORD;
//#endif

/*******************************************************************
 * @type DWORD |
 * Type definition of double word. Variables from that type
 * contain 32 Bits.
 *******************************************************************/
typedef ULONG				DWORD;
#endif
#endif

/*******************************************************************
 * @type BOOL |
 * Type definition of bool. Variables from that type
 * contain 8 Bits as boolean (TRUE or FALSE).
 *******************************************************************/
typedef	UCHAR				BOOL;			//8 bit

/*******************************************************************
 * @type S8 |
 * Type definition for a signed 8 bit variable.
 *******************************************************************/
typedef	char				S8;

/*******************************************************************
 * @type S16 |
 * Type definition for a signed 16 bit variable.
 *******************************************************************/
typedef	SHORT				S16;

/*******************************************************************
 * @type S16 |
 * Type definition for a signed 24 bit variable.
 *******************************************************************/
typedef	INT24 				S24;

/*******************************************************************
 * @type S32 |
 * Type definition for a signed 32 bit variable.
 *******************************************************************/
typedef	LONG				S32;

/*******************************************************************
 * @type U8 |
 * Type definition for a unsigned 8 bit variable.
 *******************************************************************/
typedef UCHAR				U8;

/*******************************************************************
 * @type U16 |
 * Type definition for a unsigned 16 bit variable.
 *******************************************************************/
typedef	USHORT				U16;

/*******************************************************************
 * @type U24 |
 * Type definition for a unsigned 16 bit variable.
 *******************************************************************/
typedef	UINT24				U24;

/*******************************************************************
 * @type U32 |
 * Type definition for a unsigned 32 bit variable.
 *******************************************************************/
typedef	ULONG				U32;

#ifndef	TRUE
#define	TRUE	1
#endif 	//TRUE

#ifndef	FALSE
#define	FALSE	0
#endif	//FALSE

#ifndef	NULL
#define NULL	0
#endif	//NULL

#endif	//__TYPEDEFS_H__
