/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
/* arpinit.c - arpinit */

#include <conf.h>
#include <kernel.h>
#include <proc.h>
#include <network.h>

/** @name arp_conf.c
 * @memo Configure adress resolution protocol resources.
 * @doc This file contains tunable elements that affect the ARP driver. The size of
 * the ARP table can be adjusted here.
 *
 * In general, the number of entries should be approximately the same as the
 * number of simultaneous connection that will be expected. If an excessive
 * number of ARP requests are seen on the network, try increasing the size of
 * this table.
 *
 * Note that if the ARP table it made too small, performance will be impacted.
 */
/*@{*/
/**
 * @doc An entry is required in `#arptable[]#' for each network host that this
 * system will be communicating with at any given time. Entries are reused, so
 * the table only has to have enough entries to handle the number of active
 * concurrent connections that are expected.
 */

struct	arpentry	arptable[5];

/**
 * @doc The size of the ARP table is contained in ARP_TSIZE. This variable
 * should be treated as Read-Only, and it's declaration in arp_conf.c should
 * not be changed.
 */

/* Don't modify this declaration of ARP_TSIZE */
const int ARP_TSIZE=sizeof(arptable)/sizeof(struct  arpentry);

/*@}*/
