/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#include <conf.h>
#include <kernel.h>
#include <proc.h>
#include <network.h>

/** @name emac_conf.c
 * @memo Configure physcial network address.
 * @doc On the eZ80 Evaluation Platform, the unique MAC address for each board
 * is stored in Flash memory. The default configuration attempts to get
 * the MAC from flash, but will fill in a non-unique default if the flash memory
 * hasn't been configured.
 */
/*@{*/

/** 
 * @memo Default physical network address.
 @doc This is a default MAC address that will be used if all else fails.
 */
unsigned char defmacaddr[EP_ALEN] = {0x00,0x90,0x23,0x00,0x00,0x00};


/**
 * @memo Get ethernet physical address.
@doc This function Determines the MAC address for the system, and places it in
the location specified by it's parameter.
@param eaddr is a pointer to the location in which it place the MAC address.
 */
void
get_etheraddr(Eaddr *eaddr)
{
//unsigned char *flptr=(unsigned char *)0x3FFA;
unsigned char *				flptr=p_mac_addr;


/* Look in the flash memory to see if a MAC address is present */
if( flptr[0] == 0xFF && flptr[1] == 0xFF && flptr[2] == 0xFF &&
    flptr[3] == 0xFF && flptr[4] == 0xFF && flptr[5] == 0xFF ) {
	/*  No MAC set in flash, use the default */
	flptr=defmacaddr;
	}

blkcopy(eaddr,flptr,EP_ALEN);
}
/*@}*/
