/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#include <conf.h>
#include <kernel.h>
#include <sleep.h>
#include <network.h>

/** @name ip_conf.c
 * @memo Configure internet protocol resources.
 * @doc This file contains tunable elements that affect the IP driver. The size of
 * the routing table can be adjusted here.
 *
 * Each network interface will require 2 entries, and the default route also
 * requires an entry. On complex network topologies, additional routes may
 * be added by the ICMP driver, or by some routing protocol.
 *
 * Note that if the routing table is too small, portions of the network may
 * become unreachable from this system. Please use caution when adjusting
 * the size of the routing table, and make sure you have a good understanding
 * of IP routing.
 */
/*@{*/
/**
 * @doc `#rttable[]#' is a hash table for the routine table. For large
 * complex networks, this can make route look ups more efficient. For smaller
 * networks, only a couple of entries are required.
 */

struct	route * rttable[4];

/**
 * @doc The size of the Route table is contained in RT_TSIZE. This variable
 * should be treated as Read-Only, and it's declaration in ip_conf.c should
 * not be changed.
 */

/* Don't modify this declaration of RT_TSIZE */
int RT_TSIZE = sizeof(rttable)/sizeof(struct route *);

/**
 * @doc An entry in the routing table must exist for each subnet that may be
 * learned by this system. In addition, a certain number of entries are also
 * required to hold the default route, and routes associated with each network
 * interface. `#RT_BPSIZE#' is the total number of entries in the routing table.
 */

/* Don't modify this declaration of RT_TSIZE */
int RT_BPSIZE = 100;

/*@}*/
