/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#include <conf.h>
#include <kernel.h>
#include <bootinfo.h>
#include <network.h>
#include <stdlib.h>

/*------------------------------------------------------------------------
 *  netconfig - set network configuration parms using BOOTP
 *------------------------------------------------------------------------
 */
/** @doc
 * @memo Contol the DHCP server discovery timeout.
 * @doc
 * The bootp_tries variable declared in netconfig.c controls the amount of
 * time the system will spend looking for a DHCP server.  The initial wait
 * time is 4 seconds.  If no response is found within 4 seconds, the next
 * attempt will wait 8 seconds, then 16, then 32, etc.,  until "bootp_tries" 
 * attempts have been made.  So, if bootp_tries is set to 1, the system will 
 * wait 4 seconds for a DHCP response, and will use the BootRecord information 
 * if no reply is detected in that timeframe.  If boot_tries is set to 2, the 
 * system will wait a total of 12 (4 + 8) seconds for a DHCP response.  On a 
 * busy network, it is recommended that bootp_tries be set to 5.
 */
int bootp_tries=2;

/** @doc 
 * @memo Optional user callback for network configuration.
 * @doc This function is called as part of the network configuration. It provides
 * a place to change the information in the BootRecord before the network
 * is configured, using that information.
 *
 * The default configuration of this function attempts to use DHCP to obtain
 * and IP address on the local network. If a DHCP server is not located, the
 * address found in the BootRecord will be used. If a DHCP server is found,
 * then the information obtained from that server will be placed in the
 * BootRecord.
 *
 * Other decisions about how the network is configured may be placed here also.
 */
void netconfig()
{
    init_ether(&Bootrecord, b_use_dhcp);

    return;
}
