/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#include <kernel.h>
#include <network.h>
#include <ppp.h>
#include <modem.h>

/**
 * @name ppp_conf.c
 * @memo Defaul PPP Configurations
 * @doc These are default settings used by PPP. This file should be included
 * in a project, and modified as needed.
 */

/*@{*/
/**
 * @name authpairs
 * @doc This array contains ID/password pairs to be used to authenticate
 * peer connections.
 */
/*@{*/
/*@}*/

struct authpair peerauthpairs[] = {
	{"ez80", "ppp"},
	{"zlgusr", "zlgpwd"}
};

int	numpeerauthpairs = sizeof(peerauthpairs) / sizeof(struct authpair);


/**
 * @doc This table contains the chat script needed to connect to a MS Windows
 * system which is acting as the host using DCC.
 */

struct modemchat dccclientchat[] = {
	{"CLIENTCLIENT",NULL},
	{NULL,"CLIENTSERVER"},
	};

int ndccclientchat = sizeof(dccclientchat)/sizeof(struct modemchat);


/**
 * @doc This table contains the chat script needed to connect to a MS Windows
 * system which is acting as the guest using DCC.
 */

struct modemchat dcchostchat[] = {
	{NULL,"CLIENT"},
	{"CLIENTSERVER",NULL},
	};

int ndcchostchat = sizeof(dcchostchat)/sizeof(struct modemchat);


/**
 * @doc This table contains the chat script needed to accept a connection
 * via a modem.
 */
struct modemchat modemchat[] = {
	{"ATE&F&K3&S1\r","OK"},
	{NULL, "RING"},
	{"ATA\r","CONNECT"},
	{NULL, "\r\n"},
	};

int nmodemchat = sizeof(modemchat)/sizeof(struct modemchat);

/**
 * @doc This table contains the chat script needed to connect with a modem.
 */

struct modemchat dialchat[] = {
	{"ATE&F&K3&S1\r","OK"},
	{"ATDT2526177\r","CONNECT"},
	{NULL, "\r\n"},
	};

int ndialchat = sizeof(dialchat)/sizeof(struct modemchat);

/**
 * @name ppp
 * @doc A default ppp configuration which is passed into ppp_init().
 */
/*@{*/
/*@}*/

struct pppconf ppp = 
{
	"192.168.2.1",		/* myaddress */
	"zilog",				/* myuserID */
	"demo",				/* mypassword */
	"192.168.2.2",		/* peeraddress */
	PPP_PAP,				/* peer authentication protocol */
	1500,					/* MRU */
	0xffffffffUL,		/* ACCM */
	3,						/* LCPTimer */
	10,					/* LCPMaxTimeouts */
	2,						/* LCPMaxTerminate */
	10,					/* LCPMaxConfigure */
	NULL,					/* offerSecondaryDNS */
	NULL,					/* offerPrimaryNBNS */
	NULL,					/* offerSecondaryNBNS */
	TRUE,					/* debug */
	DIALUP_SERVER,		/* default to DIALUP Server mode */
	0,						/* Don't Use Peer DNS in Server mode */
	1,						/* Routing enabled */
	0,						/* PPP is the default Route */
	0,						/* Manual reconnect */
	modemchat,			/* Default chat script for Dialup Server */
	4						/* Number of entries in modemchat script for Dialup Serevr */
};

/*@}*/
