/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#include <conf.h>
#include <kernel.h>
#include <proc.h>
#include <sem.h>

/** @name sys_conf.c
 * @memo Tune Operating System Parameters.
 * @doc This file contains tunable elements of the Operating System portion
 * of IPworks. The size of some of the system table can be adjusted here.
 *
 * Note: If some of these tables are configured too small, IPworks will not
 * function. Tuning should be done in small increments while testing in
 * and environment that closely simulates the expected target environment.
 */
/*@{*/
/**
 * @doc An entry is required in `#proctab[]#' for each task executing
 * under IPworks.
 *
 * Note that IPworks itself requires 10-15 entries, depending on the actual
 * configuration.
 */

struct	pentry	proctab[25];

/**
 * @doc The number of process is contained in NPROC. This variable
 * should be treated as Read-Only, and it's declaration in sys_conf.c should
 * not be changed.
 */

/* Don't modify this declaration of NPROC */
int NPROC = sizeof(proctab)/sizeof(struct pentry);

/**
 * @doc This table is the number of semaphores that may exist. Semaphores
 * are used by many different parts of IPworks, so be careful when reducing
 * the size of this table.
 */

struct	sentry	semaph[100];

/**
 * @doc The number of semaphores is contained in NSEM. This variable
 * should be treated as Read-Only, and it's declaration in sys_conf.c should
 * not be changed.
 */

/* Don't modify this declaration of NSEM */
int NSEM = sizeof(semaph)/sizeof(struct sentry);

/*@}*/
