#include <kernel.h>



/*
 * ==============================================================
 * HW Configuration for eZ80190 Evaluation Board with CS8900A NIC
 * ==============================================================
 */
#ifdef EVB_190_CS

const CS_CONFIG_S					cs_config[MAX_CHIP_SELECTS] =
{
	{0x00, 0x0F, CSCTL_4_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
	{0x10, 0x17, CSCTL_1_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
	{0x18, 0x1F, CSCTL_1_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
	{0x30, 0x30, CSCTL_7_WAIT_STATES | CSCTL_IO_ACCESS 	 | CSCTL_ENABLE_CS}
};

const RAM_BLOCK_S					ram_blocks[] =
{
	{ 0x100000, 0x1FFFFF },
	{0,0}
};

BYTE *								p_mac_addr = (BYTE *) 0x003FFA;

/*
 * GPIO Map for 190 Eval Board with CS8900A:
 *
 *		Port A	
 *			PA0..PA7		All GPIOs are available to the user,
 *							(Default setting =    Mode 2, Input)
 *		Port B
 *			PB0..PB7		All GPIOs are available to the user,
 *							(Default setting =    Mode 2, Input)
 *		Port C
 *			PC0			Modem (Uart 1) TxD,   Mode 7, Alternate Function
 *			PC1			Modem (Uart 1) RxD,   Mode 7, Alternate Function
 *			PC2			Modem (Uart 1) RTS,   Mode 7, Alternate Function
 *			PC3			Modem (Uart 1) CTS,   Mode 7, Alternate Function
 *			PC4			Modem (Uart 1) DTR,   Mode 7, Alternate Function
 *			PC5			Modem (Uart 1) DSR,   Mode 7, Alternate Function
 *			PC6			Modem (Uart 1) DCD,   Mode 7, Alternate Function
 *			PC7			Modem (Uart 1) RI,    Mode 7, Alternate Function
 *		Port D
 *			PD0			Console (Uart 0) TxD, Mode 7, Alternate Function
 *			PD1			Console (Uart 0) RxD, Mode 7, Alternate Function
 *			PD2			<<< Not Used >>>,     Mode 2, Input				
 *			PD3			<<< Not Used >>>,     Mode 2, Input				
 *			PD4			CS8900A IRQ Line,     Mode 8, IRQ, actie high 	(not used)
 *			PD5			<<< Not Used >>>,     Mode 2, Input
 *			PD6			CS8900A LANLED Line,  Mode 2, Input 				(not used)
 *			PD7			CS8900A SLEEP Line,   Mode 1, Output = 1			(not used)
 */
const GPIO_CONFIG_S				GPIO_config[ MAX_GPIO_PORTS ] =
{
//	DR		 DDR   ALT1	 ALT2		
	{0xFF, 0xFF, 0x00, 0x00},		// Settings for Port A
	{0xFF, 0xFF, 0x00, 0x00},		// Settings for Port B
	{0x00, 0xFF, 0x00, 0xFF},		// Settings for Port C
	{0xFC, 0xEF, 0x10, 0x13}		// Settings for Port D
};
#endif



/*
 * ===============================================================
 * HW Configuration for eZ80190 Evaluation Board with RT8019AS NIC
 * ===============================================================
 */
#ifdef EVB_190_RT

const CS_CONFIG_S					cs_config[MAX_CHIP_SELECTS] =
{
	{0x00, 0x0F, CSCTL_4_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
	{0x40, 0x4F, CSCTL_1_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
	{0x32, 0x32, CSCTL_0_WAIT_STATES | CSCTL_IO_ACCESS 	 | CSCTL_ENABLE_CS},
	{0x00, 0x00, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_DISABLE_CS}
};

const RAM_BLOCK_S					ram_blocks[] =
{
	{ 0x400000, 0x4FFFFF },
	{0,0}
};

BYTE *								p_mac_addr = (BYTE *) 0x003FFA;

/*
 * GPIO Map for 190 Eval Board with CS8900A:
 *
 *		Port A
 * 		PA0			Realtek IRQ Line	    Mode 8, active high	
 *			PA1..PA7		GPIOs available to the user,
 *							(Default setting =    Mode 2, Input)
 *		Port B
 *			PB0..PB7		All GPIOs are available to the user,
 *							(Default setting =    Mode 2, Input)
 *		Port C
 *			PC0			Modem (Uart 1) TxD,   Mode 7, Alternate Function
 *			PC1			Modem (Uart 1) RxD,   Mode 7, Alternate Function
 *			PC2			Modem (Uart 1) RTS,   Mode 7, Alternate Function
 *			PC3			Modem (Uart 1) CTS,   Mode 7, Alternate Function
 *			PC4			Modem (Uart 1) DTR,   Mode 7, Alternate Function
 *			PC5			Modem (Uart 1) DSR,   Mode 7, Alternate Function
 *			PC6			Modem (Uart 1) DCD,   Mode 7, Alternate Function
 *			PC7			Modem (Uart 1) RI,    Mode 7, Alternate Function
 *		Port D
 *			PD0			Console (Uart 0) TxD, Mode 7, Alternate Function
 *			PD1			Console (Uart 0) RxD, Mode 7, Alternate Function
 *			PD2			<<< Not Used >>>,     Mode 2, Input				
 *			PD3			<<< Not Used >>>,     Mode 2, Input				
 *			PD3			<<< Not Used >>>,     Mode 2, Input				
 *			PD5			<<< Not Used >>>,     Mode 2, Input
 *			PD6			CS8900A LANLED Line,  Mode 2, Input 				(not used)
 *			PD7			CS8900A SLEEP Line,   Mode 1, Output = 1			(not used)
 */
const GPIO_CONFIG_S					GPIO_config[ MAX_GPIO_PORTS ] =
{
//	DR		 DDR   ALT1	 ALT2		
	{0xFF, 0xFE, 0x01, 0x01},		// Settings for Port A
	{0xFF, 0xFF, 0x00, 0x00},		// Settings for Port B
	{0x00, 0xFF, 0x00, 0xFF},		// Settings for Port C
	{0xFC, 0xFF, 0x00, 0x03}		// Settings for Port D
};

#endif



/*
 * ==============================================================
 * HW Configuration for eZ80L92 Evaluation Board with CS8900A NIC
 * ==============================================================
 */
#ifdef EVB_L92_CS

#ifdef RAM_MAP
	const CS_CONFIG_S				cs_config[MAX_CHIP_SELECTS] =
	{
		{0xF0, 0xFF, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x00, 0x07, CSCTL_1_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x80, 0xBF, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x03, 0x03, CSCTL_0_WAIT_STATES |     CSCTL_IO_ACCESS | CSCTL_ENABLE_CS}
	};
	const RAM_BLOCK_S				ram_blocks[] =
	{
		{ 0x000000, 0x07FFFF },
		{ 0xB80000, 0xBFFFFF },
		{0,0}
	};
	BYTE *							p_mac_addr        = (BYTE *) 0xF03FFA;
#else
	const CS_CONFIG_S				cs_config[MAX_CHIP_SELECTS] =
	{
		{0x00, 0x0F, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0xC0, 0xC7, CSCTL_1_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x80, 0xBF, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x03, 0x03, CSCTL_0_WAIT_STATES |     CSCTL_IO_ACCESS | CSCTL_ENABLE_CS}
	};
	const RAM_BLOCK_S				ram_blocks[] =
	{
		{ 0xC00000, 0xC7FFFF },
		{0,0}
	};
	BYTE *							p_mac_addr        = (BYTE *) 0x003FFA;
#endif

const BYTE							cs_bus_mode[MAX_CHIP_SELECTS] =
{
	CSBM_CTL_INTEL_MODE | CSBM_CTL_2_EZ80_CLOCKS,
	CSBM_CTL_EZ80_MODE  | CSBM_CTL_1_EZ80_CLOCKS,
	CSBM_CTL_INTEL_MODE | CSBM_CTL_1_EZ80_CLOCKS,
	CSBM_CTL_INTEL_MODE | CSBM_CTL_4_EZ80_CLOCKS
};

/*
 * GPIO Map for L92 Eval Board with CS8900A:
 *
 *		Port A	
 *			PA0..PA7		Not Present
 *		Port B
 *			PB0..PB7		All GPIOs are available to the user,
 *							(Default setting = Mode 2, Input)
 *							Note: Push Button Switches 1..3 are connected to PB0..2
 *		Port C
 *			PC0			Modem (Uart 1) TxD, Mode 7, Alternate Function
 *			PC1			Modem (Uart 1) RxD, Mode 7, Alternate Function
 *			PC2			Modem (Uart 1) RTS, Mode 7, Alternate Function
 *			PC3			Modem (Uart 1) CTS, Mode 7, Alternate Function
 *			PC4			Modem (Uart 1) DTR, Mode 7, Alternate Function
 *			PC5			Modem (Uart 1) DSR, Mode 7, Alternate Function
 *			PC6			Modem (Uart 1) DCD, Mode 7, Alternate Function
 *			PC7			Modem (Uart 1) RI,  Mode 7, Alternate Function
 *		Port D
 *			PD0			Console (Uart 0) TxD, Mode 7, Alternate Function
 *			PD1			Console (Uart 0) RxD, Mode 7, Alternate Function
 *			PD2			Console (Uart 0) RTS, Mode 7, Alternate Function
 *			PD3			Console (Uart 0) CTS, Mode 7, Alternate Function
 *			PD4			CS8900A IRQ Line, 	 Mode 8, Interrupt actie high
 *			PD5			- available for user, Mode 2, Input
 *			PD6			CS8900A /LANLED Line, Mode 2, Input	   	(not used)
 *			PD7			CS8900A /SLEEP Line,  Mode 1, Output = 1	(not used)
 */

const GPIO_CONFIG_S				GPIO_config[ MAX_GPIO_PORTS ] =
{
//	DR		 DDR   ALT1	 ALT2		
	{0xFF, 0xFF, 0x00, 0x00},		// Settings for Port B
	{0x00, 0xFF, 0x00, 0xFF},		// Settings for Port C
	{0xF0, 0x6F, 0x10, 0x1F}		// Settings for Port D
};
#endif


/*
 * ==============================================================
 * HW Configuration for eZ80F92 Evaluation Board with CS8900A NIC
 * ==============================================================
 */
#ifdef EVB_F92_CS

#ifdef RAM_MAP
	const CS_CONFIG_S				cs_config[MAX_CHIP_SELECTS] =
	{
		{0xF0, 0xFF, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x00, 0x07, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x80, 0xBF, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x03, 0x03, CSCTL_0_WAIT_STATES |     CSCTL_IO_ACCESS | CSCTL_ENABLE_CS}
	};
	const RAM_BLOCK_S				ram_blocks[] =
	{
		{ 0x000000, 0x07FFFF },
		{ 0xB80000, 0xBFFFFF },
		{0,0}
	};
	BYTE *							p_mac_addr = (BYTE *) 0xF03FFA;
#else
	const CS_CONFIG_S				cs_config[MAX_CHIP_SELECTS] =
	{
		{0x00, 0x0F, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0xC0, 0xC7, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x80, 0xBF, CSCTL_0_WAIT_STATES | CSCTL_MEMORY_ACCESS | CSCTL_ENABLE_CS},
		{0x03, 0x03, CSCTL_0_WAIT_STATES |     CSCTL_IO_ACCESS | CSCTL_ENABLE_CS}
	};
	const RAM_BLOCK_S				ram_blocks[] =
	{
		{ 0xC00000, 0xC7FFFF },
		{0,0}
	};
	BYTE *							p_mac_addr = (BYTE *) 0x003FFA;
#endif

const BYTE							cs_bus_mode[MAX_CHIP_SELECTS] =
{
	CSBM_CTL_INTEL_MODE | CSBM_CTL_1_EZ80_CLOCKS,
	CSBM_CTL_EZ80_MODE  | CSBM_CTL_1_EZ80_CLOCKS,
	CSBM_CTL_EZ80_MODE  | CSBM_CTL_1_EZ80_CLOCKS,
	CSBM_CTL_INTEL_MODE | CSBM_CTL_2_EZ80_CLOCKS
};

/*
 * GPIO Map for F92 Eval Board with CS8900A:
 *
 *		Port A	
 *			PA0..PA7		Not Present
 *		Port B
 *			PB0..PB7		All GPIOs are available to the user,
 *							(Default setting = Mode 2, Input)
 *							Note: Push Button Switches 1..3 are connected to PB0..2
 *		Port C
 *			PC0			Modem (Uart 1) TxD, Mode 7, Alternate Function
 *			PC1			Modem (Uart 1) RxD, Mode 7, Alternate Function
 *			PC2			Modem (Uart 1) RTS, Mode 7, Alternate Function
 *			PC3			Modem (Uart 1) CTS, Mode 7, Alternate Function
 *			PC4			Modem (Uart 1) DTR, Mode 7, Alternate Function
 *			PC5			Modem (Uart 1) DSR, Mode 7, Alternate Function
 *			PC6			Modem (Uart 1) DCD, Mode 7, Alternate Function
 *			PC7			Modem (Uart 1) RI,  Mode 7, Alternate Function
 *		Port D
 *			PD0			Console (Uart 0) TxD, Mode 7, Alternate Function
 *			PD1			Console (Uart 0) RxD, Mode 7, Alternate Function
 *			PD2			Console (Uart 0) RTS, Mode 7, Alternate Function
 *			PD3			Console (Uart 0) CTS, Mode 7, Alternate Function
 *			PD4			CS8900A IRQ Line, 	 Mode 8, Interrupt actie high
 *			PD5			- available for user, Mode 2, Input
 *			PD6			CS8900A /LANLED Line, Mode 2, Input	   	(not used)
 *			PD7			CS8900A /SLEEP Line,  Mode 1, Output = 1	(not used)
 */

const GPIO_CONFIG_S				GPIO_config[ MAX_GPIO_PORTS ] =
{
//	DR		 DDR   ALT1	 ALT2		
	{0xFF, 0xFF, 0x00, 0x00},		// Settings for Port B
	{0x00, 0xFF, 0x00, 0xFF},		// Settings for Port C
	{0xF0, 0x6F, 0x10, 0x1F}		// Settings for Port D
};
#endif




