#ifndef _EZ80_H_
#define _EZ80_H_

#ifdef _EZ80L92
	#include "ez80l92.h"
#endif
#ifdef _EZ80F92
	#include "ez80f92.h"
#endif
#ifdef _EZ80190
	#include "ez80190.h"
#endif

/*
 * Pointer type definitions for the eZ80 Compiler to access I/O.
 * Note that all IO devices are internal.  However, some of the macros below 
 * use the __EXTIO keyword.  These macros are intended to be used with a 
 * variable that holds the base address of the peripheral.  This allows the 
 * same code fragment to operate on identical peripherals located at different 
 * places in the IO map.  For example, if your code neede to write the value 
 * 0x11 to either UART_THR0 or UART_THR1 depending on the value of a variable,
 * and that variable contained the base address of which UART to use, you could
 * either write:
 *
 *			if( uart_base == UART0 )
 *			{
 *				UART_THR0 = 0x11;
 *			}
 *			else
 *			{
 *				UART_THR1 = 0x11;
 *			}
 *
 * Or you could use the base-indexed macro like this:
 *			UART_THR(uart_base) = 0x11;
 *
 * However you must not use a constant with the base-index macros.  For example,
 * 	UART_THR( UART0 ) = 0x11; 
 * will produce unpredictable results.
 */
typedef volatile unsigned char __INTIO *			IORegInt8;
typedef volatile unsigned char __EXTIO *			IORegExt8;
typedef volatile unsigned short int __INTIO *	IORegInt16;
typedef volatile unsigned short int __EXTIO *	IORegExt16;


/* Timer 0 */
#define TMR_CTL0					(*(IORegInt8)0x80)
#define TMR_DRL0					(*(IORegInt8)0x81)
#define TMR_DRH0					(*(IORegInt8)0x82)
#define TMR_RRL0					(*(IORegInt8)0x81)
#define TMR_RRH0					(*(IORegInt8)0x82)

/* Timer 1 */
#define TMR_CTL1					(*(IORegInt8)0x83)
#define TMR_DRL1					(*(IORegInt8)0x84)
#define TMR_DRH1					(*(IORegInt8)0x85)
#define TMR_RRL1					(*(IORegInt8)0x84)
#define TMR_RRH1					(*(IORegInt8)0x85)

/* Timer 2 */
#define TMR_CTL2					(*(IORegInt8)0x86)
#define TMR_DRL2					(*(IORegInt8)0x87)
#define TMR_DRH2					(*(IORegInt8)0x88)
#define TMR_RRL2					(*(IORegInt8)0x87)
#define TMR_RRH2					(*(IORegInt8)0x88)

/* Timer 3 */
#define TMR_CTL3					(*(IORegInt8)0x89)
#define TMR_DRL3					(*(IORegInt8)0x8A)
#define TMR_DRH3					(*(IORegInt8)0x8B)
#define TMR_RRL3					(*(IORegInt8)0x8A)
#define TMR_RRH3					(*(IORegInt8)0x8B)

/* Timer 4 */
#define TMR_CTL4					(*(IORegInt8)0x8C)
#define TMR_DRL4					(*(IORegInt8)0x8D)
#define TMR_DRH4					(*(IORegInt8)0x8E)
#define TMR_RRL4					(*(IORegInt8)0x8D)
#define TMR_RRH4					(*(IORegInt8)0x8E)

/* Timer 5 */
#define TMR_CTL5					(*(IORegInt8)0x8F)
#define TMR_DRL5					(*(IORegInt8)0x90)
#define TMR_DRH5					(*(IORegInt8)0x91)
#define TMR_RRL5					(*(IORegInt8)0x90)
#define TMR_RRH5					(*(IORegInt8)0x91)

#define TMR0						0x80
#define TMR1						0x83
#define TMR2						0x86
#define TMR3						0x89
#define TMR4						0x8C
#define TMR5						0x8F
#define TMR_CTL(base)			(*((IORegExt8)(base+0)))
#define TMR_DRL(base)			(*((IORegExt8)(base+1)))
#define TMR_DRH(base)			(*((IORegExt8)(base+2)))
#define TMR_RRL(base)			(*((IORegExt8)(base+1)))
#define TMR_RRH(base)			(*((IORegExt8)(base+2)))



/* Watch Dog Timer */
#define WDT_CTL					(*(IORegInt8)0x93)
#define WDT_RR						(*(IORegInt8)0x94)



/* GPIO */
#define PB_DR						(*(IORegInt8)0x9A)
#define PB_DDR						(*(IORegInt8)0x9B)
#define PB_ALT1					(*(IORegInt8)0x9C)
#define PB_ALT2					(*(IORegInt8)0x9D)

#define PC_DR						(*(IORegInt8)0x9E)
#define PC_DDR						(*(IORegInt8)0x9F)
#define PC_ALT1					(*(IORegInt8)0xA0)
#define PC_ALT2					(*(IORegInt8)0xA1)

#define PD_DR						(*(IORegInt8)0xA2)
#define PD_DDR						(*(IORegInt8)0xA3)
#define PD_ALT1					(*(IORegInt8)0xA4)
#define PD_ALT2					(*(IORegInt8)0xA5)



/* Chip Select */
#define CS_LBR0					(*(IORegInt8)0xA8)
#define CS_UBR0					(*(IORegInt8)0xA9)
#define CS_CTL0					(*(IORegInt8)0xAA)
#define CS_LBR1					(*(IORegInt8)0xAB)
#define CS_UBR1					(*(IORegInt8)0xAC)
#define CS_CTL1					(*(IORegInt8)0xAD)
#define CS_LBR2					(*(IORegInt8)0xAE)
#define CS_UBR2					(*(IORegInt8)0xAF)
#define CS_CTL2					(*(IORegInt8)0xB0)
#define CS_LBR3					(*(IORegInt8)0xB1)
#define CS_UBR3					(*(IORegInt8)0xB2)
#define CS_CTL3					(*(IORegInt8)0xB3)

#define CS0							0xA8
#define CS1							0xAB
#define CS2							0xAE
#define CS3							0xB1
#define CS_LBR(base)				(*((IORegInt8)(base+0)))
#define CS_UBR(base)				(*((IORegInt8)(base+1)))
#define CS_CTL(base)				(*((IORegInt8)(base+2)))



/* eZ80 Common Peripheral devices */
#define UART0						0xC0
#define UART1						0xD0
#define I2C0						0xC8

#define SPI_CTL(base)			(*((IORegExt8)(base+0)))
#define SPI_SR(base)				(*((IORegExt8)(base+1)))
#define SPI_RBR(base)			(*((IORegExt8)(base+2)))
#define SPI_TSR(base)			(*((IORegExt8)(base+2)))

#define UART_RBR(base)			(*((IORegExt8)(base+0)))
#define UART_THR(base)			(*((IORegExt8)(base+0)))
#define BRG_DLRL(base)			(*((IORegExt8)(base+0)))
#define BRG_DLRH(base)			(*((IORegExt8)(base+1)))
#define UART_IER(base)			(*((IORegExt8)(base+1)))
#define UART_IIR(base)			(*((IORegExt8)(base+2)))
#define UART_FCTL(base)			(*((IORegExt8)(base+2)))
#define UART_LCTL(base)			(*((IORegExt8)(base+3)))
#define UART_MCTL(base)			(*((IORegExt8)(base+4)))
#define UART_LSR(base)			(*((IORegExt8)(base+5)))
#define UART_MSR(base)			(*((IORegExt8)(base+6)))
#define UART_SPR(base)			(*((IORegExt8)(base+7)))

#define I2C_SAR(base)			(*((IORegExt8)(base+0)))
#define I2C_xSAR(base)			(*((IORegExt8)(base+1)))
#define I2C_DR(base)				(*((IORegExt8)(base+2)))
#define I2C_CTL(base)			(*((IORegExt8)(base+3)))
#define I2C_SR(base)				(*((IORegExt8)(base+4)))
#define I2C_CCR(base)			(*((IORegExt8)(base+4)))
#define I2C_SRR(base)			(*((IORegExt8)(base+5)))

/* Non-Index Uart registers */
#define	UART_BRGL0				(*(IORegInt8)0xC0)
#define	UART_BRGH0				(*(IORegInt8)0xC1)
#define	UART_RBR0				(*(IORegInt8)0xC0)
#define	UART_THR0				(*(IORegInt8)0xC0)
#define	UART_IER0				(*(IORegInt8)0xC1)
#define	UART_IIR0				(*(IORegInt8)0xC2)
#define	UART_FCTL0				(*(IORegInt8)0xC2)
#define	UART_LCTL0				(*(IORegInt8)0xC3)
#define	UART_MCTL0				(*(IORegInt8)0xC4)
#define	UART_LSR0				(*(IORegInt8)0xC5)
#define	UART_MSR0				(*(IORegInt8)0xC6)
#define	UART_SPR0				(*(IORegInt8)0xC7)

#define	UART_BRGL1				(*(IORegInt8)0xD0)
#define	UART_BRGH1				(*(IORegInt8)0xD1)
#define	UART_RBR1				(*(IORegInt8)0xD0)
#define	UART_THR1				(*(IORegInt8)0xD0)
#define	UART_IER1				(*(IORegInt8)0xD1)
#define	UART_IIR1				(*(IORegInt8)0xD2)
#define	UART_FCTL1				(*(IORegInt8)0xD2)
#define	UART_LCTL1				(*(IORegInt8)0xD3)
#define	UART_MCTL1				(*(IORegInt8)0xD4)
#define	UART_LSR1				(*(IORegInt8)0xD5)
#define	UART_MSR1				(*(IORegInt8)0xD6)
#define	UART_SPR1				(*(IORegInt8)0xD7)



/*
 * Timer Control Register bit definitions
 * Note, PRT operation is slightly different for 190 and L92.
 * Inparticular different clock divisors are used and the L92
 * can count external events and/or toggle GPIO pins.
 */
#define TCR_PRT_IRQ				0x80
#define TCR_IRQ_EN				0x40
#define TCR_PRT_MODE				0x10
#define TCR_CLKDIV_MASK 		0x0C
#define TCR_RST_EN				0x02
#define TCR_PRT_EN				0x01



/*
 * Chip select Control Register bit definitions
 */
#define CSCTL_WAIT_STATE_MASK	0xE0
#define CSCTL_7_WAIT_STATES	0xE0
#define CSCTL_6_WAIT_STATES	0xC0
#define CSCTL_5_WAIT_STATES	0xA0
#define CSCTL_4_WAIT_STATES	0x80
#define CSCTL_3_WAIT_STATES	0x60
#define CSCTL_2_WAIT_STATES	0x40
#define CSCTL_1_WAIT_STATES	0x20
#define CSCTL_0_WAIT_STATES	0x00
#define CSCTL_MEMORY_ACCESS	0x00

#define CSCTL_IO_ACCESS			0x10
#define CSCTL_ENABLE_CS			0x08
#define CSCTL_DISABLE_CS		0x00



/* UART_IER bits */
#define IER_MIIE					0x08
#define IER_LSIE					0x04
#define IER_TIE					0x02
#define IER_RIE					0x01


/* UART_IIR bits */
#define IIR_FIFOEN				0xC0
#define IIR_ISCMASK				0x0E
#define IIR_RLS					0x06
#define IIR_RDR					0x04
#define IIR_CTO					0x0C
#define IIR_TBE					0x02
#define IIR_MS						0x00
#define IIR_INTBIT				0x01


/* UART_FCTL bits */
#define FCTL_TRIGMASK			0x00
#define FCTL_TRIG_1				0x00
#define FCTL_TRIG_4				0x40
#define FCTL_TRIG_8				0x80
#define FCTL_TRIG_14				0xC0
#define FCTL_CLRTXF				0x04
#define FCTL_CLRRXF				0x02
#define FCTL_FIFOEN				0x01


/* UART_LCTL bits */
#define LCTL_DLAB					0x80
#define LCTL_SB					0x40 		/* Send Break */
#define LCTL_FPE					0x20 		/* Force Parity Error */
#define LCTL_EPS					0x10 		/* Even Parity */
#define LCTL_PEN					0x08 		/* Parity Enable */
#define LCTL_2STOPBITS			0x04
#define LCTL_5DATABITS			0x00
#define LCTL_6DATABITS			0x01
#define LCTL_7DATABITS			0x02
#define LCTL_8DATABITS			0x03


/* UART_MCTL bits */
#define MCTL_LOOP					0x10
#define MCTL_OUT2					0x08
#define MCTL_OUT1					0x04
#define MCTL_RTS					0x02
#define MCTL_DTR					0x01


/* UART_LSR bits */
#define LSR_ERR					0x80
#define LSR_TEMT					0x40
#define LSR_THRE					0x20
#define LSR_BI						0x10
#define LSR_FE						0x08
#define LSR_PE						0x04
#define LSR_OE						0x02
#define LSR_DR						0x01


/* UART_MSR bits */
#define MSR_DCD					0x80
#define MSR_RI						0x40
#define MSR_DSR					0x20
#define MSR_CTS					0x10
#define MSR_DDCD					0x08
#define MSR_TERI					0x04
#define MSR_DDSR					0x02
#define MSR_DCTS					0x01



/* WDT_CTL bits */
#define WDTCTL_EN					0x80
#define WDTCTL_NMI				0x40
#define WDCTL_RST_FLAG			0x20
#define WDTCTL_TWO18				0x03
#define WDTCTL_TWO22				0x02
#define WDTCTL_TWO25				0x01
#define WDTCTL_TWO27				0x00



/* WDT_RR bits */
#define WDTRR_RESET1				0xA5
#define WDTRR_RESET2				0x5A



#endif 