#ifndef _EZ80L92_H_
#define _EZ80L92_H_


/* Timer ISS */
#define TMR_ISS					(*(IORegInt8)0x92)

/* SPI */
#define SPI0						0xBA
/* SPI Baud Rate Generator */
#define SPI_BRG_L					(*(IORegInt8)0xB8)
#define SPI_BRG_H					(*(IORegInt8)0xB9)
/* SPI Registers */
#define SPI_CTL0 					(*(IORegInt8)0xBA)
#define SPI_SR0 					(*(IORegInt8)0xBB)
#define SPI_RBR0 					(*(IORegInt8)0xBC)
#define SPI_TSR0 					(*(IORegInt8)0xBC)

/* IR_CTL */
#define IR_CTL   					(*(IORegInt8)0xBF)

/* I2C */
#define	I2C_SAR0  				(*(IORegInt8)0xC8)
#define	I2C_XSAR0 				(*(IORegInt8)0xC9)
#define	I2C_DR0 					(*(IORegInt8)0xCA)
#define	I2C_CTL0					(*(IORegInt8)0xCB)
#define	I2C_SR0 					(*(IORegInt8)0xCC)
#define	I2C_CCR0					(*(IORegInt8)0xCC)
#define	I2C_SRR0					(*(IORegInt8)0xCD)

/* Low Power Control */
#define CLK_PPD1 					(*(IORegInt8)0xDB)
#define CLK_PPD2					(*(IORegInt8)0xDC)

/* Real Time Clock */
#define RTC_SEC  					(*(IORegInt8)0xE0)
#define RTC_MIN  					(*(IORegInt8)0xE1)
#define RTC_HRS  					(*(IORegInt8)0xE2)
#define RTC_DOW  					(*(IORegInt8)0xE3)
#define RTC_DOM  					(*(IORegInt8)0xE4)
#define RTC_MON  					(*(IORegInt8)0xE5)
#define RTC_YR   					(*(IORegInt8)0xE6)
#define RTC_CEN  					(*(IORegInt8)0xE7)
#define RTC_ASEC 					(*(IORegInt8)0xE8)
#define RTC_AMIN 					(*(IORegInt8)0xE9)
#define RTC_AHRS 					(*(IORegInt8)0xEA)
#define RTC_ADOW 					(*(IORegInt8)0xEB)
#define RTC_ACTRL					(*(IORegInt8)0xEC)
#define RTC_CTRL 					(*(IORegInt8)0xED)

/* Chip Select Bus Mode Control */
#define CS0_BMC  					(*(IORegInt8)0xF0)
#define CS1_BMC  					(*(IORegInt8)0xF1)
#define CS2_BMC  					(*(IORegInt8)0xF2)
#define CS3_BMC  					(*(IORegInt8)0xF3)


/*
 * Timer Control Register bit definitions
 */
#define TCR_BRK_STP				0x40
#define TCR_CLK_DIV4				0x00		
#define TCR_CLK_DIV16			0x04
#define TCR_CLK_DIV64			0x08
#define TCR_CLK_DIV256 			0x0C


/*
 * Timer Input Source Select Register.
 * Note that the outputs of Timer 4 and 5 can be used to toggle PB4 and PB5
 * when these GPIO pins are set for Alternate function.
 */
#define ISS_TMR3_SYS_CLK		0x00
#define ISS_TMR3_RTC     		0x40
#define ISS_TMR3_PB1     		0x80
#define ISS_TMR2_SYS_CLK		0x00
#define ISS_TMR2_RTC     		0x10
#define ISS_TMR2_PB0     		0x20
#define ISS_TMR1_SYS_CLK		0x00
#define ISS_TMR1_RTC     		0x04
#define ISS_TMR1_PB1     		0x08
#define ISS_TMR0_SYS_CLK		0x00
#define ISS_TMR0_RTC     		0x01
#define ISS_TMR0_PB1     		0x02

/* WDT_CTL bits */
#define WDTCTL_CLK_SYS			0x00
#define WDTCTL_CLK_RTC			0x08


/* CS Bus Mode Control bits */
#define CSBM_CTL_MASK						0xC0
#define CSBM_CTL_EZ80_MODE					0x00
#define CSBM_CTL_Z80_MODE					0x40
#define CSBM_CTL_INTEL_MODE				0x80
#define CSBM_CTL_MOTOROLA_MODE			0xC0
#define CSBM_CTL_AD_MUX						0x20
#define CSBM_CTL_EZ80_CLOCKS_MASK		0x0F
#define CSBM_CTL_1_EZ80_CLOCKS			0x01
#define CSBM_CTL_2_EZ80_CLOCKS			0x02
#define CSBM_CTL_3_EZ80_CLOCKS			0x03
#define CSBM_CTL_4_EZ80_CLOCKS			0x04
#define CSBM_CTL_5_EZ80_CLOCKS			0x05
#define CSBM_CTL_6_EZ80_CLOCKS			0x06
#define CSBM_CTL_7_EZ80_CLOCKS			0x07
#define CSBM_CTL_8_EZ80_CLOCKS			0x08
#define CSBM_CTL_9_EZ80_CLOCKS			0x09
#define CSBM_CTL_10_EZ80_CLOCKS			0x0A
#define CSBM_CTL_11_EZ80_CLOCKS			0x0B
#define CSBM_CTL_12_EZ80_CLOCKS			0x0C
#define CSBM_CTL_13_EZ80_CLOCKS			0x0D
#define CSBM_CTL_14_EZ80_CLOCKS			0x0E
#define CSBM_CTL_15_EZ80_CLOCKS			0x0F

/* Interrupt vector table offsets */
#define IV_RSV1					0x00
#define IV_RSV2					0x02
#define IV_RSV3					0x04
#define IV_RSV4					0x06
#define IV_RSV5					0x08
#define IV_TMR0					0x0A
#define IV_TMR1					0x0C
#define IV_TMR2					0x0E
#define IV_TMR3					0x10
#define IV_TMR4					0x12
#define IV_TMR5					0x14
#define IV_RTC						0x16
#define IV_UART0					0x18
#define IV_UART1					0x1A
#define IV_I2C						0x1C
#define IV_SPI						0x1E
#define IV_RSV6					0x20
#define IV_RSV7					0x22
#define IV_RSV8					0x24
#define IV_RSV9					0x26
#define IV_RSV10					0x28
#define IV_RSV11					0x2A
#define IV_RSV12					0x2C
#define IV_RSV13					0x2E
#define IV_PB0						0x30
#define IV_PB1						0x32
#define IV_PB2						0x34
#define IV_PB3						0x36
#define IV_PB4						0x38
#define IV_PB5						0x3A
#define IV_PB6						0x3C
#define IV_PB7						0x3E
#define IV_PC0						0x40
#define IV_PC1						0x42
#define IV_PC2						0x44
#define IV_PC3						0x46
#define IV_PC4						0x48
#define IV_PC5						0x4A
#define IV_PC6						0x4C
#define IV_PC7						0x4E
#define IV_PD0						0x50
#define IV_PD1 					0x52
#define IV_PD2						0x54
#define IV_PD3 					0x56
#define IV_PD4 					0x58
#define IV_PD5 					0x5A
#define IV_PD6 					0x5C
#define IV_PD7 					0x5E
#define IV_RSV14					0x60
#define IV_RSV15					0x62
#define IV_RSV16					0x64
#define IV_NMI	   				0x66



#endif
