;*******************************************************************************
;* Section:		IRQVect                                                        *
;*                                                                             *
;* This section will hold the Interrupt Vector Table and the ISR Jump Table.   *
;* When an interrupt occurs on the eZ80 in ADL mode, the CPU retrieves the 2   *
;* byte vector address from IVT.  It will then start executing code (the ISR)  *
;* at address {0 | I | [vect]}.  Therefore, the vector table must be located   *
;* in the first 64kB of addressable memory.  This module assumes not all of    *
;* the ISR fits in the first 64kB of the address space, so a Jump Table is     *
;* created in memory immediately before the Vector table.  This table just     *
;* contains code of the form jmp.lil 24-bit ISR address.  This allows the ISR  *
;* to exist anywhere in the 24-bit ADL address space.                          *
;*******************************************************************************
	DEFINE	.IRQVect
	SEGMENT .IRQVect 

	;***	The interrupt vector table (IVT_BASE) needs to be located on a 256
	;* 		byte boundary.  In the current version of the compiler only segments
	;*		can be ALIGNed.  Attempting to align data within a segment does not
	;*		produce the desired result.  If the IRQVect segment is aligned then
	;*		a potential hole will be created in the memory map causing the linker
	;*		to place data out of the defined segment ORDER.  Therefore to ensure 
	;*		vector table is properly aligned, extra storage is reserved here.  If 
	;*		you modify the default bootstrap code or reorder the default segments 
 	;*		it may be necessary to adjust the value on the next line.
	ds		%52

IVT_SIZE	.equ	%40
	;***	The interrupt vector table size is different on various members of
	;*		the eZ80 family of processors.  In general the architecture can 
	;*		support up to 128 vectors.  However, the EZ80L92 only uses 52 
	;*		vectors (36 active) and the EZ80190 only uses 48 vectors(43 active).
	;* 		This module assumes 64 vectors are avaiable.
	.def	_IVT_Base
	.def	_IVT_Jump_Table

_IVT_Jump_Table:
	ds    IVT_SIZE * 5
_IVT_Base:
	ds	  IVT_SIZE * 2

