/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _IPW_EZ80_H_
#define _IPW_EZ80_H_


#include <ether.h>
#include <uzi.h>
#include <bootinfo.h>
#include <basetypes.h>


/*
 * Macro Definitions
 */
#define NULLPTR								(void *) 0
#define NBPG									4096
#define NGD		 								8

#define MININT          					0x800000
#define MAXINT          					0x7FFFFF
#define FALSE									0
#define TRUE									1
#define IV_NULL								0xFF

#define MAX_CHIP_SELECTS					4	
#define MAX_PRTC_DIVISOR_STEPS			4
#define IVT_SIZE								0x40

#ifdef _EZ80L92
	#define IV_UZI0 							IV_UART0
	#define IV_UZI1							IV_UART1
#endif



/*
 * Structure and Type definitions
 */
typedef enum						GPIO_PORTS_E
{
#ifdef _EZ80190
	PORTA,
#endif
	PORTB,
	PORTC,
	PORTD
} GPIO_PORTS_E;
#define MAX_GPIO_PORTS						(PORTD+1)


typedef struct CS_CONFIG_S
{
	BYTE								b_lower_bound;
	BYTE								b_upper_bound;
	BYTE								b_control;
} CS_CONFIG_S;


typedef struct 					GPIO_CONFIG_S
{
	BYTE								b_dr;
	BYTE								b_ddr;
	BYTE 								b_alt1;
	BYTE								b_alt2;
} GPIO_CONFIG_S;


typedef struct						IVT_JT_ENTRY_S
{
	BYTE								b_lil_suffix;
   BYTE								b_jp_opcode;
	void 								(*handler)(void);
} IVT_JT_ENTRY_S;


typedef struct						RAM_BLOCK_S
{
	unsigned int					Start;
	unsigned int					End;	
} RAM_BLOCK_S;



/*
 * Global Variables
 */
extern unsigned short int		IVT_Base[IVT_SIZE];
extern IVT_JT_ENTRY_S			IVT_Jump_Table[IVT_SIZE];

extern const CS_CONFIG_S		cs_config[MAX_CHIP_SELECTS];
extern const BYTE					cs_bus_mode[MAX_CHIP_SELECTS];
extern const GPIO_CONFIG_S		GPIO_config[MAX_GPIO_PORTS];


extern const RAM_BLOCK_S		ram_blocks[];



extern BYTE							xinu_prtc; 		
extern BYTE							xinu_prtc_iv;	
extern unsigned short int		xinu_quantum;	
extern unsigned short int		xinu_min_stack;
extern BYTE							xinu_eth_irq;
extern BYTE							xinu_uses_wdt;
extern IORegExt16					p_emac_base;
extern BYTE							b_use_dhcp;
extern BYTE 						b_xinu_uses_uart0;
extern BYTE 						b_xinu_uses_uart1;
extern BYTE							b_uart0_iv;
extern BYTE							b_uart1_iv;
extern BYTE							b_initial_prtc_divisor;
extern DWORD 						masterclock;
extern BYTE *						p_mac_addr;
extern unsigned int				max_tcp_resends;
extern BYTE							ppp_connect_delay;


extern unsigned int				mac_addr_ofs;
extern unsigned short int *	p_INT_VT_base;
extern IVT_JT_ENTRY_S *			p_INT_JT_base;


extern const unsigned char * const	flash_ptr;
extern const unsigned int 		flash_length;
extern const unsigned int		ram_base;
extern const unsigned int		ram_length;
extern const unsigned int		TOS;
extern const unsigned int		code_size;
extern const unsigned int		data_size;
extern unsigned long 			masterclock;



/*
 * Function prototypes
 */
/* uzi.c */
extern int uziinit(struct devsw *pdev);
extern int uziputc(struct devsw *pdev, int c);
/* console.c */
extern int conputc(struct devsw *pdev, int c);
extern int conwrite(struct devsw *pdev, char *buf, int size);
/* emac_init.c */
extern int emac_init(struct devsw *pdev);
extern int emac_close(struct devsw *pdev);
/* emac_write.c */
extern int emac_write(struct devsw *pdev, struct ep *pep, int len);
/* emac_read.c */
extern int emac_read(struct devsw *pdev, struct ep **ppep, int len);
/* emac_conf.c */
extern void get_etheraddr(Eaddr *eaddr);
/* emac_control.c */
extern int emac_control(struct devsw *pdev, int func, char *arg1, char *arg2);


extern int init_ether(struct BootInfo *hmmnfo,int dodhcp);
extern void emac_reset( void );
extern void emac_enable_irq( void );
extern void emac_disable_irq( void );
extern void ethisr( void );


/* serial.c */
extern int serinit(struct devsw *pdev);
extern int seropen(struct devsw *pdev, char *name, char *arg);
extern int serclose(struct devsw *pdev);
extern int serread(struct devsw *pdev, unsigned char *buf, int size);
extern int sersread(struct devsw *pdev, unsigned char *buf, int size);
extern int serwrite(struct devsw *pdev, unsigned char *buf, int size);
extern int sergetc(struct devsw *pdev);
extern int sersputc(struct devsw *pdev, unsigned char c);
extern int serputc(struct devsw *pdev, unsigned char c);
extern int seriin(struct devsw *pdev, unsigned char ch);
extern void serintr(struct uzibase *puzi);
extern void serinchar(struct uzibase *puzi, unsigned char ch);
extern void serinbuf(struct uzibase *puzi);
extern void serinputenable(struct uzibase *puzi);
extern void serinputdisable(struct uzibase *puzi);
extern void enterISR(char *from);
extern void exitISR(void);

extern void ppp_stop( void );
extern void ppp_resume( void );

/* These routines are provided in the eZ80 standard library */
extern void _ei(void);
extern void _di(void);


#endif /* _IPW_EZ80_H_ */




