	.if _EZ80F92
		.include "eZ80F92.inc"
	.endif
	.if _EZ80L92
		.include "eZ80L92.inc"
	.endif
	.if _EZ80190
		.include "eZ80190.inc"
	.endif



;*******************************************************************************
;* Section:		.bootstrap                                                     *
;*                                                                             *
;* The bootstrap code contains the SW reset handlers.  The Reset instruction   *
;* is of the form RST n.  This instruction causes the CPU to save the current  *
;* PC to the stack and then starts executing code at {0000nn}.  Valid values   *
;* of n are:	00h, 08h, 10h, 18h, 20h, 28h, 30h, 38h.                        *
;*                                                                             *
;* Note: When the HW is powered on (or Reset), Flash is mapped to the entire   *
;* 24-bit address space (000000-FFFFFF) and the PC is set to 0.  This will     *
;* cause the boot loader to begin executing RST0.                              *
;*                                                                             *
;* Unlike a HW reset, the RST n instruction does not re-initialize the         *
;* peripheral devices.  This is done by the startup routine.                   *
;*                                                                             *
;* Illegal instruction Traps will also reult in the execution of RST0          *
;*******************************************************************************
	DEFINE .bootstrap, SPACE=ROM
	SEGMENT .bootstrap


	.assume ADL=1

	.def	_RST0
	.def	_RST8
	.def	_RST10
	.def	_RST18
	.def	_RST20
	.def	_RST28
	.def	_RST30
	.def	_RST38
	.def	_NMI66

_RST0:
	di
	rsmix	
	jp.lil	_ADL_START

_RST8:
	di
	rsmix
	jp.lil	_ADL_START

_RST10:
	di
	rsmix
	jp.lil	_ADL_START

_RST18:
	di
	rsmix
	jp.lil	_ADL_START

_RST20:
	di
	rsmix
	jp.lil	_ADL_START

_RST28:
	di
	rsmix
	jp.lil	_ADL_START

_RST30:
	di
	rsmix
	jp.lil	_ADL_START

_RST38:
	di
	rsmix
	jp.lil	_ADL_START
	
	ds %26
_NMI66:
	di
	rsmix
	jp.lil	_ADL_START



;*******************************************************************************
;* Section:		.startup                                                        *
;*                                                                             *
;* After a HW reset, all peripheral devices are initialized to a known state.  *
;* However, the state of the peripherals is unknown after a SW reset.  This    *
;* routine ensures none of the peripheral devices will generate interrupts.    *
;* In addition, the I register is set to point to the .IRQVect table.          *
;*******************************************************************************
	DEFINE	.startup, SPACE=ROM
	SEGMENT .startup 

	.assume ADL=1
	.def 	_ADL_START

_ADL_START:
	;***	Set I register to start of interrupt vector table, use interrupt mode 2
	di
	rsmix
	ld		hl, _p_INT_VT_base
	ld		bc, (hl)
	ld		a, b
	ld		i, a
	im		2

	;***	Include pltform specific code to ensure on-chip peripherals will not
	;       generate interrupts.  Where appropriate disable peripherals.
	;		If your project does not invoke a SW reset, this code does not need to
	;		be executed.
	.if _EZ80F92
		.include "boot_F92.asm"
	.endif
	.if _EZ80L92
		.include "boot_L92.asm"
	.endif
	.if _EZ80190
		.include "boot_190.asm"
	.endif

	;***	Include the common boot code.
	.include "boot.asm"




