/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
/*
 * ZiLOG eZ808 Evaluation Board, REAL TIME CLOCK Support Library, Ver 0.98
 * Copyright (c) 2000, ZiLOG, Inc
 * 
 * Pins PD7, PD6 and PD5 of GPIO PortD are used as open-drain I/O for data
 * transfer to/from the DS1302 Real Time Clock chip which uses a serial
 * 3-wire I/O interface. The chip has 31 bytes of RAM in addition to the Real
 * Time Clock registers.
 * 
 * Key timing parameters are: RTC_IO_Bit to RTC_SCLK_Bit rising edge setup -
 * 200nS (Max) RTC_IO_Bit hold time                         - 280nS (Max)
 * RTC_RST_Bit high to RTC_SCLK_Bit rising      - 4uS   (Max) RTC_RST_Bit low
 * to next RTC_RST_Bit high cycle 4uS   (Max)
 * 
 * Refer to DS1302 data sheet for info on RTC internal registers
 */

#define GPIOPort_RTC        PortD
/*
 * The following 3 are PortD pins that actually connect to the DS1302 RTC
 * chip
 */
#define RTC_IO_Bit          0x40
#define RTC_SCLK_Bit        0x20
#define RTC_RST_Bit         0x80
#define RTC_AllBits         RTC_IO_Bit | RTC_SCLK_Bit | RTC_RST_Bit

#define RTC_IO_BitPos       6

#define RAMWRITECMD         0xC0
#define RAMREADCMD          0xC1
#define CLKWRITECMD         0x80
#define CLKREADCMD          0x81

#define CLOCK               0	/* Used when accessing clock registers */
#define NVRAM               1	/* Used to specify accesses to NV RAM */

#define H12FORMAT       	0x80	/* 1 - 12hr, 0 - 24hr time format */
#define MSBHOUR			0x10
#define PM			0x20	/* in 12hrformat- 0-am, 1-pm */
#define MSBDATE			0x10
#define MSBMONTH 		0x10

#define ENABLEWRITE		0x00
#define DISABLEWRITE		0x80
#define STARTCLK		0x00	/* clk start */
#define STOPCLK			0x80
/*
 * Trickle charge register selection parameters
 */
#define LOW			0x03
#define MEDIUM			0x02
#define HIGH			0x01
#define SINGLEDIODE		0x04
#define TWODIODE		0x08	/* For extra voltage drop */
#define ENABLETRICKLECHARGE	0xA0
#define DISABLETRICKLECHARGE	0x00
/*
 * Clock factors register addr (right aligned)
 */
#define	SEC_REG			0x00
#define	MIN_REG			0x01
#define	HOUR_REG		0x02
#define	DATE_REG		0x03
#define	MONTH_REG		0x04
#define DAY_REG			0x05
#define	YEAR_REG		0x06
/*
 * Define chip control registers
 */
#define CONTROL_REG		0x07
#define	CHARGE_REG		0x08
#define	CLKBURST_REG		0x1F


/*
 * Define macro to align the 5 bit addr field into the RTC command character
 */
#define ALIGNADDR(x)        ((x << 1) & 0x3E)

typedef struct {
	unsigned char           sec;
	unsigned char           min;
	unsigned char           hrs;
	unsigned char           date;
	unsigned char           month;
	unsigned char           day;
	unsigned char           year;
	unsigned char           am_pm;
} TimeDate_Struct;

typedef struct {
	char           *day;
} Days;

/*
 * Extern definitions for RTC library functions
 */
extern void     InitRTCInterface(void);
/*
 * Initializes RTC hardware interface for accesses to RTC
 */

/*
 * Writes a single byte into the RTC location given by addr. For clock
 * registers use the convenient clock factors defines above
 */
extern void     WriteRTC(unsigned char addr, unsigned char data, unsigned char clock_or_ram);


/*
 * Reads a byte (or Clock register) from RTC. If it is a clock register, the
 * format needs to be interpreted properly. See DS1302Z data sheet for more
 * information.
 */
extern unsigned char    ReadRTC(unsigned char addr, unsigned char clock_or_ram);

/* Reads the RTC's time fields into the memory structure */
extern void     ReadTime(TimeDate_Struct * td);

/* Reads the RTC's date fields into the memory structure */
extern void     ReadDate(TimeDate_Struct * td);

/* Update time fields of the RTC with the contents of the memory structure */
extern void     WriteTime(TimeDate_Struct * td);

/* Update date fields of the RTC with the contents of the memory structure */
extern void     WriteDate(TimeDate_Struct * td);

/* enable/disable write operation */
extern void     WriteCtrl(unsigned char wbit);

/* start the oscillator */
extern void     StartRTC(void);

/* stop the oscillator */
extern void     StopRTC(void);

/* setup trickle charger */
extern void     TrickleCharge(unsigned char chargectrl);
