/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
/* arp.h - SHA, SPA, THA, TPA */
#ifndef _ARP_H_
#define _ARP_H_

/* Internet Address Resolution Protocol  (see RFCs 826, 920)		*/

#define	AR_HARDWARE	1	/* Ethernet hardware type code		*/

/* Definitions of codes used in operation field of ARP packet */
	
#define	AR_REQUEST	1	/* ARP request to resolve address	*/
#define	AR_REPLY	2	/* reply to a resolve request		*/

#define	RA_REQUEST	3	/* reverse ARP request (RARP packets)	*/
#define	RA_REPLY	4	/* reply to a reverse request (RARP ")	*/

struct	arp	{
	short	ar_hwtype;	/* hardware type			*/
	short	ar_prtype;	/* protocol type			*/
	char	ar_hwlen;	/* hardware address length		*/
	char	ar_prlen;	/* protocol address length		*/
	short	ar_op;		/* ARP operation (see list above)	*/
	unsigned char	ar_addrs[1]; /* sender and target hw & proto addrs */
#if 0
	char	ar_sha[???];	/* sender's physical hardware address	*/
	char	ar_spa[???];	/* sender's protocol address (IP addr.)	*/
	char	ar_tha[???];	/* target's physical hardware address	*/
	char	ar_tpa[???];	/* target's protocol address (IP)	*/
#endif
};

#define	SHA(p)	(&p->ar_addrs[0])
#define	SPA(p)	(&p->ar_addrs[(int)p->ar_hwlen])
#define	THA(p)	(&p->ar_addrs[(int)(p->ar_hwlen + p->ar_prlen)])
#define	TPA(p)	(&p->ar_addrs[(int)((p->ar_hwlen*2) + p->ar_prlen)])


#define	MAXHWALEN	EP_ALEN	/* Ethernet				*/
#define	MAXPRALEN	IP_ALEN	/* IP					*/

#define ARP_HLEN	8	/* ARP header length			*/

#define	ARP_QSIZE	10	/* ARP port queue size			*/

/* cache timeouts */

#define ARP_TIMEOUT	600		/* 10 minutes			*/
#define	ARP_INF		MAXINT	/* "infinite" timeout value	*/
#define	ARP_RESEND	1	/* resend if no reply in 1 sec		*/
#define	ARP_MAXRETRY	4	/* give up after ~30 seconds		*/

struct	arpentry {		/* format of entry in ARP cache		*/
	short	ae_state;	/* state of this entry (see below)	*/
	short	ae_hwtype;	/* hardware type			*/
	short	ae_prtype;	/* protocol type			*/
	char	ae_hwlen;	/* hardware address length		*/
	char	ae_prlen;	/* protocol address length		*/
	struct netif *ae_pni;	/* pointer to interface structure	*/
	int	ae_queue;	/* queue of packets for this address	*/
	int	ae_attempts;	/* number of retries so far		*/
	int	ae_ttl;		/* time to live				*/
	unsigned char	ae_hwa[MAXHWALEN]; /* Hardware address 		*/
	unsigned char	ae_pra[MAXPRALEN]; /* Protocol address 		*/
};

#define	AS_FREE		0	/* Entry is unused (initial value)	*/
#define	AS_PENDING	1	/* Entry is used but incomplete		*/
#define	AS_RESOLVED	2	/* Entry has been resolved		*/

/* RARP variables */

extern int	rarppid;	/* id of process waiting for RARP reply	*/
extern int	rarpsem;	/* semaphore for access to RARP service	*/

/* ARP variables */

extern struct	arpentry	arptable[];
extern const int	ARP_TSIZE;

/* ../arp/arp_in.c */
int arp_in(struct netif *pni, struct ep *pep);
/* ../arp/arpadd.c */
struct arpentry *arpadd(struct netif *pni, struct arp *parp);
/* ../arp/arpalloc.c */
struct arpentry *arpalloc(void);
/* ../arp/arpdq.c */
void arpdq(struct arpentry *pae);
/* ../arp/arpfind.c */
struct arpentry *arpfind(unsigned char *pra, int prtype, struct netif *pni);
/* ../arp/arpflush.c */
void arpflush(void);
/* ../arp/arpinit.c */
void arpinit(void);
/* ../arp/arpprint.c */
int arpprint(int fd);
/* ../arp/arpqsend.c */
void arpqsend(struct arpentry *pae);
/* ../arp/arpsend.c */
int arpsend(struct arpentry *pae);
/* ../arp/arptimer.c */
void arptimer(int gran);

#endif /* _ARP_H_ */
