/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */

#ifndef	_HTTP_H
#define	_HTTP_H	1
/*
 * http.h - This contains the public interfaces for the httpd
 */


typedef int file_t;

/** A static page is defined for pages that exist statically in the program. */
struct staticpage {
        /** A pointer to the actual contents of the page. This could be the
         * actual string representing the entire page, or an array of bytes
         * (e.g. the array produced by the mkwebpage program).  */
	unsigned char *contents;
        /*  The size of the above array, since it is not null terminated.  If
         *  this is actually a string, it would be equal to strlen(array).
         */
	int	size;
	};

/**
 *  A structure describing any particular webpage which the http server is
 *  expected to handle.  The server will be passed a list of such structures.
 */
struct webpage {
        /** Whether this is a static (HTTP_PAGE_STATIC) or dynamic
         * (HTTP_PAGE_DYNAMIC) page. */
        int	type;
        /*  The relative path to this page. */
	char	*path;
        /*  The mime type to be returned in the MIMETYPE header. */
	char	*mimetype;
        /*  Either a structure defining the static page, or the 'cgi' function
         *  which will generate this page.
         */
	union {
		const struct staticpage	*spage;
		int	(*cgi)(struct http_request *);
//		int	(*cgi)(void *);

		} content;
	};

typedef const struct webpage Webpage;

struct header_rec {
	char    *name;
	int     val;
	};

/* page types */
#define HTTP_PAGE_STATIC	1
#define HTTP_PAGE_DYNAMIC	2

#ifndef HTTP_REQUEST_BUF
#define HTTP_REQUEST_BUF	1024
#endif

#ifndef HTTP_MAX_HEADERS
#define HTTP_MAX_HEADERS	16
#endif

#ifndef HTTP_MAX_PARAMS
#define HTTP_MAX_PARAMS	16
#endif





/* HTTP Methods */

#define HTTP_GET	1
#define HTTP_HEAD	2
#define HTTP_POST	3
#define HTTP_LINK	4
#define HTTP_UNLINK	5
#define HTTP_PUT	6
#define HTTP_DELETE	7
#define HTTP_OPTIONS	8
#define HTTP_TRACE	9
#define	HTTP_NOTIFY	10
#define	HTTP_SEARCH	11
#define	HTTP_MSEARCH	12
#define	HTTP_MPOST	13
#define	HTTP_SUBSCRIBE	14
#define	HTTP_UNSUBSCRIBE 15

typedef struct http_hdr {
	int	key;
	char*	value;
} Http_Hdr;


/**
 * A key/value pair of strings.
 * @name http_params
 * @type typedef struct http_params
 */
struct http_params {
        /**  The key, typically an http header. */
	char	*key;
        /**  The value associated with that key. */
	char	*value;
};

typedef struct http_params Http_Params;

/** @memo The http_request structure.
 * @doc This structure is used to hold parsed incoming HTTP requests, and to
 * hold HTTP requests being constructed for outgoing requests.
 * It holds all the information associated with a request.
 * The getch and write fields are particularly noteworthy.  These
 * values are callbacks provided by the implementor, which are used to send and
 * receive HTTP data. In this way the package is isolated from the I/O
 * mechanism, and it is even possible to use different I/O mechanisms for each
 * request generated or serviced.
 * @name http_request
 * @type typedef struct http_request
 */
typedef struct http_request {
	int	method;
	int	reply;
	int	numheaders;
	int	numparams;
	int	numrespheaders;
	file_t	fd;
	int    (*getch)(file_t fd);
	int    (*write)(file_t fd, const void *buf,int size);
// MCB L92	Http_Hdr rqstheaders[HTTP_MAX_HEADERS];
// MCB L92	Http_Hdr respheaders[HTTP_MAX_HEADERS];
// MCB L92	Http_Params params[HTTP_MAX_PARAMS];
	const struct http_method	*methods;
	Webpage	*website;
	const struct header_rec	*headers;
// MCB L92	char	buffer[HTTP_REQUEST_BUF];
	char	*bufstart; /* first free space */
	char	*extraheader;
	Http_Hdr rqstheaders[HTTP_MAX_HEADERS];
	Http_Hdr respheaders[HTTP_MAX_HEADERS];
	Http_Params params[HTTP_MAX_PARAMS];
	char	buffer[HTTP_REQUEST_BUF];
} Http_Request;

typedef struct http_method {
	int	key;
	char	*name;
	void	(*method)(Http_Request *);
} Http_Method;


extern const Http_Method http_defmethods[];
extern const struct header_rec httpdefheaders[];
// TS extern const struct header_rec defreplies[];
extern struct header_rec defreplies[];

extern char *HTTP_404_Reply_Body;
extern int http_init(const Http_Method *methods,const struct header_rec *headers, Webpage *webpages,int port);




#endif	/* _HTTP_H */
