/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */

#ifndef	_HTTPD_H
#define	_HTTPD_H	1

#ifndef NULL
#define NULL 0
#endif

#ifdef xinu
#include <stdlib.h>
#include <kernel.h>
#include <inttypes.h>
#endif
#ifdef unix
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <inttypes.h>
#endif
#ifdef VXWORKS
#include <vxWorks.h>
#endif
#include <ctype.h>

#include "http.h"

/* HTTPD process info */
#define	HTTPSTK		2500	/* stack size for HTTPD	*/
#define	HTTPPRI		20		/* HTTPD priority		*/
#define	HTTPNAM		"httpd"		/* name of HTTPD process	*/
#define	HTTPARGC	0		/* count of args to HTTPD	*/

#define HTTPRQSTK	1024+sizeof(struct http_request)
#define HTTPRQPRI	20
#define HTTPRQNAM	"http_request"

/* Adjustable stuff */
#define HTTP_REQUEST_SIZE	256 /* obsolete? */


/* HTTP Headers */

/* Values 1  -100 are used for HTTP_HDR_* */
/* Values 101-200 are used for SSDP_HDR_* */
/* Values 201-300 are used for SOAP_HDR_* */
/* Values 301-400 are used for GENA_HDR_* */

#define HTTP_HDR_ACCEPT			1
#define HTTP_HDR_CACHE_CONTROL		2
#define HTTP_HDR_CONNECTION		3
#define HTTP_HDR_CONTENT_LENGTH		4
#define HTTP_HDR_CONTENT_TYPE		5
#define HTTP_HDR_TRANSFER_ENCODING	6
#define	HTTP_HDR_DATE			7
#define	HTTP_HDR_LOCATION		8
#define	HTTP_HDR_HOST			9
#define	HTTP_HDR_SERVER			10

/* UPnP-specific headers - These should probably move to upnp.h */
#define	HTTP_HDR_EXT			11
#define	HTTP_HDR_ST			12
#define	HTTP_HDR_USN			13
#define	HTTP_HDR_MAN			14
#define	HTTP_HDR_MX			15
#define	HTTP_HDR_NT			16
#define	HTTP_HDR_NTS			17
#define	HTTP_HDR_SOAPACTION		18
#define	HTTP_HDR_CALLBACK		19
#define	HTTP_HDR_TIMEOUT		20
#define	HTTP_HDR_SID			21
#define	HTTP_HDR_SEQ			22

/* HTTP Reply Codes */
#define HTTP_200_OK			200
#define HTTP_400_BAD_REQUEST		400
#define HTTP_403_FORBIDDEN		403
#define HTTP_404_NOT_FOUND		404
#define HTTP_411_LENGTH_REQUIRED	411
#define HTTP_412_PRECONDITION_FAILED	412
#define HTTP_414_REQUEST_URI_TOO_LONG	414
#define HTTP_500_INTERNAL_ERROR		500
#define HTTP_501_NOT_IMPLEMENTED	501
#define HTTP_503_SERVICE_UNAVAILABLE    503

#ifndef __http_write
#define __http_write(rqst,buf,size) rqst->write(rqst->fd,buf,size)
#endif

/* httpfind.c */
extern Webpage *http_findpage(struct http_request *request);
/* httpget.c */
extern void http_get(struct http_request *request);
/* httphdr.c */
extern void http_output_headers(struct http_request *rqst);
extern int http_get_header(struct http_request *rqst);
extern void http_reset_headers(struct http_request *rqst);
extern void http_add_header(struct http_request *rqst, int header, char *value);
extern char *http_find_header(struct http_request *rqst, int key);
extern char *http_find_argument(struct http_request *rqst, char *arg);
extern char *http_find_param(Http_Params *params, char *key);
/* httporply.c */
extern int http_output_reply(struct http_request *request, int reply);
/* httporqst.c */
extern int http_output_request(struct http_request *request, int method, char *url);
/* httpparse.c */
extern int http_parse_request(struct http_request *rqst);
extern int http_parse_response(struct http_request *rqst);
extern int http_parse_arguments(struct http_request *rqst, char *ptr);
extern char * __http_uri_unescape(char *ptr);

/* httppost.c */
extern void http_post(struct http_request *request);
/* httprqst.c */
extern void http_request(struct http_request *request);
/* httpitoa.c */
char *__http_itoa(int value, char *s);
int __http_atoi(char *s);
/* httpd-os.c */
int __http_date(char *buf, int size);
void __http_init_request(struct http_request *req);
void __http_complete_request(struct http_request *req);
//int __http_connect(struct http_request *req, uint32_t addr, int port);

#endif	/* _HTTPD_H */
