/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _IGMP_H_
#define _IGMP_H_
/* igmp.h - IG_VER, IG_TYP */

extern int	HG_TSIZE;		/* host group table size	*/

#define	IG_VERSION	 1		/* RFC 1112 version number	*/

#define	IG_HLEN		 8		/* IGMP header length		*/
#define	IGT_HQUERY	 1		/* host membership query	*/
#define	IGT_HREPORT	 2		/* host membership report	*/

struct igmp {
	unsigned char	ig_vertyp;	/* version and type field	*/
	char		ig_unused;	/* not used by IGMP		*/
	unsigned short	ig_cksum;	/* compl. of 1's compl. sum	*/
	IPaddr		ig_gaddr;	/* host group IP address	*/
};

#define	IG_VER(pig)	(((pig)->ig_vertyp>>4) & 0xf)
#define	IG_TYP(pig)	((pig)->ig_vertyp & 0xf)

#define	IG_NSEND	2		/* # IGMP join messages to send	*/
#define	IG_DELAY	5		/* delay for resends (1/10 secs)*/

/* Host Group Membership States */

#define	HGS_FREE	0	/* unallocated host group table entry	*/
#define	HGS_DELAYING	1	/* delay timer running for this group	*/
#define	HGS_IDLE	2	/* in the group but no report pending	*/
#define	HGS_STATIC	3	/* for 224.0.0.1; no state changes	*/

struct hg {
	unsigned char	 hg_state;	/* HGS_* above			*/
	unsigned char	 hg_ifnum;	/* interface index for group	*/
	IPaddr		 hg_ipa;	/* IP multicast address		*/
	unsigned int	 hg_refs;	/* reference count		*/
	Bool		 hg_ttl;	/* max IP ttl for this group	*/
};

/* Host Group Update Process Info. */

#define	IGUSTK		512		/* stack size for update proc.	*/
#define	IGUPRI		 50		/* update process priority	*/
#define	IGUNAM		"igmp_update"	/* name of update  process	*/
#define	IGUARGC		0		/* count of args to hgupdate	*/

struct hginfo {
	Bool	hi_valid;	/* TRUE if hginit() has been called	*/
	int	hi_mutex;	/* table mutual exclusion		*/
	int	hi_uport;	/* listen port for delay timer expires	*/
};

extern struct hginfo	HostGroup;

extern IPaddr ig_allhosts;	/* "all hosts" group address (224.0.0.1)*/
extern IPaddr ig_allDmask;	/* net mask to match all class D addrs.	*/
extern struct hg hgtable[];
/* hgadd.c */
extern int hgadd(int ifnum, IPaddr ipa, Bool islocal);
/* hgarpadd.c */
extern int hgarpadd(int ifnum, IPaddr ipa);
/* hgarpdel.c */
extern int hgarpdel(int ifnum, IPaddr ipa);
/* hginit.c */
extern void hginit(void);
/* hgjoin.c */
extern int hgjoin(int ifnum, IPaddr ipa, Bool islocal);
/* hgleave.c */
extern int hgleave(int ifnum, IPaddr ipa);
/* hglookup.c */
extern struct hg *hglookup(int ifnum, IPaddr ipa);
extern int hggetttl(int ifnum, IPaddr ipa);
/* hgprint.c */
extern int hgprint(int fd);
/* hgrand.c */
extern int hgrand(void);
/* igmp.c */
extern int igmp(int typ, int ifnum, IPaddr hga);
/* igmp_in.c */
extern int igmp_in(struct netif *pni, struct ep *pep);
/* igmp_settimers.c */
extern int igmp_settimers(int ifnum);
/* igmp_update.c */
extern int igmp_update(void);
#endif /* _IGMP_H_ */
