/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _KERNEL_H_
#define _KERNEL_H_

#include <ez80.h>
#include <ipw_ez80.h> 


/* kernel.h - disable, enable, halt, restore, isodd, min, max */
//#include "mem.h"




/* Symbolic constants used throughout Xinu */

//typedef	char		unsigned Bool;	/* Boolean type			*/




#define	FALSE		0		/* Boolean constants		*/
#define	TRUE		1
#define	EMPTY		(-1)		/* an illegal gpq		*/
#ifndef NULL
#define	NULL		(void*)0		/* Null pointer for linked lists*/
#endif
#define	NULLCH		'\0'		/* The null character		*/
#define	NULLSTR		""		/* Pointer to empty string	*/
#define	SYSCALL		int		/* System call declaration	*/
#define	LOCAL		static 		/* Local procedure declaration	*/
#define	COMMAND		int		/* Shell command declaration	*/
#define	BUILTIN		int		/* Shell builtin " "		*/
#define	INTPROC		int		/* Interrupt procedure  "	*/
#define	PROCESS		int		/* Process declaration		*/
#define	RESCHYES	1		/* tell	ready to reschedule	*/
#define	RESCHNO		0		/* tell	ready not to resch.	*/
#define	LOWBYTE		0377		/* mask for low-order 8 bits	*/
#define	HIBYTE		0177400		/* mask for high 8 of 16 bits	*/
#define	LOW16		0177777		/* mask for low-order 16 bits	*/
#define	MAGIC		0125251		/* unusual value for top of stk	*/

/* Universal return constants */

#define	OK		 1		/* system call ok		*/
#define	SYSERR		-1		/* system call failed		*/
#define BADDEV          -1
#define	EOF		-2		/* End-of-file (usu. from read)	*/
#define	TIMEOUT		-3		/* time out  (usu. recvtim)	*/
#define	INTRMSG		-4		/* keyboard "intr" key pressed	*/
					/*  (usu. defined as ^B)	*/
#define	BLOCKERR	-5		/* non-blocking op would block	*/

/* Initialization constants */

#define	INITSTK		1024		/* initial process stack size	*/
#define	INITPRIO	20		/* initial process priority	*/
#define	INITNAME	"main"		/* initial process name		*/
#define	INITARGS	1,0		/* initial count/arguments	*/
#define	INITRET		userret		/* processes return address	*/
#define	INITREG		0		/* initial register contents	*/
// MCB L92 #define	QUANTUM		10		/* clock ticks until preemption	*/



/* Machine size definitions						*/

// MCB L92 typedef	char	CHAR;		/* sizeof the unit the holds a character*/
// MCB L92 typedef	int	WORD;		/* maximum of (int, char *)		*/
// MCB L92 typedef	char	*PTR;		/* sizeof a char. or fcnt. pointer 	*/
// MCB L92 typedef int	INT;		/* sizeof compiler integer		*/
// MCB L92 typedef	int	REG;		/* sizeof machine register		*/

#define MAXLONG		0x7fffffffL
#define MINLONG		0x80000000L

typedef short	STATWORD[1];	/* machine status for disable/restore	*/
				/* by declaring it to be an array, the	*/
				/* name provides an address so forgotten*/
				/* &'s don't become a problem		*/

typedef int (*procptr)(void);	/* Starting address of a process */

/* Miscellaneous utility inline functions */
#define	isodd(x)	(01&(WORD)(x))
#define	min(a,b)	( (a) < (b) ? (a) : (b) )
#define	max(a,b)	( (a) > (b) ? (a) : (b) )

#define isbaddev(f)     ( (f)<0 || (f)>=NDEVS )

extern	int	rdyhead, rdytail;

extern	int	preempt;

extern unsigned char VERSION[];

extern int noint;
extern void disable(short *);
extern void restore(short *);

/* Memmory map related stuff */
#ifdef i386
#define HOLESIZE        (600)
#define HOLESTART       (640 * 1024)
#define HOLEEND         ((1024 + HOLESIZE) * 1024)
#endif

#ifdef KBMON
#include <kbm.h>
#endif
#include <conf.h>
#include <mem.h>
#include <ports.h>
#ifdef i386
#include <i386.h>
#endif
#ifdef ez80
#include <ipw_ez80.h>	// MCB L92

#endif
#ifdef mc16
#include <mc16.h>
#endif
#ifdef unixproc
#include <unixproc.h>
#endif
#include <ether.h>

/* adddevice.c */
extern int adddevice(struct devsw *newdev, int minor);
/* blkcmp.c */
extern int blkcmp(unsigned char *s1, unsigned char *s2, int len);
/* blkcopy.c */
//extern int blkcopy(unsigned char *to, unsigned char *from, int nbytes);
extern int blkcopy(void *to, void *from, int nbytes);
/* blkequ.c */
extern int blkequ(unsigned char *first, unsigned char *second, int nbytes);
/* chprio.c */
extern SYSCALL chprio(int pid, int newprio);
/* ckmode.c */
extern SYSCALL ckmode(char *mode);
/* clkinit.c */
extern void clkinit(void);
extern void clktest(void);
/* close.c */
extern SYSCALL close(int descrp);
/* conf.c */
/* control.c */
extern SYSCALL control(int descrp, int func, char *addr, char *addr2);
#ifndef NO_CREATE_DECL
/* create.c */
extern SYSCALL create(procptr procaddr, int ssize, int priority, char *name, int nargs, ...);
#endif
/* dotrace.c */
extern void dotrace(char *procname, int *argv, int argc);
/* evec.c */
extern void initevec(void);
// MCB L92 extern void set_evec(unsigned int xnum, void (*handler)(void));
extern void * set_evec(	unsigned short int vector, void (*handler)(void) );
// MCB L92 extern void trap(int inum);


/* freebuf.c */
extern int freebuf(int *buf);
/* freemem.c */
//extern int freemem(struct mblock *block, WORD size);
extern int freemem(void *block, WORD size);


/* getbuf.c */
extern int *getbuf(int poolid);
extern int *nbgetbuf(int poolid);
/* getc.c */
extern SYSCALL getc(int descrp);
/* getitem.c */
extern int getfirst(int head);
extern int getlast(int tail);
/* getmem.c */
//extern WORD *getmem(unsigned nbytes);


extern void *getmem(unsigned nbytes);
/* getpid.c */
extern SYSCALL getpid(void);
/* getprio.c */
extern SYSCALL getprio(int pid);
/* getstk.c */
extern WORD *getstk(unsigned int nbytes);
/* gettime.c */
extern SYSCALL gettime(unsigned long *timvar);
/* getuid.c */
extern SYSCALL getuid(char *login);
/* getuser.c */
extern struct user *getuser(unsigned long uid);
/* gpq.c */
extern int enq(int q, char *elt, int key);
extern char *deq(int q);
extern char *headq(int q);
extern char *seeq(int q);
extern int newq(int size, int mtype);
extern void freeq(int q);
extern int lenq(int q);
#ifdef i386
/* i386.c */
extern int setsegs(void);
extern int init8259(void);
extern int pseg(struct sd *psd);
#endif
/* init.c */
extern int init_dev(int descrp);
/* initialize.c */
extern int nulluser(void);
extern int stop(char *s);
extern void delay(int n);
extern long sizmem(void);
/* insert.c */
extern int insert(int proc, int head, int key);
/* insertd.c */
extern int insertd(int pid, int head, int key);
/* ioerr.c */
extern int ioerr(void);
/* ionull.c */
extern int ionull(void);
/* kill.c */
extern SYSCALL kill(int pid);
#ifndef NO_KPRINTF_DECL
/* kprintf.c */
extern int kprintf(char *, ... );
#endif
/* kputc.c */
extern int kputc(int dev, char c);
/* main.c */
extern int user1(void);
extern int main(void);
/* mark.c */
extern void _mkinit(void);
extern int mark(int *loc);
/* mkpool.c */
extern int mkpool(int bufsiz, int numbufs);
/* naminit.c */
extern void naminit(void);
/* nammap.c */
extern int nammap(char *name, char *newname);
/* namopen.c */
extern int namopen(struct devsw *devptr, char *filenam, char *mode);
/* namrepl.c */
extern int namrepl(char *name, char *newname);
/* newqueue.c */
extern int newqueue(void);
/* open.c */
extern int open(int descrp, char *nam, char *mode);
#ifndef NO_PANIC_DECL
/* panic.c */
extern void panic(char *msg,...);
#endif
/* pcount.c */
extern int pcount(int portid);
/* pcreate.c */
extern int pcreate(int count);
/* pdelete.c */
extern int pdelete(int portid, int (*dispose)(int *));
/* pinit.c */
extern int pinit(int maxmsgs);
/* poolinit.c */
extern int poolinit(void);
/* preceive.c */
extern int preceive(int portid);
/* preset.c */
extern int preset(int portid, int (*dispose)(int *));
/* printq.c */
extern void printq(int head);
/* psend.c */
extern int psend(int portid, WORD msg);
extern int psendu(int portid, WORD msg);
/* ptclear.c */
extern void _ptclear(struct pt *ptptr, int newstate, int (*dispose)(int *));
/* putc.c */
extern int putc(int descrp, char ch);
/* queue.c */
extern int enqueue(int item, int tail);
extern int dequeue(int item);
/* read.c */
extern int read(int descrp, char *buff, int count);
/* ready.c */
extern int ready(int pid, int resch);
/* receive.c */
extern int receive(void);
/* recvclr.c */
extern int recvclr(void);
/* recvtim.c */
extern int recvtim(int maxwait);
/* remove.c */
extern int remove(char *name, int key);
/* rename.c */
extern int rename(char *old, char *new);
/* resched.c */
extern int resched(void);
/* resume.c */
extern int resume(int pid);
/* scount.c */
extern int scount(int sem);
/* screate.c */
extern int screate(int count);
/* sdelete.c */
extern int sdelete(int sem);
/* seek.c */
extern int seek(int descrp, long pos);
/* send.c */
extern int send(int pid, WORD msg);
/* sendf.c */
extern int sendf(int pid, int msg);
/* setdev.c */
extern int setdev(int pid, int dev1, int dev2);
/* setnok.c */
extern int setnok(int nok, int pid);
/* signal.c */
extern int signal(int sem);
/* signaln.c */
extern int signaln(int sem, int count);
/* sleep.c */
extern int sleep(int n);
/* sleep10.c */
extern int sleep10(int n);
/* sleep100.c */
extern int sleep100(int n);
/* sreset.c */
extern int sreset(int sem, int count);
/* ssclock.c */
extern void stopclk(void);
extern void strtclk(void);
/* stacktrace.c */
extern int stacktrace(unsigned int pid);
/* suspend.c */
extern int suspend(int pid);
#ifndef NO_SYSLOG_DECL
/* syslog.c */
extern int syslog(int where, char *pname, char *fmt, ...);
#endif
/* unsleep.c */
extern int unsleep(int pid);
/* userret.c */
extern int userret(void);
/* wait.c */
extern int wait(int sem);
/* wakeup.c */
extern int wakeup(void);
/* write.c */
extern int write(int descrp, char *buff, int count);
/* xdone.c */
extern void xdone(void);

extern void enable(void);

extern SYSCALL archinit(void);

extern void ctxsw(int *,short *,int *,short *);
extern void timed_738_init(void);

extern void checksum( unsigned long * cur_chksum, unsigned short * pData, unsigned int Count );

#endif /* _KERNEL_H_ */
