/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
/* netif.h - NIGET */
#ifndef _NETIF_H_
#define _NETIF_H_

#include <ether.h>
#include <inttypes.h>


#define Bool unsigned char



#define	NI_MAXHWA 14			/* max size of any hardware	*/
					/*  (physical) net address	*/
struct	hwa	{			/* a hardware address		*/
	int		ha_len;		/* length of this address	*/
	unsigned char	ha_addr[NI_MAXHWA]; 	/* the address		*/
};

#define	NI_INQSZ	30		/* interface input queue size	*/
#define	NETNLEN		64		/* length of network name	*/

#define	NI_LOCAL	0		/* index of local interface	*/
#define	NI_PRIMARY	1		/* index of primary interface	*/

#define	NI_MADD		0		/* add multicast (ni_mcast)	*/
#define	NI_MDEL		1		/* delete multicast (ni_mcast)	*/

/* interface states */
#define	NIS_UNUSED	0x00
#define	NIS_UP		0x01
#define	NIS_DOWN	0x02
#define	NIS_TESTING	0x03

/* Definitions of network interface structure (one per interface)	*/

struct	netif {				/* info about one net interface	*/
//MCB L92	char	ni_name[NETNLEN];	/* domain name of this interface*/
	char	ni_state;		/* interface states: NIS_ above	*/
	IPaddr	ni_ip;			/* IP address for this interface*/
	IPaddr	ni_net;			/* network IP address		*/
	IPaddr	ni_subnet;		/* subnetwork IP address	*/
	IPaddr	ni_mask;		/* IP subnet mask for interface	*/
	IPaddr	ni_brc;			/* IP broadcast address		*/
	IPaddr	ni_nbrc;		/* IP net broadcast address	*/
	int	ni_mtu;			/* max transfer unit (bytes)	*/
	int	ni_hwtype;		/* hardware type (for ARP)	*/
	struct	hwa	ni_hwa;		/* hardware address of interface*/
	struct	hwa	ni_hwb;		/* hardware broadcast address	*/
	int	(*ni_mcast)(int,int,Eaddr,IPaddr);	/* multicast add/delete func.	*/
	Bool	ni_ivalid;		/* is ni_ip valid?		*/
	Bool	ni_nvalid;		/* is ni_name valid?		*/
	Bool	ni_svalid;		/* is ni_subnet valid?		*/
	int	ni_dev;			/* the Xinu device descriptor	*/
	int	ni_ipinq;		/* IP input queue		*/
	int	ni_outq;		/* (device) output queue	*/
	int	(*ni_send)(struct netif *,struct ep *); /* Function to call to send a packet */
	/* Interface MIB */
	char	*ni_descr;		/* text description of hardware */
	int	ni_mtype;		/* MIB interface type		*/
/* SNMP specifies that these (the uint32_t values) are 32-bit entities */
	uint32_t	ni_speed;	/* bits per second		*/
	char	ni_admstate;		/* administrative status (NIS_*)*/
	uint32_t	ni_lastchange;	/* last state change (1/100 sec)*/
	uint32_t	ni_ioctets;	/* # of octets received		*/
	uint32_t	ni_iucast;	/* # of unicast received	*/
	uint32_t	ni_inucast;	/* # of non-unicast received	*/
	uint32_t	ni_idiscard;	/* # dropped - output queue full*/
	uint32_t	ni_ierrors;	/* # input packet errors	*/
	uint32_t	ni_iunkproto;	/* # in packets for unk. protos */
	uint32_t	ni_ooctets;	/* # of octets sent		*/
	uint32_t	ni_oucast;	/* # of unicast sent		*/
	uint32_t	ni_onucast;	/* # of non-unicast sent	*/
	uint32_t	ni_odiscard;	/* # output packets discarded	*/
	uint32_t	ni_oerrors;	/* # output packet errors	*/
	uint32_t	ni_oqlen;	/* output queue length		*/
	uint32_t	ni_maxreasm;	/* max datagram can reassemble	*/
	char	ni_name[NETNLEN];	/* domain name of this interface*/
};

#define	NIGET(ifn)	((struct ep *)deq(nif[ifn].ni_ipinq))

extern int	NIF;	/* # of interfaces */

extern struct netif	nif[];

/* addnif.c */
extern struct netif *addnif(int dev);

#endif /* _NETIF_H_ */
