/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _NETWORK_H_
#define _NETWORK_H_
/* network.h */

/* All includes needed for the network */

#include <systypes.h>
#include <ip.h>
#include <ether.h>
#include <ipreass.h>
#include <icmp.h>
#include <netif.h>
#include <udp.h>
#include <tcp.h>
#include <tcpfsm.h>
#include <tcpstat.h>
#include <tcb.h>
#include <net.h>
#include <dgram.h>
#include <arp.h>
#ifdef OSPF
#include <ospf.h>
#endif /* OSPF */
#ifdef	RIP
#include <rip.h>
#endif	/* RIP */
#include <snmpvars.h>

/* Declarations data conversion and checksum routines */

extern	unsigned short 	cksum(unsigned short *,int); /* 1s comp of 16-bit 1s comp sum*/

#if	BYTE_ORDER == LITTLE_ENDIAN
extern unsigned short int ez80_hs2net( unsigned short int value );
#define hs2net(x) ez80_hs2net( (x) )
//#define hs2net(x) (unsigned) ((((x)>>8) &0xff) | (((x) & 0xff)<<8))
#define	net2hs(x) hs2net(x)

extern DWORD ez80_hl2net( DWORD value );
//#define hl2net(x) ((((((x)& 0xffUL)<<24)) | (((x)>>24) & 0xffUL)) | \
//		  (((x) & 0xff0000UL)>>8) | (((x) & 0xff00UL)<<8))
#define hl2net(x) ez80_hl2net( (x) )
#define net2hl(x) ez80_hl2net( (x) )
#endif

#if	BYTE_ORDER == BIG_ENDIAN
#define hs2net(x) (x)
#define net2hs(x) (x)
#define hl2net(x) (x)
#define net2hl(x) (x)
#endif

/* network macros */
#define hi8(x)   (unsigned char)  (((long) (x) >> 16) & 0x00ff)
#define low16(x) (unsigned short) ((long) (x) & 0xffff)

// MCB L92 #define	BYTE(x, y)	((x)[(y)]&0xff)	/* get byte "y" from ptr "x" */

/* dnparse.c */
extern int dnparse(char *fspec, IPaddr *paddr, unsigned short *pport);
/* dot2ip.c */
extern IPaddr dot2ip(char *pdot);
/* ethmatch.c */
extern Bool ethmatch(struct netif *pni, Eaddr pea);
/* ethmcast.c */
extern int ethmcast(int op, int dev, Eaddr hwa, IPaddr ipa);
/* ethnif.c */
extern int ether_send(struct netif *pni, struct ep *pep);
/* getaddr.c */
extern int getaddr(IPaddr ip);
extern IPaddr getiaddr(int inum);
/* getconfig.c */
extern int getconfig(int *piface);
/* getname.c */
extern int getname(char *nam);
extern int getiname(int inum, char *nam);
/* getnet.c */
extern IPaddr getnet(void);
extern IPaddr getinet(int inum);
/* getutim.c */
extern int getutim(unsigned long *timvar);
/* initgate.c */
extern int initgate(void);
extern void efaceinit(int iface);
/* inithost.c */
extern int inithost(void);
/* ip2dot.c */
extern char *ip2dot(char *pdot, IPaddr ip);
/* ip2name.c */
extern char *ip2name(IPaddr ip, char *nam);
/* local_out.c */
extern int local_out(struct ep *pep);
/* name2ip.c */
extern IPaddr name2ip(char *nam);
extern IPaddr gname(char *nam);
extern IPaddr resolve(char *nam);
/* netdump.c */
extern int netdump(void);
/* netmask.c */
extern IPaddr netmask(IPaddr net);
/* netmatch.c */
extern Bool netmatch(IPaddr dst, IPaddr net, IPaddr mask, Bool islocal);
/* netnum.c */
extern IPaddr netnum(IPaddr ipa);
/* netstart.c */
extern int netstart(int userpid);
extern int gateway_question(void);
extern void netconfig(void);
extern void nifdump(int i);
/* netwrite.c */
extern int netwrite(struct netif *pni, struct ep *pep, int len);
/* ni_in.c */
extern int ni_in(struct netif *pni, struct ep *pep, int len);
/* othinit.c */
/* othwrite.c */
/* rarp_in.c */
extern int rarp_in(struct netif *pni, struct ep *packet);
/* rarpsend.c */
extern int rarpsend(int ifn);
/* setmask.c */
extern int setmask(int inum, IPaddr mask);
/* slowtimer.c */
extern int slowtimer(void);
/* tftp.c */
extern int tftp_get(char *Addr, char *filename, unsigned char *buf, int buflen);
extern int tftp_put(char *Addr, char *filename, unsigned char *buf, int buflen);
#endif /* _NETWORK_H_ */
