/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _PPP_H_
#define _PPP_H_

#include <ether.h>
#include <netif.h>
#include <modemchat.h>

/* HDLC protocols */

#define PPP_IP		0x0021
#define PPP_IPCP	0x8021
#define PPP_LCP		0xC021
#define PPP_PAP		0xC023
#define PPP_LQR		0xC025
#define PPP_CHAP	0xC223
#define PPP_CCP		0x80fd

/* LCP */

#define LCP_DEFAULT_MRU	1500

struct ppplcp {
	unsigned char Code;
	unsigned char Id;
	unsigned short Length;
	unsigned char Data[1];
	};

#define LCP_Configure_Request	1

struct lcp_cr_anon {
	unsigned char	Type;
	unsigned char	Length;
	};

#define LCP_CR_Maximum_Receive_Unit		1

struct lcp_cr_mru {
	unsigned char	Type;
	unsigned char	Length;
	unsigned short	MRU;
	};

#define LCP_CR_Async_Control_Character_Map	2

struct lcp_cr_accm {
	unsigned char	Type;
	unsigned char	Length;
	unsigned long	ACCM;
	};

#define LCP_CR_Authentication_Protocol		3

struct lcp_cr_auth {
	unsigned char	Type;
	unsigned char	Length;
	unsigned short	AP;
	unsigned char	Data[1];
	};

#define LCP_CR_Quality_Protocol			4

struct lcp_cr_qual {
	unsigned char	Type;
	unsigned char	Length;
	unsigned short	QP;
	unsigned char	Data[1];
	};

#define LCP_CR_Magic_Number			5

struct lcp_cr_magic {
	unsigned char	Type;
	unsigned char	Length;
	unsigned long	MAGICNUM;
	};

#define LCP_CR_Protocol_Field_Compression	7

struct lcp_cr_pfc {
	unsigned char	Type;
	unsigned char	Length;
	};

#define LCP_CR_Address_and_Control_Field_Compression	8

struct lcp_cr_acfc {
	unsigned char	Type;
	unsigned char	Length;
	};

#define LCP_CR_FCS_Alternatives			9
#define 	LCP_CR_FA_Null		1
#define 	LCP_CR_FA_CCITT16	2
#define 	LCP_CR_FA_CCITT32	4
#define LCP_CR_Self_Describing_Pad		10
#define LCP_CR_Numbered_Mode			11
#define LCP_CR_Multi_Link_Proceedure		12
#define LCP_CR_Callback				13

struct lcp_cr_callback {
	unsigned char	Type;
	unsigned char	Length;
	unsigned char	Operation;
	unsigned char	Message[1];
	};

#define LCP_CR_Connect_Time			14
#define LCP_CR_Compound_Frames			15
#define LCP_CR_Nominal_Data_Encapsulation	16
#define LCP_CR_Multilink_MRRU			17

struct lcp_cr_mrru {
	unsigned char	Type;
	unsigned char	Length;
	unsigned short	MRRU;
	};

#define LCP_CR_Multilink_Short_Sequence_Number_Header_Format	18
#define LCP_CR_Multilink_Endpoint_Discriminator	19

#define LCP_Configure_Ack	2
#define LCP_Configure_Nack	3
#define LCP_Configure_Reject	4
#define LCP_Terminate_Request	5
#define LCP_Terminate_Ack	6
#define LCP_Code_Reject		7
#define LCP_Protocol_Reject	8

struct lcp_prot_reject {
	unsigned char	Code;
	unsigned char	Id;
	unsigned short	Length;
	unsigned short	Protocol;
	unsigned char	Information[1];
	};

#define LCP_Echo_Request	9

struct lcp_echo {
	unsigned char	Code;
	unsigned char	Id;
	unsigned short	Length;
	unsigned long	Magic;
	unsigned char	Data[1];
	};

#define LCP_Echo_Reply		10
#define LCP_Display_Request	11
#define LCP_Identification	12
#define LCP_Time_Remaining	13

/* lcpflags */
#define PPP_LCP_SENT_ACK 0x01
#define PPP_LCP_RECV_ACK 0x02
#define PPP_LCP_PFC	 0x04
#define PPP_LCP_ACFC	 0x08


/* IPCP */

struct pppipcp {
	unsigned char Code;
	unsigned char Id;
	unsigned short Length;
	unsigned char Data[1];
	};

#define IPCP_Configure_Request		1

struct ipcp_cr_anon {
	unsigned char	Type;
	unsigned char	Length;
	};

#define IPCP_IP_Addresses			1	/* Deprecated */

#define IPCP_IP_Compression_Protocol		2

struct ipcp_cr_comp {
	unsigned char	Type;
	unsigned char	Length;
	unsigned short	Protocol;
	unsigned char	Data[1];
	};

#define IPCP_IP_Address				3

struct ipcp_cr_addr {
	unsigned char	Type;
	unsigned char	Length;
// MCB L92	unsigned long	IPaddr;
	unsigned long	IP_addr;
	};

#define IPCP_Primary_DNS_Address		0x81
#define IPCP_Primary_NBNS_Address		0x82
#define IPCP_Secondary_DNS_Address		0x83
#define IPCP_Secondary_NBNS_Address		0x84


#define IPCP_Configure_Ack		2
#define IPCP_Configure_Nack		3
#define IPCP_Configure_Reject		4
#define IPCP_Terminate_Request		5
#define IPCP_Terminate_Ack		6
#define IPCP_Terminate_Nack		7
#define IPCP_Code_Reject		8

/* ipcpflags */
#define PPP_IPCP_SENT_ACK 0x01
#define PPP_IPCP_RECV_ACK 0x02

/* PAP */

struct ppppap {
	unsigned char Code;
	unsigned char Id;
	unsigned short Length;
	unsigned char Data[1];
	};

#define PAP_Authenticate_Request	1
#define PAP_Authenticate_Ack		2
#define PAP_Authenticate_Nack		3

/* papflags */
#define PPP_PAP_SENT_ACK	0x01
#define PPP_PAP_RECV_ACK	0x02
#define PPP_PAP_NEED_SENT_ACK	0x03
#define PPP_PAP_NEED_RECV_ACK	0x04

/* PPP State Management */

#include <pppconf.h>

typedef enum { DEAD=1, ESTABLISH=2, AUTHENTICATE=3,
		NETWORK=4, TERMINATE=5} pppphase;

struct pppstate {
	struct pppconf	*pppconf;
	pppphase	phase;
	int		serdev;
	int		hdlcdev;
	unsigned char	lcpflags;
	unsigned char	papflags;
	unsigned char	ipcpflags;
	unsigned long	Magic;
	IPaddr		peerIP;
	struct netif	*nif;
	};

/* lcp.c */
extern void lcp_in(struct pppstate *ppp,struct ep *pep);
extern void lcp_do_protocol_reject(struct pppstate *ppp,struct ep *pep);
extern int lcptimer(struct pppstate *ppp);
/* pap.c */
extern void pap_in(struct pppstate *ppp,struct ep *pep);
extern int paptimer(struct pppstate *ppp);
/* ipcp.c */
extern void ipcp_in(struct pppstate *ppp,struct ep *pep);
extern int ipcptimer(struct pppstate *ppp);
/* pppinproc.c */
extern int pppin(struct pppconf *pppconf,struct netif *pnif, int serdev, int hdev);
/* pppinit.c */
extern void ppp_init(int dev, struct pppconf *pppconf);
/* pppinproc.c */
extern struct pppstate pppstate;
/* pppstates.c */
int ppp_dead(struct pppstate *ppp);
int ppp_establish(struct pppstate *ppp);
int ppp_authenticate(struct pppstate *ppp);
int ppp_network(struct pppstate *ppp);
int ppp_terminate(struct pppstate *ppp);
/* ../ppp/pppsend.c */
extern int ppp_send(struct netif *pni, struct ep *pep);


#endif /* _PPP_H_ */
