/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _PPPCONF_H_
#define _PPPCONF_H_



typedef enum PPP_MODE_E
{
	DCC_CLIENT,
	DCC_SERVER,
	DIALUP_CLIENT,
	DIALUP_SERVER
} PPP_MODE_E;



/** @memo The pppconf structure.
 * @doc This structure is used to hold the settings for a PPP connection.
 * @name pppconf
 * @type struct pppconf
 */
struct pppconf {
	/** A string that contains the dotted quad IP address that should be
	 * used for the local end of the connection. A NULL should be used
	 * to indicate that the local IP should be obtained via negotiation
	 * from the other end of the connection.
	 * @type char *
	 */
	char	*myaddress;
	/** A string that is the Peer-ID that will be sent for authentication.
	 * Typically, this will be a username that is used when connecting to
	 * the remote system.
	 * @type char *
	 */
	char	*myuser;
	/** A string that is the password used for authentication. 
	 * @type char *
	 */
	char	*mypassword;
	/** A string that contains the dotted quad IP address that should be
	 * used for the remote end of the connection. A NULL should be used
	 * to indicate that the remote IP should be obtained via negotiation
	 * from the other end of the connection. If a value is specified, the
	 * connection will only be established if the remote end negotiates the
	 * same address.
	 * @type char *
	 */
	char	*peeraddress;
	/** A value that specifies the authentication protocol to use. A value
	 * of 0 means that no authentication is required by the remote end.
	 * Typical values would be PPP_PAP or PPP_CCP (Note the PPP_CCP is not
	 * implemented yet).
	 * @type unsigned short
	 */
	unsigned short 	auth;
	/** The Maximun Receive Unit (MRU) specifies the largest packet size
	 * that can be received.
	 * @type int
	 */
	int 	MRU;
	/** A 32 bit value that specifies which control characters must be
	 * escaped when transmitted over the data link. Each bit represents
	 * the value equal to the position of the bit that is set.
	 * @type unsigned long
	 */
	unsigned long ACCM;
	/** The length of time to wait between configuration packets when no
	 * response is received. The default value should be 3 (seconds).
	 * @type int
	 */
	int	LCPTimer;
	/** The maximum number of timeouts allowed during LCP negotiation
	 * before the connection is marked as dead.  The default value should
	 * be 15.
	 * @type int
	 */
	int	LCPMaxTimeouts;
	/** The number of times a Termination Request packet is sent and
	 * unanswered after which the link is assumed to be dead.
	 * @type int
	 */
	int	LCPMaxTerminate;
	/** The number of times a Configuration Request packet is sent and
	 * unanswered before the connection is terminated.
	 * @type int
	 */
	int	LCPMaxConfigure;
	/** A string that contains the dotted quad IP address of the secondary
	 * DNS server that we are offering to provide to the peer.  A NULL
	 * should be used to indicate that we do not have a secondary DNS server
	 * address to offer.  NOTE: The Primary DNS server that will be offered
         * if requested will be retrieved from the Bootrecord.
	 * @type char *
	 */
	char	*offerSecondaryDNS;
	/** A string that contains the dotted quad IP address of the primary
	 * NBNS server that we are offering to provide to the peer.  A NULL
	 * should be used to indicate that we do not have a primary NBNS server
	 * address to offer.
	 * @type char *
	 */
	char	*offerPrimaryNBNS;
	/** A string that contains the dotted quad IP address of the secondary
	 * NBNS server that we are offering to provide to the peer.  A NULL
	 * should be used to indicate that we do not have a secondary NBNS 
	 * server * address to offer.
	 * @type char *
	 */
	char	*offerSecondaryNBNS;
	/** A boolean that indicates whether debug messages should be displayed
	 * on the console.
	 * @type Bool
	 */
	Bool	debug;
	/** The Mode field indicates the current operating mode of PPP:
	 *		Dial up Client              => Uses a modem to call a service provider.
	 * 	Dial up Server 		       => Answers incoming modem calls to provide service to a remote client.
	 *    Direct Cable Connect Client => Uses a serial cable to call a service provider.
	 * 	Direct Cable Connect Server => Provides services to a remote client using a serial cable.
	 * The PPP operating mode also determines which of the fields in this structure are used.
	 * @type unsigned char
	 */
	unsigned char	ppp_mode;
	/** Flag to indicate if the PPPP client should request a Primary DNS address from the remote host.
	 * This flag should only be set if PPP is operating in DCC_CLIENT or DIALUP_CLIENT mode.  Note that
	 * if the eZ80 has an active Ethernet interface, setting this flag to 1 will cause PPP to override 
	 * the default name server address with the value specified by the remote host.  Once PPP disconnects
	 * the original Name Server address is restored.  If the eZ80 is operating in Client mode without an
	 * Ethenet interface, then this flag should be set to 1.
	 * FInally, please note that not all hosts are capable of providing a primary DNS address.  In this case
	 * PPP will restore the original Name Server address.
	 * @type unsigned char
	 */
	unsigned char 	use_peer_dns;
	/**
	 * Flag to indicate if IPWorks will enable non-local routing.  This flag should only be set to 1 if PPP
 	 * is operating in Server mode; allowing the PPP client to access the Internet through the eZ80.  Note
	 * however, if the eZ80 operating in Server mode does not have an Ethernet interface, then the PPP client
	 * will not be able to access the network even if routing is enabled.  Also, please be aware that even 
	 * when routing is enable by setting this flag to a 1, the eZ80 is not a full-blown router and does not
	 * participate in any network routing protocols.
	 * @type unsigned char
	 */
	unsigned char 	enable_routing;
	/**
	 * Flag to indicate if the default routing table entry should be assign to the PPP interface once it is
	 * connected.  If this flag is set to 1, then the default route will be changed from Ethernet to PPP
	 * once PPP establishes a connection.  The default route will be restored to its previous value once PPP
	 * disconnects.  This flag should always be set to 1 if PPP isoperating in Client mode without an Ethernet
	 * interface.
	 * @type unsigned char	 	 
	 */
	unsigned char 	ppp_is_default_route;
	/**
	 * Flag to indicate if PPP should automatically attempt to reconnect to the peer once PPP disconnects.
	 * If this flag is set to 1 then PPP will always re-attempt a connection after a diconnect event.
	 * If this flag is set to a 0, then PPP will not reconnect until the "ppp_resume" command is entered on the 
	 * console or until the ppp_resume() function is called.
	 * @type unsigned char	 	 
	 */
	unsigned char  do_auto_reconnect;

	struct modemchat *	chat;
	int 	nchat;
	};

/** @memo The authpair structure.
 * @doc This structure is used to hold the ID / Password pairs that IPWorks
 * will compare incoming authentication requests against.
 * @name authpair
 * @type struct 
 */
struct authpair  {
	/** The ID to be authenticated.
	 * @type char *
	 */
	char *id;
	/** The password that goes with this ID.
	 * @type char *
	 */
	char *passwd;
};
#endif /* _PPPCONF_H_ */
