/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
/* shell.h */
#ifndef _SHELL_H_
#define _SHELL_H_

#include <mark.h>
#include <cmd.h>
#include <stdlib.h>


/* Declarations for the Xinu shell */

#define	SHEXIT		-5		/* shell exit return		*/
#define	SHNAMLEN	9		/* length of user name + 1	*/
#define	SHBUFLEN	80		/* length of general buffer	*/
#define	SHARGLEN	82		/* length of area for arguments	*/
#define	SHMAXTOK	16		/* maximum tokens per line	*/
#define	SHMLEN		64		/* maximum length of mach. name	*/
#define	SHCMDSTK	8192		/* size of command proc. stack	*/
#define	SHCMDPRI	50		/* command process priority	*/

// MCB L92 #define SHLLSTK		2048
#define SHLLSTK		4096
#define SHLLPRI		20
#define SHLLNAM		"shell"

struct	shvars	{			/* shell variables		*/
	unsigned long shlast;		/* time shell last touched	*/
	unsigned long shlogon;		/* time user logged on		*/
	MARKER	shmark;			/* marked if shused valid	*/
	Bool	shused;			/* TRUE => user using shell	*/
	char	shuser[SHNAMLEN];	/* current user name		*/
	char	shmach[SHMLEN];		/* name of this machine		*/
	char	shbuf[SHBUFLEN];	/* general purpose buffer	*/
	char	*shtok[SHMAXTOK];	/* pointers to input tokens	*/
	char	shtktyp[SHMAXTOK];	/* type of token in shtok[i]	*/
	char	shargst[SHARGLEN];	/* actual strings of arguments	*/
};
typedef int	(* SHELL_CMD)(struct shvars *,	int stdin, int stdout, int stderr,int nargs, char *args );

/* addarg.c */
extern int addarg(struct shvars *Shl, int pid, int nargs, int len);
/* ascdate.c */
extern int ascdate(long time, char *str);
/* bootp.c */
extern int bootp(void);
#ifdef _not_yet
extern int parse_bootp(struct boot_type *tmp);
extern int parse_vendor(char vendor[]);
extern int printbootp(struct boot_type *tmp);
#endif
/* lexan.c */
extern int lexan(struct shvars *Shl, char *line);
/* login.c */
extern int login(struct shvars *Shl, int dev);
/* netcmds.c */
extern struct cmdent	netcmds[];
extern int	nnetcmds;
/* shell.c */
extern int shell(int dev);
extern struct cmdent *ShellCommands;
extern void shell_add_commands(struct cmdent *cmds, int ncmds);
extern int shell_init(int dev);
/* shell_conf.c */
extern struct cmdent	defaultcmds[];
extern int	ndefaultcmds;
/* x_arp.c */
extern int x_arp(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_boot.c */
extern int x_boot(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_bpool.c */
extern int x_bpool(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_cat.c */
extern int x_cat(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_close.c */
extern int x_close(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_conf.c */
extern int x_conf(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
extern char *FindName(char *strIP);
/* x_cp.c */
extern int x_cp(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_create.c */
extern int x_creat(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_date.c */
extern int x_date(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_devs.c */
extern int x_devs(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_dg.c */
extern int x_dg(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_dumper.c */
extern int x_dumper(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
extern int summary(int stdout);
/* x_echo.c */
extern int x_echo(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_exit.c */
extern int x_exit(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_finger.c */
extern int x_finger(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
extern int rfing(char *user, char *rhost, int stdout, int stderr);
extern int lfing(char *nam, int output);
/* x_hang.c */
extern int x_hang(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_help.c */
extern int x_help(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_ifstat.c */
extern int x_ifstat(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_igmp.c */
extern int x_igmp(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_kbuf.c */
extern int x_kbuf(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_kill.c */
extern int x_kill(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_mail.c */
extern int x_mail(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_mem.c */
extern int x_mem(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_mount.c */
extern int x_mount(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_mv.c */
extern int x_mv(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_net.c */
extern int x_net(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_ns.c */
extern int x_ns(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_ospf.c */
extern int x_ospf(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_ping.c */
extern int x_ping(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_port.c */
extern int x_port(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_pppopt.c */
extern int x_pppopt(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_pppstat.c */
extern int x_pppstat(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_ps.c */
extern int x_ps(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_reboot.c */
extern int x_reboot(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_rf.c */
extern int x_rf(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_rls.c */
extern int x_rls(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_rm.c */
extern int x_rm(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_route.c */
extern int x_route(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_routes.c */
extern int x_routes(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_sem.c */
extern int x_sem(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_set.c */
extern int x_set(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
extern int debug_level(char *option);
/* x_sleep.c */
extern int x_sleep(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_tftpdemo.c */
extern int x_tftpdemo(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_snap.c */
extern int x_snap(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_snmp.c */
extern int x_snmp(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_timerq.c */
extern int x_timerq(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_udplisten.c */
extern int x_udplisten(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_udpping.c */
extern int x_udpping(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_unmou.c */
extern int x_unmou(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
/* x_uptime.c */
extern int x_uptime(struct shvars *Shl, int stdin, int stdout, int stderr, int nargs, char *args[]);
extern int rwcomp(int *px, int *py);
/* x_who.c */
extern int x_who(struct shvars *Shl, int stdin, int stdout, int stderr);

#endif
