/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _snmp_h_
#define _snmp_h_
/* snmp.h - strequ */
#include <snmpstr.h>
#include <mib.h>

#define	SNMPD		snmpd		/* SNMP server code 		*/
extern  int     	SNMPD(void);	/* SNMP server daemon 		*/
#define	SNMPSTK		8000		/* SNMP server stack size 	*/
#define	SNMPPRI		20		/* SNMP server priority 	*/
#define SNMPDNAM	"snmpd"		/* SNMP server daemon name 	*/

/* strequ - return TRUE if strings x and y are the same			*/
#define	strequ(x,y)	(strcmp((x), (y)) == 0)	

#define	u_char		unsigned char

/* Functions to access parts of the above snval structure		*/
#define SVTYPE(bl)	((bl)->sb_val.sv_type)
#define SVINT(bl)	((bl)->sb_val.sv_val.sv_int)
#define SVUINT(bl)	((bl)->sb_val.sv_val.sv_uint)
#define SVSTR(bl)	((bl)->sb_val.sv_val.sv_str.sv_str)
#define SVSTRLEN(bl)	((bl)->sb_val.sv_val.sv_str.sv_len)
#define SVOID(bl)	((bl)->sb_val.sv_val.sv_oid.id)
#define SVOIDLEN(bl)	((bl)->sb_val.sv_val.sv_oid.len)
#define SVIPADDR(bl)	(&((bl)->sb_val.sv_val.sv_ipaddr))


/* Structure that holds a complete description of an SNMP request 	*/
struct req_desc {
	u_char	reqtype;		/* request type			*/
	u_char	reqid[10];		/* request identifier		*/
	int	reqidlen;		/* length of the identifier	*/
	u_char	err_stat;		/* error status			*/
	u_char	err_idx;		/* error index			*/
	int	err_stat_pos;		/* position of error status in	*/
					/* the ASN.1 encoding		*/
	int	err_idx_pos;		/* position of error index	*/
	int	pdutype_pos;		/* position of pdu type		*/
	struct 	snbentry *bindlf;	/* front of bindings list	*/
	struct	snbentry *bindle;	/* end of bindings list 	*/
};

#define SNMPMAXSZ	U_MAXLEN 	/* max SNMP request size	*/
#define SNMPPORT	161		/* SNMP server UDP port		*/

/* SNMP error types							*/
#define SNMP_OK		0		/* no error			*/
#define	SERR_TOO_BIG	1		/* reply would be too long 	*/
#define SERR_NO_SUCH 	2		/* no such object id exists	*/
#define SERR_BAD_VALUE	3		/* bad value in a set operation	*/

#define SVERS_LEN	1		/* SNMP version is 1 byte long	*/
#define SVERSION	0		/* current SNMP version		*/

#define SCOMM_STR	"public"	/* SNMP community string	*/

/* operations to be applied to an SNMP object 				*/
#define	SOP_GET		1		/* get operation 		*/
#define SOP_GETN	2		/* getnext operation		*/
#define SOP_GETF	3		/* get first operation		*/
#define SOP_SET		4		/* set operation		*/

/* standard version and community string -- backwards */
static char SNVCBACK[] = {
	'c', 'i', 'l', 'b', 'u', 'p', 0x06, 0x04 /* ASN1_OCTSTR */,
	SVERSION, SVERS_LEN, 0x02 /* ASN1_INT */
};
#define SNVCLEN 	sizeof(SNVCBACK) /* length of SNVCBACK 		*/

/* SNMP client return codes						*/
#define SCL_OK		0	/* good response -- no errors 		*/
#define SCL_OPENF	1	/* open fails 				*/
#define SCL_WRITEF	2	/* write fails 				*/
#define SCL_NORESP	3	/* no response from server		*/
#define SCL_READF	4	/* read fails				*/
#define SCL_BADRESP	5	/* bad response				*/
#define SCL_BADREQ	6	/* bad request				*/

/* Table specific constants						*/
#define SNUMF_AETAB	5	/* 5 fields in an Addr Entry 		*/
#define SNUMF_ATTAB	3	/* 3 fields in an Addr Transl. Entry	*/
#define SNUMF_IFTAB	21	/* 21 fields in an Interface Entry	*/
#define SNUMF_RTTAB	13	/* 13 fields in a Route Table Entry	*/
#define SNUMF_TCTAB	5	/* 5 fields in a TCP Connection Entry	*/
#define SNUMF_NMTAB	4	/* 4 fields in a IP NetToMedia Entry    */
#define SNUMF_UETAB	2	/* 4 fields in a UDP Entry */

#define	SAE_OIDLEN	3	/* all sae variables start with 4.20.1	*/
#define SAT_OIDLEN	3	/* all sat variables start with 3.1.1	*/
#define SIF_OIDLEN	3	/* all sif variables start with 2.2.1	*/
#define SNM_OIDLEN	3	/* all snm variables start with 4.22.1	*/
#define SRT_OIDLEN	3	/* all srt variables start with 4.21.1	*/
#define STC_OIDLEN	3	/* all stc variables start with 6.13.1	*/
#define SUE_OIDLEN	3	/* all sue variables start with 7.5.1	*/

/* a1rwint.c */
extern int32_t a1readint(unsigned char *pack, int len);
extern int a1writeint(int32_t val, unsigned char *buffp, int a1type);
extern uint32_t a1readuint(unsigned char *pack, int len);
extern int a1writeuint(uint32_t val, unsigned char *buffp, int a1type);
/* a1rwlen.c */
extern int a1readlen(unsigned char *pack, int *lenlen);
extern int a1writelen(unsigned char *pp, int len);
/* a1rwoid.c */
extern int a1readoid(unsigned char *pack, int objidlen, struct oid *objid);
extern int a1writeoid(unsigned char *packp, struct oid *oidp, Bool full);
/* a1rwval.c */
extern int a1readval(struct snval *val, int type, int vallen, unsigned char *pack);
extern int a1writeval(struct snbentry *bl, unsigned char *bp);
/* mksnmp.c */
extern int mksnmp(struct req_desc *rqdp, unsigned char *snmppack, int pdutype);
/* sae_findn.c */
extern int sae_findnext(int iface, int numifaces);
/* sae_get.c */
extern int sae_get(struct snbentry *bindl, int numifaces);
/* sae_getf.c */
extern int sae_getf(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sae_getn.c */
extern int sae_getn(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sae_match.c */
extern int sae_match(struct snbentry *bindl, int *iface, int *field, int numifaces);
/* sae_set.c */
extern int sae_set(void);
/* sat_findn.c */
extern int sat_findnext(int entry, int iface);
/* sat_get.c */
extern int sat_get(struct snbentry *bindl, int numifaces);
/* sat_getf.c */
extern int sat_getf(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sat_getn.c */
extern int sat_getn(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sat_match.c */
extern int sat_match(struct snbentry *bindl, int *iface, int *entry, int *field, int numifaces);
/* sat_set.c */
extern int sat_set(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sif_get.c */
extern int sif_get(struct snbentry *bindl, int numifaces);
/* sif_getf.c */
extern int sif_getf(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sif_getn.c */
extern int sif_getn(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sif_match.c */
extern int sif_match(struct snbentry *bindl, int *iface, int *field, int numifaces);
/* sif_set.c */
extern int sif_set(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sna2b.c */
extern int sna2b(struct req_desc *rqdp);
/* snb2a.c */
extern void snb2a(struct req_desc *rqdp);
/* snclient.c */
extern int snclient(struct req_desc *rqdp, char *fport, int stdout);
/* snerr.c */
extern int snerr(int stdout, struct req_desc *rqdp);
/* snfreebl.c */
extern int snfreebl(struct snbentry *bl);
/* snhash.c */
extern struct mib_info *getmib(struct oid *oip);
extern int hashoid(struct oid *oip);
extern int hashinit(void);
/* sninit.c */
extern int sninit(void);
/* snleaf.c */
/* snm_get.c */
extern int snm_get(struct snbentry *bindl, int numifaces);
/* snm_getf.c */
extern int snm_getf(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* snm_getn.c */
extern int snm_getn(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* snm_match.c */
extern int snm_match(struct snbentry *bindl, int *iface, int *entry, int *field, int numifaces);
/* snm_findn.c */
extern int snm_findnext(int entry, int iface);
/* snm_set.c */
extern int snm_set(struct snbentry *bindl, struct mib_info *mip, int numifaces);
extern int snleaf(struct snbentry *bindl, struct mib_info *mip, int op,int ccbug);
/* snmpinit.c */
extern void snmp_init(void);
/* snoip.c */
extern int sip2ocpy(u_short *oidp, IPaddr pip);
extern int so2ipcpy(IPaddr *pip, u_short *oidp);
extern int soipequ(u_short *oidp, IPaddr pip, int len);
/* snparse.c */
extern int snparse(struct req_desc *rqdp, unsigned char *snmppack, int len);
/* snprint.c */
extern int snmpprint(int stdout, struct snbentry *bindl);
extern int snmpprint_val(int stdout, struct snval *val);
extern int snmpprint_objid(int stdout, struct oid *objidp);
extern int snmpprint_objname(int stdout, struct oid *oip);
extern void snmpprint_req(int stdout, struct req_desc *rdp);
/* snrslv.c */
extern int snrslv(struct req_desc *rqdp);
/* sntable.c */
extern int sntable(struct snbentry *bindl, struct mib_info *mip, int op,int ccbug);
/* srt_findn.c */
extern struct route *srt_findnext(struct route *rtp, int *rtl);
/* srt_get.c */
extern int srt_get(struct snbentry *bindl, int numifaces);
/* srt_getf.c */
extern int srt_getf(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* srt_getn.c */
extern int srt_getn(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* srt_match.c */
extern int srt_match(struct snbentry *bindl, struct route **rtp, int *rtl, int *field);
/* srt_set.c */
extern int srt_set(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* stc_findn.c */
extern int stc_findnext(int tcbn);
/* stc_get.c */
extern int stc_get(struct snbentry *bindl);
/* stc_getf.c */
extern int stc_getf(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* stc_getn.c */
extern int stc_getn(struct snbentry *bindl, struct mib_info *mip);
/* stc_match.c */
extern int stc_match(struct snbentry *bindl, int *field, int *tcbn);
/* stc_set.c */
extern int stc_set(struct snbentry *bindl, struct mib_info *mip);
/* sue_findn.c */
extern int sue_findnext(int dgn);
/* sue_get.c */
extern int sue_get(struct snbentry *bindl);
/* sue_getf.c */
extern int sue_getf(struct snbentry *bindl, struct mib_info *mip, int numifaces);
/* sue_getn.c */
extern int sue_getn(struct snbentry *bindl, struct mib_info *mip);
/* sue_match.c */
extern int sue_match(struct snbentry *bindl, int *field, int *dgn);
/* sue_set.c */
extern int sue_set(struct snbentry *bindl, struct mib_info *mip);
#endif
