/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */

#ifndef _SOAP_H
#define _SOAP_H

#include "httpd.h"
#include "upnp.h"

extern struct header_rec soapheaders[];
extern Http_Method soap_methods[];

int soap_init(Upnp_Device **devices,Http_Method *methods,struct header_rec *headers, Webpage *webpages,int port);

char *soap_get_action_name(Soap_Request *request);
void soap_send_action_response(Soap_Request *request, Http_Params *return_args);
void soap_send_query_response(Soap_Request *request, char *value);
void soap_send_action_failure(Soap_Request *request, char *code, char *message);

/*  User routines to allocate space for large values in soap action args. */
/** 
 *  @memo Routine to allocate a larger buffer for receiving SOAP requests.
 *  @doc If an application needs a large space for the data in a SOAP request,
 *  for example, if an argument to the request is the contents of a file, the
 *  user should set this pointer to the routine which will allocate the extra
 *  space.  The standard space is slightly under 1000 bytes.
 *  @return A pointer to the space, or NULL if the space could not be
 *  allocated.
 */
extern void *(*soap_alloc_buffer)(int size);

/**
 *  @memo Routine corresponding to the soap_alloc_buffer() routine.
 *  @doc This user defined routine should free the space allocated by the
 *  original call.  The allocation and free routines are called within a lock,
 *  so the user can expect that they will be called in pairs.  This may
 *  alleviate a need to actually free the space if the user has completed its
 *  use of that space.  If there is no need for freeing the space, this routine
 *  can be left as NULL.
 *  @param space The space returned by the allocation routine.
 */
extern void (*soap_free_buffer)(void *space);

/** The action id for a query state variable */
#define SOAP_QUERY_STATE_VARIABLE -1

/** @memo Get the action id associated with this soap request.
 *  @doc Returns the action id of the action which was called, or a '-1' if
 *  this is a call to query state variable.  This action id corresponds to the
 *  actionid field of the Upnp_Action structure matched by this SOAP action.
 *  @type int
 *  @args (Soap_Request *request)
 */
#define soap_get_actionid(r) r->action->actionid
/** @memo Get the name of the variable in a QueryStateVariable request.
 *  @doc Returns a the 'varName' field of the xml sent from a control point.
 *  @type char *
 *  @args (Soap_Request *request)
 */
#define soap_get_query_state_variable(r) http_find_param(r->arguments, "varName")
/** @memo Get the value associated with the specified argument name.
 *  @doc Returns the string value of the argument.
 *  @type char *
 *  @args (Soap_Request *request, char *arg_name)
 */
#define soap_get_action_argument(r, name) http_find_param(r->arguments, name)
/** @memo Get the user_data.
 *  @doc Returns the user data which was associated with the service to which
 *  this request belongs.  It is the user_data field of the Upnp_Service
 *  struct.
 *  @type void *
 *  @args (Soap_Request *request)
 */
#define soap_get_user_data(r) r->service->user_data

#endif
