/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _TCB_H_
#define _TCB_H_
/* tcb.h */

#include <tcp.h>
#include <tcpfsm.h>

/* TCP endpoint types */

#define	TCPT_SERVER		1
#define	TCPT_CONNECTION		2
#define	TCPT_MASTER		3

/* TCP process info */
#define	TCPISTK		1024		/* stack size for TCP input	*/
#define	TCPIPRI		100		/* TCP runs at high priority	*/
#define	TCPINAM		"tcpinp"	/* name of TCP input process	*/
#define	TCPIARGC	0		/* count of args to tcpin 	*/

#define	TCPOSTK		1024		/* stack size for TCP output	*/
#define	TCPOPRI		100		/* TCP runs at high priority	*/
#define	TCPONAM		"tcpout"	/* name of TCP output process	*/
#define	TCPOARGC	0		/* count of args to tcpout 	*/

#define	TCPIQLEN	20		/* TCP input process port queue len */
#define	TCPOQLEN	Ntcp*NTCPEVENTS	/* TCP output process port queue len */

/* TCP exceptional conditions */

#define	TCPE_RESET		-1
#define	TCPE_REFUSED		-2
#define	TCPE_TOOBIG		-3
#define	TCPE_TIMEDOUT		-4
#define	TCPE_URGENTMODE		-5
#define	TCPE_NORMALMODE		-6

/* string equivalents of TCPE_*, in "tcpswitch.c" */
extern	char	*tcperror[];

#define	READERS		1
#define	WRITERS		2

/* tcb_flags */

#define	TCBF_NEEDOUT	0x01	/* we need output			*/
#define	TCBF_FIRSTSEND	0x02	/* no data to ACK			*/
#define	TCBF_GOTFIN	0x04	/* no more to receive			*/
#define	TCBF_RDONE	0x08	/* no more receive data to process	*/
#define	TCBF_SDONE	0x10	/* no more send data allowed		*/
#define	TCBF_DELACK	0x20	/* do delayed ACK's			*/
#define	TCBF_BUFFER	0x40	/* do TCP buffering (default no)	*/
#define	TCBF_PUSH	0x80	/* got a push; deliver what we have	*/
#define	TCBF_SNDFIN	0x100	/* user process has closed; send a FIN	*/
#define	TCBF_RUPOK	0x200	/* receive urgent pointer is valid	*/
#define	TCBF_SUPOK	0x400	/* send urgent pointer is valid		*/

/* aliases, for user programs */

#define	TCP_BUFFER	TCBF_BUFFER
#define	TCP_DELACK	TCBF_DELACK

/* receive segment reassembly data */

#define	NTCPFRAG	10

struct tcb {
	short	tcb_state;	/* TCP state				*/
	short	tcb_ostate;	/* output state				*/
	short	tcb_type;	/* TCP type (SERVER, CLIENT)		*/
	int	tcb_mutex;	/* tcb mutual exclusion			*/
	short	tcb_code;	/* TCP code for next packet		*/
	short	tcb_flags;	/* various TCB state flags		*/
	short	tcb_error;	/* return error for user side		*/

	IPaddr	tcb_rip;	/* remote IP address			*/
	unsigned short tcb_rport;/* remote TCP port			*/
	IPaddr	tcb_lip;	/* local IP address			*/
	short	tcb_lport;	/* local TCP port			*/
	struct	netif	*tcb_pni; /* pointer to our interface		*/

	tcpseq	tcb_suna;	/* send unacked				*/
	tcpseq	tcb_snext;	/* send next				*/
	tcpseq	tcb_slast;	/* sequence of FIN, if TCBF_SNDFIN	*/
	long	tcb_swindow;	/* send window size (octets)		*/
	tcpseq	tcb_lwseq;	/* sequence of last window update	*/
	tcpseq	tcb_lwack;	/* ack seq of last window update	*/
	int	tcb_cwnd;	/* congestion window size (octets)	*/
	int	tcb_ssthresh;	/* slow start threshold (octets)	*/
	int	tcb_smss;	/* send max segment size (octets)	*/
	tcpseq	tcb_iss;	/* initial send sequence		*/

	int	tcb_srt;	/* smoothed Round Trip Time		*/
	int	tcb_rtde;	/* Round Trip deviation estimator	*/
	int	tcb_persist;	/* persist timeout value		*/
	int	tcb_keep;	/* keepalive timeout value		*/
	int	tcb_rexmt;	/* retransmit timeout value		*/
	int	tcb_rexmtcount;	/* number of rexmts sent		*/

	tcpseq	tcb_rnext;	/* receive next				*/
	tcpseq	tcb_rupseq;	/* receive urgent pointer		*/
	tcpseq	tcb_supseq;	/* send urgent pointer			*/

	int	tcb_lqsize;	/* listen queue size (SERVERs)		*/
	int	tcb_listenq;	/* listen queue port (SERVERs)		*/
	struct tcb *tcb_pptcb;	/* pointer to parent TCB (for ACCEPT)	*/
	int	tcb_ocsem;	/* open/close semaphore 		*/
	int	tcb_dvnum;	/* TCP slave pseudo device number	*/

	int	tcb_ssema;	/* send semaphore			*/
	u_char	*tcb_sndbuf;	/* send buffer				*/
	int	tcb_sbstart;	/* start of valid data			*/
	int	tcb_sbcount;	/* data character count			*/
	int	tcb_sbsize;	/* send buffer size (bytes)		*/

	int	tcb_rsema;	/* receive semaphore			*/
	u_char	*tcb_rcvbuf;	/* receive buffer (circular)		*/
	int	tcb_rbstart;	/* start of valid data			*/
	int	tcb_rbcount;	/* data character count			*/
	int	tcb_rbsize;	/* receive buffer size (bytes)		*/
	int	tcb_rmss;	/* receive max segment size		*/
	tcpseq	tcb_cwin;	/* seq of currently advertised window	*/
	int	tcb_rsegq;	/* segment fragment queue		*/
	tcpseq	tcb_finseq;	/* FIN sequence number, or 0		*/
	tcpseq	tcb_pushseq;	/* PUSH sequence number, or 0		*/
};
/* TCP fragment structure */

struct tcpfrag {
	tcpseq	tf_seq;
	int	tf_len;
};
/* TCP control() functions */

#define	TCPC_LISTENQ	0x01	/* set the listen queue length		*/
#define	TCPC_ACCEPT	0x02	/* wait for connect after passive open	*/
#define	TCPC_STATUS	0x03	/* return status info (all, for master)	*/
#define	TCPC_SOPT	0x04	/* set user-selectable options		*/
#define	TCPC_COPT	0x05	/* clear user-selectable options	*/
#define	TCPC_SENDURG	0x06	/* write urgent data			*/

/* global state information */

extern int tcps_oport;	/* Xinu port to start TCP output		*/
extern int tcps_iport;	/* Xinu port to send TCP input packets		*/
extern int tcps_lqsize;	/* default SERVER queue size			*/
extern int tcps_tmutex;	/* tcb table mutex				*/

#ifndef NO_TCPSWITCH_DECLS
extern int (*tcpswitch[])(struct tcb *, struct ep *);
extern int (*tcposwitch[])(int, int);
#endif

extern struct	tcb	tcbtab[];
extern const int Ntcp;

/* tcp_in.c */
extern int tcp_in(struct netif *pni, struct ep *pep);
/* tcpabort.c */
extern int tcpabort(struct tcb *ptcb, int error);
/* tcpacked.c */
extern int tcpacked(struct tcb *ptcb, struct ep *pep);
/* tcpackit.c */
extern int tcpackit(struct tcb *ptcb, struct ep *pepin);
/* tcpcksum.c */
extern unsigned short tcpcksum(struct ep *pep, int len);
/* tcpclosed.c */
extern int tcpclosed(struct tcb *ptcb, struct ep *pep);
/* tcpclosewait.c */
extern int tcpclosewait(struct tcb *ptcb, struct ep *pep);
/* tcpclosing.c */
extern int tcpclosing(struct tcb *ptcb, struct ep *pep);
/* tcpdata.c */
extern int tcpdata(struct tcb *ptcb, struct ep *pep);
/* tcpdemux.c */
extern struct tcb *tcpdemux(struct ep *pep);
/* tcpdodat.c */
extern int tcpdodat(struct tcb *ptcb, struct tcp *ptcp, tcpseq first, int datalen);
/* tcpestablished.c */
extern int tcpestablished(struct tcb *ptcb, struct ep *pep);
/* tcpfin1.c */
extern int tcpfin1(struct tcb *ptcb, struct ep *pep);
/* tcpfin2.c */
extern int tcpfin2(struct tcb *ptcb, struct ep *pep);
/* tcph2net.c */
extern struct tcp *tcph2net(struct tcp *ptcp);
/* tcphowmuch.c */
extern int tcphowmuch(struct tcb *ptcb);
/* tcpidle.c */
extern int tcpidle(int tcbnum, int event);
/* tcpinp.c */
extern int tcpinp(void);
/* tcpiss.c */
extern int tcpiss(void);
/* tcpkick.c */
extern int tcpkick(struct tcb *ptcb);
/* tcpkilltimers.c */
extern int tcpkilltimers(struct tcb *ptcb);
/* tcplastack.c */
extern int tcplastack(struct tcb *ptcb, struct ep *pep);
/* tcplisten.c */
extern int tcplisten(struct tcb *ptcb, struct ep *pep);
/* tcpnet2h.c */
extern struct tcp *tcpnet2h(struct tcp *ptcp);
/* tcpok.c */
extern int tcpok(struct tcb *ptcb, struct ep *pep);
/* tcpopts.c */
extern int tcpopts(struct tcb *ptcb, struct ep *pep);
/* tcpostate.c */
extern int tcpostate(struct tcb *ptcb, int acked);
/* tcpout.c */
extern int tcpout(void);
/* tcppersist.c */
extern int tcppersist(int tcbnum, int event);
/* tcpreset.c */
extern int tcpreset(struct ep *pepin);
/* tcprexmt.c */
extern int tcprexmt(int tcbnum, int event);
/* tcprmss.c */
extern void tcprmss(struct tcb *ptcb, struct ip *pip);
/* tcprtt.c */
extern int tcprtt(struct tcb *ptcb);
/* tcprwindow.c */
extern int tcprwindow(struct tcb *ptcb);
/* tcpsend.c */
extern int tcpsend(int tcbnum, Bool rexmt);
/* tcpsmss.c */
extern int tcpsmss(struct tcb *ptcb, struct tcp *ptcp, char *popt);
/* tcpsndlen.c */
extern int tcpsndlen(struct tcb *ptcb, Bool rexmt, int *poff);
/* tcpswindow.c */
extern int tcpswindow(struct tcb *ptcb, struct ep *pep);
/* tcpswitch.c */
/* tcpsync.c */
extern int tcpsync(struct tcb *ptcb);
/* tcpsynrcvd.c */
extern int tcpsynrcvd(struct tcb *ptcb, struct ep *pep);
/* tcpsynsent.c */
extern int tcpsynsent(struct tcb *ptcb, struct ep *pep);
/* tcptimer.c */
extern int tcptimer(void);
/* tcptimewait.c */
extern int tcptimewait(struct tcb *ptcb, struct ep *pep);
/* tcpwait.c */
extern int tcpwait(struct tcb *ptcb);
/* tcpwakeup.c */
extern int tcpwakeup(int type, struct tcb *ptcb);
/* tcpwinit.c */
extern void tcpwinit(struct tcb *ptcb, struct tcb *newptcb, struct ep *pep);
/* tcpxmit.c */
extern int tcpxmit(int tcbnum, int event);
/* tfcoalesce.c */
extern int tfcoalesce(struct tcb *ptcb, int datalen, struct tcp *ptcp);
/* tfinsert.c */
extern int tfinsert(struct tcb *ptcb, tcpseq seq, int datalen, int gotfin);
/* tmclear.c */
extern int tmclear(int port, int msg);
/* tmleft.c */
extern int tmleft(int port, int msg);
/* tmset.c */
extern int tmset(int port, int portlen, int msg, int time);
/* tqdump.c */
extern void tqdump(void);
extern int tqwrite(int stdout);
#endif /* _TCB_H_ */
