/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _TCP_H_
#define _TCP_H_
/* tcp.h - TCP_HLEN, SEQCMP */

typedef	long	tcpseq;

/*
 * SEQCMP - sequence space comparator
 *	This handles sequence space wrap-around. Overlow/Underflow makes
 * the result below correct ( -, 0, + ) for any a, b in the sequence
 * space. Results:	result	implies
 *			  - 	 a < b
 *			  0 	 a = b
 *			  + 	 a > b
 */
#define	SEQCMP(a, b)	((a) - (b))

/* tcp packet format */

struct tcp {
	unsigned short	tcp_sport;	/* source port			*/
	unsigned short	tcp_dport;	/* destination port		*/
		 tcpseq	tcp_seq;	/* sequence			*/
		 tcpseq	tcp_ack;	/* acknowledged sequence	*/
	unsigned char	tcp_offset;
	unsigned char	tcp_code;	/* control flags		*/
	unsigned short	tcp_window;	/* window advertisement		*/
	unsigned short	tcp_cksum;	/* check sum			*/
	unsigned short	tcp_urgptr;	/* urgent pointer		*/
	unsigned char	tcp_data[1];
};

/* TCP Control Bits */

#define	TCPF_URG	0x20	/* urgent pointer is valid		*/
#define	TCPF_ACK	0x10	/* acknowledgement field is valid	*/
#define	TCPF_PSH	0x08	/* this segment requests a push		*/
#define	TCPF_RST	0x04	/* reset the connection			*/
#define	TCPF_SYN	0x02	/* synchronize sequence numbers		*/
#define	TCPF_FIN	0x01	/* sender has reached end of its stream	*/

#define	TCPMHLEN	  20	/* minimum TCP header length		*/
#define	TCPHOFFSET	0x50	/* tcp_offset value for TCPMHLEN	*/
#define	TCP_HLEN(ptcp)		(((ptcp)->tcp_offset & 0xf0)>>2)

/* TCP Options */

#define	TPO_EOOL	0	/* end Of Option List			*/
#define	TPO_NOOP	1	/* no Operation				*/
#define	TPO_MSS		2	/* maximum Segment Size			*/

#include <tcpstat.h>

/* tcballoc.c */
extern struct tcb *tcballoc(void);
/* tcbdealloc.c */
extern int tcbdealloc(struct tcb *ptcb);
/* tcpbind.c */
extern int tcpbind(struct tcb *ptcb, char *fport, int lport);
/* tcpclose.c */
extern int tcpclose(struct devsw *pdev);
/* tcpcntl.c */
extern int tcpcntl(struct devsw *pdev, int func, char *arg, char *arg2);
/* tcpcon.c */
extern int tcpcon(struct tcb *ptcb);
/* tcpgetc.c */
extern int tcpgetc(struct devsw *pdev);
/* tcpgetdata.c */
//extern int tcpgetdata(struct tcb *ptcb, char *pch, int len);
extern int tcpgetdata(struct tcb *ptcb, unsigned char *pch, int len);
/* tcpgetspace.c */
extern int tcpgetspace(struct tcb *ptcb, int len);
/* tcpinit.c */
extern int tcpminit(struct devsw *pdev);
extern int tcpinit(struct devsw *pdev);
/* tcplq.c */
extern int tcplq(struct tcb *ptcb, int lqsize);
/* tcpmcntl.c */
extern int tcpmcntl(struct devsw *pdev, int func, int arg);
/* tcpmopen.c */
extern int tcpmopen(struct devsw *pdev, char *fport, int lport);
/* tcpnxtp.c */
extern short tcpnxtp(void);
/* tcpputc.c */
extern int tcpputc(struct devsw *pdev, int ch);
/* tcpread.c */
//extern int tcpread(struct devsw *pdev, char *pch, int len);
extern int tcpread(struct devsw *pdev, unsigned char *pch, int len);
/* tcpserver.c */
extern int tcpserver(struct tcb *ptcb, int lport);
/* tcpstat.c */
extern int tcpstat(struct tcb *ptcb, struct tcpstat *tcps);
/* tcpuopt.c */
extern int tcpuopt(struct tcb *ptcb, int func, int flags);
/* tcpwr.c */
extern int tcpwr(struct devsw *pdev, char *pch, int len, int isurg);
/* tcpwrite.c */
extern int tcpwrite(struct devsw *pdev, char *pch, int len);
#endif /* _TCP_H_ */
