/*
 * Copyright 2001, Metro Link, Inc.
 * All Rights Reserved
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Metro Link, Inc. and may
 * contain proprietary, confidential and trade secret information of
 * Metro Link, Inc. and/or its partners.
 *  
 * The contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Metro Link, Inc.
 *
 */
#ifndef _TTY_H_
#define _TTY_H_
/* tty.h */

#define	IBLEN		256		/* input buffer size		*/
#define	OBLEN		256		/* output buffer size		*/


/* terminal special characters */
struct tchars {
	unsigned char	tc_erase;
	unsigned char	tc_intr;
	unsigned char	tc_kill;
	unsigned char	tc_lnext;
	unsigned char	tc_reprint;
	unsigned char	tc_eof;
	unsigned char	tc_stop;
	unsigned char	tc_start;
	unsigned char	tc_susp;
	unsigned char	tc_werase;
	unsigned char	tc_eol;
};

#define	CNTRL(c) ((c) - 'a' + 1)

struct tty {
	unsigned char	 tty_state;	/* TTYS_* below			*/
	struct devsw	*tty_pdev;	/* tty dev structure		*/
	struct devsw	*tty_phw;	/* hardware dev structure	*/
	struct tchars	 tty_tchars;	/* line editing characters	*/
	int		 tty_cpid;	/* controlling process		*/

	/* TTY input fields */
	int		 tty_isema;	/* 1/0 semaphore for tty input	*/
	unsigned char	 tty_iflags;	/* TIF_* below			*/
	unsigned short	 tty_istart;	/* index of first character	*/
	unsigned short	 tty_icount;	/* # characters in input buffer	*/
// MCB L92	unsigned char	 tty_in[IBLEN];

	/* TTY output fields */
	int		 tty_osema;	/* output buffer space semaphore*/
	unsigned char	 tty_oflags;	/* TOF_* below			*/
	unsigned short	 tty_ostart;	/* index of first character	*/
	unsigned short	 tty_ocount;	/* # characters in output buffer*/
// MCB L92	unsigned char	 tty_out[OBLEN];
	int		 tty_rows;
	int		 tty_cols;

	/* login information */
	int		 tty_uid;	/* user identifier		*/
	unsigned long	 tty_ltime;	/* login time			*/
	unsigned long	 tty_ctime;	/* last command time		*/
	unsigned char	 tty_in[IBLEN];
	unsigned char	 tty_out[OBLEN];
};

/* TTY states */

#define	TTYS_FREE	0
#define	TTYS_ALLOC	1

/* TTY input flags */

#define	TIF_NOBLOCK	0x0001		/* don't block on input		*/
#define	TIF_NOECHO	0x0002		/* echo input			*/
#define	TIF_RAW		0x0004
#define	TIF_CBREAK	0x0008
#define	TIF_EXCLUSIVE	0x0010
#define	TIF_EOF		0x0020		/* have seen EOF		*/

/* TTY output flags */

#define	TOF_NOBLOCK	0x0001		/* don't block on output	*/
#define	TOF_SYNC	0x0002		/* do synchronous output	*/
#define	TOF_RAW		0x0004		/* do raw output		*/

/* control() functions */

#define TTC_CPID	0x0001		/* set controlling PID		*/
#define	TTC_SYNC	0x0002		/* do synchronous output	*/
#define	TTC_GIF		0x0003		/* get input flags		*/
#define	TTC_GOF		0x0004		/* get output flags		*/
#define	TTC_NEXTC	0x0005		/* peek at next character	*/
#define	TTC_SUSER	0x0006		/* set uid for a tty		*/
#define	TTC_CUSER	0x0007		/* clear uid for a tty		*/
#define TTC_SIF		0x0008		/* set input flags		*/
#define TTC_SOF		0x0009		/* set output flags		*/

#define	NOCHAR		256

extern struct tty	ttytab[];
extern int Ntty;

/* ../tty/ttyalloc.c */
extern struct tty *ttyalloc(void);
/* ../tty/ttyclose.c */
extern int ttyclose(struct devsw *pdev);
/* ../tty/ttycntl.c */
extern int ttycntl(struct devsw *pdev, int func, char *arg1, char *arg2);
/* ../tty/ttyfree.c */
extern void ttyfree(struct tty *ptty);
/* ../tty/ttygetc.c */
extern int ttygetc(struct devsw *pdev);
/* ../tty/ttyiin.c */
extern int ttyiin(struct devsw *pdev, unsigned char ch);
/* ../tty/ttyinit.c */
extern int ttyminit(struct devsw *pdev);
extern int ttyinit(struct devsw *pdev);
/* ../tty/ttynew.c */
extern struct tty *ttynew(void);
/* ../tty/ttyoin.c */
extern int ttyoin(struct tty *ptty, int ch);
/* ../tty/ttyopen.c */
extern int ttymopen(struct devsw *pdev, int dvnum);
/* ../tty/ttyputc.c */
extern int ttyputc(struct devsw *pdev, int ch);
/* ../tty/ttyread.c */
extern int ttyread(struct devsw *pdev, unsigned char *buf, int len);
/* ../tty/ttywrite.c */
extern int ttywrite(struct devsw *pdev, unsigned char *buf, int len);
#endif /* _TTY_H_ */
